within ;
package Britannia_HVAC_DHW

  block Or2 "Logical 'or': y = u1 or u2"
    extends Modelica.Blocks.Interfaces.partialBooleanSI2SO;
    input Real  SH_Layer;
    input Real IW_Layer;
    parameter Real SH_Temp;
    parameter Real IW_Temp;
  equation

    if (u1==false and u2==true and (IW_Layer <= IW_Temp)) then
      y=false;
    elseif (u2==false and u1==true and (SH_Layer >= SH_Temp)) then
      y=false;
    else
      y = u1 or u2;
    end if;

    annotation (
      defaultComponentName="or1",
      Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,
              100}}), graphics={Text(
            extent={{-92,44},{80,-34}},
            lineColor={238,46,47},
            textString="On/Off
Control")}),
      Documentation(info="<html>
<p>
The output is <b>true</b> if at least one input is <b>true</b>, otherwise
the output is <b>false</b>.
</p>
</html>"));
  end Or2;

  block ComControl "Single Output continuous control block"
    extends Modelica.Blocks.Icons.Block;
    input Real u1;
    input Real u2;
    input Real Reldisp;
    parameter Real RelTreshold;

    Modelica.Blocks.Interfaces.RealOutput y1
      annotation (Placement(transformation(extent={{100,-8},{126,18}})));
  equation
    if ( Reldisp >= RelTreshold) then
      y1= u2;
    else
      y1 = u1;
    end if;

    annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},
              {100,100}}), graphics={Text(
            extent={{-82,78},{68,-54}},
            lineColor={238,46,47},
            textString="Disp
Control")}));
  end ComControl;

  record Refprop_Propane "Refprop.Propane"
    extends TILMedia.VLEFluidTypes.BaseVLEFluid(
      final fixedMixingRatio=true,
      final nc_propertyCalculation=1,
      final vleFluidNames={""},
      final mixingRatio_propertyCalculation={1},
      final concatVLEFluidName="Refprop.PROPANE");
    annotation ();
  end Refprop_Propane;




  model Autumn_run
    output Real COP_total_CO2=(tube.summary.Q_flow_liq+GC1_Q+GC2_Q+GC3_Q+HX_CO2_IW_Q+HX_RefRoom_Q+HX_Freezer_Q-HX_DHWdump_Q)/(Comp_MT_W+Comp_LT_W+Com_Parll_W);
    output Real COP_h_CO2_t=(tube.summary.Q_flow_liq+GC1_Q+GC2_Q+GC3_Q-HX_DHWdump_Q)/(Comp_MT_W+Comp_LT_W+Com_Parll_W);
    output Real COP_h_CO2_noD=(tube.summary.Q_flow_liq+GC1_Q+GC2_Q+GC3_Q)/(Comp_MT_W+Comp_LT_W+Com_Parll_W);
    output Real COP_c_CO2=(HX_CO2_IW_Q+HX_RefRoom_Q+HX_Freezer_Q)/(Comp_MT_W+Comp_LT_W+Com_Parll_W);
    output Real COP_h_Prop=(HX_ProSH/Comp_Pro_W);
    output Real COP_c_Prop=(HX_ProIW/Comp_Pro_W);

    output Real T_GC_CO2out=sensor_T_degC3.sensorValue;
    output Real q_HP_valve_CO2=sensor_q3.sensorValue;
    output Real p_HP_Prop=sensor_p5.sensorValue;
    output Real p_LP_Prop=sensor_p6.sensorValue;
    output Real T_IW_consumer=sensor_T_degC10.sensorValue;
    output Real T_SH_consumer=sensor_T_degC15.sensorValue;
    output Real T_DHW_consumer=sensor_T_degC13.sensorValue;

    output Real Comp_MT_W;
    output Real Comp_MT_reldisp;
    output Real Comp_LT_W;
    output Real Comp_LT_reldisp;
    output Real Com_Parll_reldisp;
    output Real Com_Parll_W;
    output Real Comp_Pro_W;
    output Real Comp_Pro_reldisp;

    output Real Prop_HP_ON=Compressor_propane.n;

    output Real GC1_Q;
    output Real GC2_Q;
    output Real GC3_Q;
    output Real GC_total=add_GasCooler.y;
    output Real HX_GW_Q;
    output Real HX_CO2_IW_Q;
    output Real HX_DHWdump_Q;
    output Real HX_RefRoom_Q;
    output Real HX_Freezer_Q;
    output Real HX_CO2air;
    output Real HX_ProSH;
    output Real HX_ProIW;
    output Real HX_ProAir;
    output Real HX_prop_dump;

    output Real tankSH_1=tank_SH.summary.arrays.T_degC_liq_cell[1];
    output Real tankSH_2=tank_SH.summary.arrays.T_degC_liq_cell[2];
    output Real tankSH_3=tank_SH.summary.arrays.T_degC_liq_cell[3];
    output Real tankSH_4=tank_SH.summary.arrays.T_degC_liq_cell[4];
    output Real tankSH_5=tank_SH.summary.arrays.T_degC_liq_cell[5];
    output Real tankSH_6=tank_SH.summary.arrays.T_degC_liq_cell[6];
    output Real tankSH_7=tank_SH.summary.arrays.T_degC_liq_cell[7];
    output Real tankSH_8=tank_SH.summary.arrays.T_degC_liq_cell[8];
    output Real tankSH_9=tank_SH.summary.arrays.T_degC_liq_cell[9];
    output Real tankSH_10=tank_SH.summary.arrays.T_degC_liq_cell[10];
    output Real tankSH_11=tank_SH.summary.arrays.T_degC_liq_cell[11];
    output Real tankSH_12=tank_SH.summary.arrays.T_degC_liq_cell[12];
    output Real tankSH_13=tank_SH.summary.arrays.T_degC_liq_cell[13];
    output Real tankSH_14=tank_SH.summary.arrays.T_degC_liq_cell[14];
    output Real tankSH_15=tank_SH.summary.arrays.T_degC_liq_cell[15];
    output Real tankSH_16=tank_SH.summary.arrays.T_degC_liq_cell[16];
    output Real tankSH_17=tank_SH.summary.arrays.T_degC_liq_cell[17];
    output Real tankSH_18=tank_SH.summary.arrays.T_degC_liq_cell[18];
    output Real tankSH_19=tank_SH.summary.arrays.T_degC_liq_cell[19];
    output Real tankSH_20=tank_SH.summary.arrays.T_degC_liq_cell[20];

    output Real tankIW_1=tank_IW.summary.arrays.T_degC_liq_cell[1];
    output Real tankIW_2=tank_IW.summary.arrays.T_degC_liq_cell[2];
    output Real tankIW_3=tank_IW.summary.arrays.T_degC_liq_cell[3];
    output Real tankIW_4=tank_IW.summary.arrays.T_degC_liq_cell[4];
    output Real tankIW_5=tank_IW.summary.arrays.T_degC_liq_cell[5];
    output Real tankIW_6=tank_IW.summary.arrays.T_degC_liq_cell[6];
    output Real tankIW_7=tank_IW.summary.arrays.T_degC_liq_cell[7];
    output Real tankIW_8=tank_IW.summary.arrays.T_degC_liq_cell[8];
    output Real tankIW_9=tank_IW.summary.arrays.T_degC_liq_cell[9];
    output Real tankIW_10=tank_IW.summary.arrays.T_degC_liq_cell[10];
    output Real tankIW_11=tank_IW.summary.arrays.T_degC_liq_cell[11];
    output Real tankIW_12=tank_IW.summary.arrays.T_degC_liq_cell[12];
    output Real tankIW_13=tank_IW.summary.arrays.T_degC_liq_cell[13];
    output Real tankIW_14=tank_IW.summary.arrays.T_degC_liq_cell[14];
    output Real tankIW_15=tank_IW.summary.arrays.T_degC_liq_cell[15];
    output Real tankIW_16=tank_IW.summary.arrays.T_degC_liq_cell[16];
    output Real tankIW_17=tank_IW.summary.arrays.T_degC_liq_cell[17];
    output Real tankIW_18=tank_IW.summary.arrays.T_degC_liq_cell[18];
    output Real tankIW_19=tank_IW.summary.arrays.T_degC_liq_cell[19];
    output Real tankIW_20=tank_IW.summary.arrays.T_degC_liq_cell[20];

    output Real tankDHW_1=tank_DHW.summary.arrays.T_degC_liq_cell[1];
    output Real tankDHW_2=tank_DHW.summary.arrays.T_degC_liq_cell[2];
    output Real tankDHW_3=tank_DHW.summary.arrays.T_degC_liq_cell[3];
    output Real tankDHW_4=tank_DHW.summary.arrays.T_degC_liq_cell[4];
    output Real tankDHW_5=tank_DHW.summary.arrays.T_degC_liq_cell[5];
    output Real tankDHW_6=tank_DHW.summary.arrays.T_degC_liq_cell[6];
    output Real tankDHW_7=tank_DHW.summary.arrays.T_degC_liq_cell[7];
    output Real tankDHW_8=tank_DHW.summary.arrays.T_degC_liq_cell[8];
    output Real tankDHW_9=tank_DHW.summary.arrays.T_degC_liq_cell[9];
    output Real tankDHW_10=tank_DHW.summary.arrays.T_degC_liq_cell[10];
    output Real tankDHW_11=tank_DHW.summary.arrays.T_degC_liq_cell[11];
    output Real tankDHW_12=tank_DHW.summary.arrays.T_degC_liq_cell[12];
    output Real tankDHW_13=tank_DHW.summary.arrays.T_degC_liq_cell[13];
    output Real tankDHW_14=tank_DHW.summary.arrays.T_degC_liq_cell[14];
    output Real tankDHW_15=tank_DHW.summary.arrays.T_degC_liq_cell[15];
    output Real tankDHW_16=tank_DHW.summary.arrays.T_degC_liq_cell[16];
    output Real tankDHW_17=tank_DHW.summary.arrays.T_degC_liq_cell[17];
    output Real tankDHW_18=tank_DHW.summary.arrays.T_degC_liq_cell[18];
    output Real tankDHW_19=tank_DHW.summary.arrays.T_degC_liq_cell[19];
    output Real tankDHW_20=tank_DHW.summary.arrays.T_degC_liq_cell[20];

    inner TIL.SystemInformationManager sim(redeclare
        TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
      redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
      redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType2,
      redeclare TILMedia.GasTypes.TILMedia_MoistAir gasType2,
      redeclare Refprop_Propane vleFluidType2,
      redeclare TILMedia.GasTypes.TILMedia_MoistAir gasType1,
      removeSingularity=true)
      annotation (Placement(transformation(extent={{186,276},{206,296}})));

    TIL.LiquidComponents.Pumps.SimplePump simplePump(
      presetVariableType="m_flow",
      use_volumeFlowRateInput=false,
      m_flowFixed=0.3,
      use_massFlowRateInput=true)
                annotation (Placement(transformation(
          extent={{-8,-8},{8,8}},
          rotation=180,
          origin={-164,338})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC
      annotation (Placement(transformation(extent={{-150,390},{-142,398}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC1
      annotation (Placement(transformation(extent={{68,272},{76,280}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC3
      annotation (Placement(transformation(extent={{-194,146},{-186,154}})));

    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState(pInitial=
          10000000)
      annotation (Placement(transformation(extent={{156,136},{168,148}})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
      annotation (Placement(transformation(extent={{128,146},{136,154}})));
    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX       HX2(
      pressureStateID=1,
      initVLEFluid_a="linearEnthalpyDistribution",
      initHeatTransfer_a="alpha",
      m_flowStart_b=PI_Floor.yInitial,
      pStart_a=pressureState.pInitial,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.Plate.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      initLiquid_b="linearTemperatureDistribution",
      m_flowStart_a=0.2,
      hInitialVLEFluid_a_CellN=260e3,
      hInitialVLEFluid_a_Cell1=354e3,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      nCells=3,
      redeclare TIL.HeatExchangers.Plate.Geometry.PlateGeometry hxGeometry(
        length=0.6,
        width=0.2,
        phi=30,
        wallThickness=0.0009,
        patternAmplitude=0.0011,
        patternWaveLength=12.6e-3,
        numberOfPlates=144),
      TInitialVLEFluid_a=278.15,
      TInitialLiquid_b=313.15,
      TInitialLiquid_b_Cell1=308.15,
      TInitialLiquid_b_CellN=298.15)
      annotation (Placement(transformation(extent={{-22,134},{-50,162}})));

    TIL.LiquidComponents.Pumps.SimplePump simplePump1(
      presetVariableType="m_flow",
      use_massFlowRateInput=true,
      use_volumeFlowRateInput=false)
                annotation (Placement(transformation(
          extent={{-8,-8},{8,8}},
          rotation=270,
          origin={-230,208})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC4
      annotation (Placement(transformation(extent={{-182,210},{-174,218}})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint(y=35)
      annotation (Placement(transformation(extent={{-166,228},{-186,248}})));
    TIL.OtherComponents.Controllers.PIController PI_Floor(
      controllerType="PI",
      invertFeedback=true,
      yMax=10,
      initType="initialOutput",
      yInitial=0.47,
      Ti=0.1,
      k=1e-1,
      use_activeInput=true,
      use_y_notActive=true,
      yMin=1e-7)
      annotation (Placement(transformation(extent={{-218,246},{-230,234}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC5(
        initialSensorValue=40, useTimeConstant=false)
      annotation (Placement(transformation(extent={{-204,270},{-196,278}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC6
      annotation (Placement(transformation(extent={{-94,146},{-86,154}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC7
      annotation (Placement(transformation(extent={{10,146},{18,154}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC8
      annotation (Placement(transformation(extent={{36,162},{44,170}})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve(
        use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=-90,
          origin={-216,104})));

    TIL.OtherComponents.Controllers.PIController PI_HPValve(
      controllerType="PI",
      invertFeedback=true,
      Ti=0.01,
      yMax=1e-2,
      yMin=1e-12,
      yInitial=2e-6,
      k=1e-10)
      annotation (Placement(transformation(extent={{-186,110},{-198,98}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p(
      tau=1,
      useTimeConstant=false,
      initialSensorValue=10000000)                   annotation (Placement(
          transformation(
          extent={{-4,-4},{4,4}},
          rotation=-90,
          origin={-198,128})));
    Modelica.Blocks.Sources.RealExpression HighPressure(y=100e5)
      annotation (Placement(transformation(extent={{-150,94},{-170,114}})));
    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX       HX3(
      pressureStateID=1,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      initVLEFluid_a="linearEnthalpyDistribution",
      initHeatTransfer_a="alpha",
      alphaInitial_a=1900,
      m_flowStart_b=PI_DHW.yInitial,
      pStart_a=pressureState.pInitial,
      initLiquid_b="linearTemperatureDistribution",
      m_flowStart_a=0.2,
      hInitialVLEFluid_a_Cell1=260e3,
      hInitialVLEFluid_a_CellN=227e3,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.Plate.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      nCells=3,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        length=0.6,
        width=0.2,
        wallThickness=0.0009,
        patternAmplitude=0.0011,
        phi=30,
        numberOfPlates=144),
      TInitialVLEFluid_a=303.15,
      TInitialLiquid_b=328.15,
      TInitialLiquid_b_Cell1=296.15,
      TInitialLiquid_b_CellN=283.15)
      annotation (Placement(transformation(extent={{-112,136},{-140,164}})));

    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX       HX1(
      pressureStateID=1,
      initVLEFluid_a="linearEnthalpyDistribution",
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      initHeatTransfer_a="alpha",
      alphaInitial_a=1900,
      m_flowStart_b=PI_DHW.yInitial,
      pStart_a=pressureState.pInitial,
      initLiquid_b="linearTemperatureDistribution",
      hInitialVLEFluid_a_Cell1=494e3,
      hInitialVLEFluid_a_CellN=360e3,
      m_flowStart_a=0.20,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.Plate.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      nCells=3,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        length=0.6,
        width=0.2,
        wallThickness=0.0009,
        patternAmplitude=0.0011,
        phi=30,
        numberOfPlates=144),
      TInitialVLEFluid_a=551.3,
      TInitialLiquid_b=621.3,
      TInitialLiquid_b_Cell1=343.15,
      TInitialLiquid_b_CellN=296.15)
      annotation (Placement(transformation(extent={{76,136},{48,164}})));

    TIL.VLEFluidComponents.Sensors.Sensor_H_flow sensor_H_flow
      annotation (Placement(transformation(extent={{94,146},{86,138}})));
    TIL.VLEFluidComponents.Sensors.Sensor_H_flow sensor_H_flow1
      annotation (Placement(transformation(extent={{-152,146},{-160,138}})));

    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState1(
        pressureStateID=3, pInitial=3400000)
      annotation (Placement(transformation(extent={{36,-10},{48,2}})));
    TIL.VLEFluidComponents.Sensors.Sensor_q sensor_q
      annotation (Placement(transformation(extent={{2,0},{10,8}})));
    TIL.VLEFluidComponents.Separators.IdealSeparator idealSeparator(
        pressureStateID=2,
      hStart=233e3,
      mixingRatioInitial={0.1},
      V=1,
      initialFillingLevel=0.5,
      mdotStart=0.1)
      annotation (Placement(transformation(extent={{-212,36},{-200,56}})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve1(
        use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=0,
          origin={-186,-4})));
    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState2(
        pressureStateID=2, pInitial=4000000)
      annotation (Placement(transformation(extent={{-6,-6},{6,6}},
          rotation=-90,
          origin={-216,74})));
    TIL.OtherComponents.Controllers.PIController PI_ValveCooling(
      controllerType="PI",
      invertFeedback=true,
      yMin=1e-9,
      yMax=1e-5,
      initType="initialOutput",
      k=1e-10,
      yInitial=7.08e-7,
      Ti=0.1) annotation (Placement(transformation(extent={{-56,28},{-68,40}})));
    Modelica.Blocks.Sources.RealExpression Superheat_realinput(y=0.85)
      annotation (Placement(transformation(extent={{-16,24},{-36,44}})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve2(
        use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=0,
          origin={-142,52})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p1
      annotation (Placement(transformation(extent={{-172,56},{-164,64}})));
    TIL.OtherComponents.Controllers.PIController PI_bypass(
      controllerType="PI",
      invertFeedback=true,
      yInitial=1e-7,
      yMax=1e-3,
      k=1e-7,
      Ti=10,
      yMin=0)
      annotation (Placement(transformation(extent={{-150,72},{-138,84}})));
    Modelica.Blocks.Sources.RealExpression Bypass_Pressure1(y=40e5)
      annotation (Placement(transformation(extent={{-192,70},{-172,90}})));
    TIL.VLEFluidComponents.Compressors.EffCompressor Compressor_MT(
        use_mechanicalPort=true,
      use_relDisplacementInput=true,
      displacement=20e-6)
      annotation (Placement(transformation(extent={{194,54},{178,70}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p2
      annotation (Placement(transformation(extent={{138,28},{146,36}})));
    TIL.OtherComponents.Controllers.PIController PI_Comp(
      controllerType="PI",
      invertFeedback=true,
      yMax=10,
      yMin=0.01,
      yInitial=3,
      Ti=100,
      k=0.01)
      annotation (Placement(transformation(extent={{136,40},{148,52}})));
    Modelica.Blocks.Sources.RealExpression Bypass_Pressure2(y=34e5)
      annotation (Placement(transformation(extent={{104,36},{124,56}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction(
      pressureStateID=3,
      volume=5e-4,
      hInitial=397e3)
      annotation (Placement(transformation(extent={{72,-8},{80,0}})));

    TIL.VLEFluidComponents.Sensors.Sensor_m_flow sensor_m_flow annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=90,
          origin={186,110})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint1(y=70)
      annotation (Placement(transformation(extent={{-84,334},{-104,354}})));
    TIL.OtherComponents.Controllers.PIController PI_DHW(
      controllerType="PI",
      invertFeedback=true,
      yMin=0.01,
      yMax=1,
      Ti=1,
      yInitial=0.10,
      k=1e-2,
      initType="initialOutput")
      annotation (Placement(transformation(extent={{-128,338},{-140,350}})));
    TIL.VLEFluidComponents.Sensors.Sensor_q sensor_q3(initialSensorValue=0.1,
        useTimeConstant=false)
      annotation (Placement(transformation(extent={{-246,58},{-238,66}})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve3(effectiveFlowAreaFixed=
          4.6e-5, use_effectiveFlowAreaInput=true)
                                         annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=0,
          origin={-186,-114})));
    TIL.OtherComponents.Controllers.PIController PI_ValveIWC(
      controllerType="PI",
      invertFeedback=true,
      yMin=1e-8,
      yMax=5e-5,
      use_activeInput=true,
      use_y_notActive=true,
      yInitial=6.4e-6,
      Ti=0.01,
      k=1e-9)
      annotation (Placement(transformation(extent={{-90,-80},{-102,-92}})));
    TIL.VLEFluidComponents.Sensors.Sensor_q sensor_q4
      annotation (Placement(transformation(extent={{-26,-110},{-18,-102}})));
    Modelica.Blocks.Sources.RealExpression Superheat_realinput1(y=0.95)
      annotation (Placement(transformation(extent={{-52,-102},{-70,-90}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC11(liquidType=sim.liquidType1)
                                                               annotation (
        Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=180,
          origin={-128,-120})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction3(
      pressureStateID=2,
      volume=5e-5,
      hInitial=213e3)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=-90,
          origin={-206,-4})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction4(
      pressureStateID=3,
      hInitial=435e3,
      volume=5e-3)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=180,
          origin={90,-4})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction5(
      pressureStateID=2,
      volume=5e-5,
      hInitial=junction3.hInitial)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=-90,
          origin={-206,-114})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve5(
        use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=0,
          origin={-188,-390})));
    TIL.OtherComponents.Controllers.PIController PI_Valve_Freezer(
      controllerType="PI",
      invertFeedback=true,
      initType="initialOutput",
      yInitial=6.5e-7,
      k=1e-12,
      yMax=1e-5,
      yMin=1e-8,
      Ti=1)
      annotation (Placement(transformation(extent={{-114,-346},{-126,-334}})));
    Modelica.Blocks.Sources.RealExpression Superheat_realinput3(
                                                               y=2)
      annotation (Placement(transformation(extent={{-82,-350},{-102,-330}})));
    TIL.VLEFluidComponents.Sensors.Sensor_superheating sensor_superheating3
      annotation (Placement(transformation(extent={{-52,-384},{-44,-376}})));
    TIL.VLEFluidComponents.Compressors.EffCompressor Compressor_LT(
        use_mechanicalPort=true, use_relDisplacementInput=true)
      annotation (Placement(transformation(extent={{128,-344},{112,-328}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p3
      annotation (Placement(transformation(extent={{84,-374},{92,-366}})));
    TIL.OtherComponents.Controllers.PIController PI_LP_Comp(
      controllerType="PI",
      invertFeedback=true,
      yMin=1,
      Ti=100,
      yMax=3,
      k=1e-6,
      yInitial=1.1)
      annotation (Placement(transformation(extent={{82,-348},{94,-336}})));
    Modelica.Blocks.Sources.RealExpression Bypass_Pressure3(y=14.2e5)
      annotation (Placement(transformation(extent={{50,-352},{70,-332}})));
    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState3(
        pressureStateID=4, pInitial=1420000)
      annotation (Placement(transformation(extent={{16,-396},{28,-384}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction1(
      pressureStateID=3,
      volume=5e-3,
      hInitial=467e3)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=180,
          origin={120,-4})));
    TIL.HeatExchangers.ShellAndTube.VLEFluidLiquid.Evaporator    GreyWater_HX(
      pressureStateID=3,
      nCells=3,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.ShellAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.ShellAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.ShellAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      TInitialSuperheating=1,
      initLiquid="linearTemperatureDistribution",
      redeclare model ShellSideSinglePhaseHeatTransferModel =
          TIL.HeatExchangers.ShellAndTube.TransportPhenomena.ShellSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model ShellSideEvaporationHeatTransferModel =
          TIL.HeatExchangers.ShellAndTube.TransportPhenomena.ShellSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      initialFillingLevel=0.8,
      redeclare TIL.HeatExchangers.ShellAndTube.Geometry.ShellAndTubeGeometry
        hxGeometry(
        topClearance=0.01,
        bottomClearance=0.01,
        tubeOuterDiameter=10e-3,
        tubeWallThickness=1.5e-3,
        tubeActiveLength=1.5,
        shellInnerDiameter=0.4,
        nTotalTubes=60),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      TInitialWall=273.65,
      TInitialLiquid_Cell1=275.15,
      TInitialLiquid_CellN=293.15,
      m_flowStartLiquid=0.09185)
      annotation (Placement(transformation(extent={{-118,-244},{-90,-272}})));

    TIL.VLEFluidComponents.Valves.OrificeValve valve4(
        use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=0,
          origin={-184,-244})));
    TIL.OtherComponents.Controllers.PIController PI_Valve_GreyWater(
      controllerType="PI",
      invertFeedback=true,
      use_activeInput=true,
      use_y_notActive=true,
      k=1e-12,
      Ti=1,
      yMin=9.7e-7,
      yMax=5e-6,
      yInitial=1.1e-6)
      annotation (Placement(transformation(extent={{-72,-222},{-84,-210}})));
    Modelica.Blocks.Sources.RealExpression Superheat_realinput2(y=1)
      annotation (Placement(transformation(extent={{0,-210},{-20,-190}})));
    TIL.VLEFluidComponents.Sensors.Sensor_superheating sensor_superheating2(
        initialSensorValue=1, useTimeConstant=false)
      annotation (Placement(transformation(extent={{-82,-236},{-74,-228}})));
    TIL.LiquidComponents.Boundaries.BoundaryUnderdetermined
      boundaryUnderdetermined
      annotation (Placement(transformation(extent={{-164,-268},{-156,-248}})));
    TIL.LiquidComponents.Boundaries.BoundaryOverdetermined
      boundaryOverdetermined(
      streamVariablesInputType="T",
      boundaryType="p, m_flow",
      m_flowFixed=-0.09185,
      use_massFlowRateInput=true,
      TFixed=293.15)
      annotation (Placement(transformation(extent={{-46,-268},{-54,-248}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction2(
      pressureStateID=2,
      volume=5e-5,
      hInitial=junction3.hInitial)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=-90,
          origin={-206,-244})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction6(
      pressureStateID=3,
      volume=5e-4,
      hInitial=446e3)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=90,
          origin={90,-114})));
    TIL.VLEFluidComponents.Separators.IdealSeparator idealSeparator1(
      pressureStateID=3,
      hStart=junction.hInitial,
      mixingRatioInitial={1},
      V=1,
      mdotStart=0.2,
      initialFillingLevel=0)
      annotation (Placement(transformation(extent={{138,-18},{150,2}})));

    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX HX_CO2_IW(
      initVLEFluid_a="linearEnthalpyDistribution",
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      pressureStateID=3,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      m_flowStart_a=PI_ValveIWC.yInitial,
      pStart_a=pressureState1.pInitial,
      m_flowStart_b=PI_Pump_IWC.yInitial,
      initHeatTransfer_a="alpha",
      alphaInitial_a=1500,
      hInitialVLEFluid_a_CellN=junction4.hInitial,
      hInitialVLEFluid_a_Cell1=junction3.hInitial,
      liquidType_b=sim.liquidType1,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
          numberOfPlates=80),
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      cellOrientation_a="A",
      nCells=5,
      initLiquid_b="linearTemperatureDistribution",
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      TInitialVLEFluid_a=273.15,
      TInitialLiquid_b=280.15,
      TInitialLiquid_b_Cell1=280.15,
      TInitialLiquid_b_CellN=288.15)
      annotation (Placement(transformation(extent={{-112,-108},{-84,-136}})));

    TIL.LiquidComponents.HydraulicCapacitors.HydraulicCapacitor
      hydraulicCapacitor1(
                         C=1e20,
      fixedInitialPressure=true,
      massInitial=1,
      m_flowStart=0.3,
      TInitial=283.15)
      annotation (Placement(transformation(extent={{66,380},{74,396}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC17
      annotation (Placement(transformation(extent={{100,388},{108,396}})));
    TIL.LiquidComponents.Sensors.Sensor_m_flow sensor_m_flow3
      annotation (Placement(transformation(extent={{56,380},{48,388}})));
    TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundary1(
        boundaryType="n",
      use_nInput=false,
      nFixed=50)
      annotation (Placement(transformation(extent={{154,52},{162,72}})));
    TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundary2(
        boundaryType="n",
      use_nInput=false,
      nFixed=50)
      annotation (Placement(transformation(extent={{98,-346},{106,-326}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC10(liquidType=sim.liquidType1)
                                                               annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=0,
          origin={-266,-122})));
    TIL.LiquidComponents.Tubes.Tube tank_IW(
      redeclare model PressureDropModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      initLiquid="linearTemperatureDistribution",
      m_flowStart=0.5,
      redeclare model TubeSideHeatTransferModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1),
      redeclare model WallHeatConductionModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.WallHeatTransfer.ConstantR
          (constantR=1/4000),
      tubeGeometry(
        wallThickness=0.05,
        crossSectionType=TIL.Internals.CrossSectionType.Circular,
        innerDiameter=1,
        length=60.15),
      nCells=20,
      TInitialWall=288.15,
      TInitialLiquid_Cell1=288.15,
      TInitialLiquid_CellN=288.15) annotation (Placement(transformation(
          extent={{14,-4},{-14,4}},
          rotation=-90,
          origin={-246,-154})));

    TIL.LiquidComponents.JunctionElements.VolumeJunction junction8(volume=1e-4,
        TInitial=280.15)                                           annotation (
        Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=0,
          origin={-246,-130})));
    TIL.LiquidComponents.Tubes.Tube tank_DHW(
      nCells=20,
      redeclare model TubeSideHeatTransferModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1900),
      redeclare model WallHeatConductionModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model PressureDropModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      m_flowStart=3,
      redeclare TIL.LiquidComponents.Tubes.Geometry.TubeGeometry tubeGeometry(
          innerDiameter=1, length=12.73),
      initLiquid="constantTemperature",
      TInitialLiquid=283.15,
      TInitialWall=283.15,
      TInitialLiquid_Cell1=283.15,
      TInitialLiquid_CellN=343.15)
                           annotation (Placement(transformation(
          extent={{-16,-4},{16,4}},
          rotation=90,
          origin={102,336})));

    TIL.LiquidComponents.Boundaries.Boundary OutletDHW2(
      streamVariablesInputType="T",
      use_temperatureInput=false,
      boundaryType="m_flow",
      m_flowFixed=0.5,
      use_massFlowRateInput=true,
      TFixed=353.15)
      annotation (Placement(transformation(extent={{166,360},{158,380}})));
    TIL.LiquidComponents.Boundaries.Boundary OutletDHW3(
                                                       boundaryType="p",
      streamVariablesInputType="T",
      use_temperatureInput=false,
      TFixed=278.15)
      annotation (Placement(transformation(extent={{156,304},{164,324}})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction9(volume=5e-3, TInitial=
         343.15)
      annotation (Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=-90,
          origin={104,362})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction10(volume=5e-3,
        TInitial=283.15)
      annotation (Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=0,
          origin={112,314})));
    TIL.HeatExchangers.FinAndTube.MoistAirLiquid.CrossFlowHX    parallelFlowHX(
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      moistAirCellFlowType="flow A-B",
      redeclare model FinSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
      gasType=sim.gasType2,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=10000),
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=10000),
      m_flowMoistAirStart=1,
      nCells=3,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
      redeclare model FinEfficiencyModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinEfficiency.Schmidt,
      redeclare TIL.HeatExchangers.FinAndTube.Geometry.KKI001 hxGeometry(
          nSerialTubes=20, nParallelTubes=20),
      TInitialLiquid=283.15,
      TInitialWall=283.15,
      m_flowLiquidStart=0.122)
      annotation (Placement(transformation(extent={{-60,370},{-32,398}})));

    TIL.GasComponents.Fans.SimpleFan simpleFan2(use_volumeFlowRateInput=true,
        gasType=sim.gasType2) annotation (Placement(transformation(
          extent={{-8,-8},{8,8}},
          rotation=180,
          origin={-46,424})));
    TIL.GasComponents.Boundaries.Boundary boundary(
      streamVariablesInputType="T",
      boundaryType="p",
      gasType=sim.gasType2,
      TFixed=277.25)
      annotation (Placement(transformation(extent={{-4,-10},{4,10}},
          rotation=-90,
          origin={-46,444})));
    TIL.GasComponents.Boundaries.Boundary boundary1(
      boundaryType="p",
      streamVariablesInputType="T",
      gasType=sim.gasType2,
      TFixed=283.15)
      annotation (Placement(transformation(extent={{-4,-10},{4,10}},
          rotation=90,
          origin={-46,356})));
    Modelica.Blocks.Logical.GreaterThreshold greaterThreshold(threshold=10)
      annotation (Placement(transformation(extent={{48,418},{28,438}})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint3(y=
          sensor_T_degC17.sensorValue)
      annotation (Placement(transformation(extent={{78,418},{58,438}})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction11(volume=8e-3,
        TInitial=308.15)                                           annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=180,
          origin={-286,262})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction12(volume=8e-3,
        TInitial=298.15)                                           annotation (
        Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=180,
          origin={-286,208})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction13(volume=8e-3,
        TInitial=308.15)                                           annotation (
        Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=180,
          origin={-270,262})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction14(volume=8e-3,
        TInitial=298.15)                                           annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=180,
          origin={-270,208})));
    TIL.LiquidComponents.Tubes.Tube tank_SH(
      redeclare model PressureDropModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      enableHeatPorts=false,
      initLiquid="linearTemperatureDistribution",
      redeclare model TubeSideHeatTransferModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1),
      redeclare model WallHeatConductionModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.WallHeatTransfer.ConstantR
          (constantR=1/4000),
      m_flowStart=-0.3,
      nCells=20,
      tubeGeometry(
        wallThickness=0.05,
        crossSectionType=TIL.Internals.CrossSectionType.Circular,
        innerDiameter=1,
        length=60.93),
      TInitialWall=298.15,
      TInitialLiquid_Cell1=298.15,
      TInitialLiquid_CellN=298.15) annotation (Placement(transformation(
          extent={{16,-4},{-16,4}},
          rotation=-90,
          origin={-288,234})));

    TIL.LiquidComponents.Boundaries.Boundary InletFloor1(
      boundaryType="m_flow",
      m_flowFixed=0.8,
      use_massFlowRateInput=true,
      TFixed=308.15)   annotation (Placement(transformation(
          extent={{-4,-10},{4,10}},
          rotation=0,
          origin={-332,262})));
    TIL.LiquidComponents.Boundaries.Boundary InletFloor2(
      m_flowFixed=-0.8,
      boundaryType="p",
      TFixed=298.15)   annotation (Placement(transformation(
          extent={{-4,-10},{4,10}},
          rotation=0,
          origin={-332,208})));
    TIL.LiquidComponents.Pumps.SimplePump simplePump2(
      presetVariableType="m_flow",
      use_massFlowRateInput=true,
      use_volumeFlowRateInput=false)
                annotation (Placement(transformation(
          extent={{8,-8},{-8,8}},
          rotation=0,
          origin={-464,240})));
    TIL.OtherComponents.Controllers.PIController PI_Floor1(
      controllerType="PI",
      invertFeedback=true,
      k=0.1,
      Ti=10,
      yMax=10,
      yMin=1e-7,
      yInitial=0.8,
      use_activeInput=true,
      use_y_notActive=true)
      annotation (Placement(transformation(extent={{-416,228},{-428,240}})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint5(y=35)
      annotation (Placement(transformation(extent={{-376,224},{-396,244}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC18
      annotation (Placement(transformation(extent={{-456,220},{-448,228}})));
    TIL.LiquidComponents.HydraulicCapacitors.HydraulicCapacitor
      hydraulicCapacitor3(
                         C=1e20,
      fixedInitialPressure=true,
      massInitial=1,
      m_flowStart=0.3)
      annotation (Placement(transformation(extent={{-290,168},{-284,182}})));
    TIL.OtherComponents.Controllers.PIController PI_Pump_IWC(
      controllerType="PI",
      initType="initialOutput",
      use_activeInput=true,
      use_y_notActive=true,
      invertFeedback=true,
      yMax=6,
      k=1e-4,
      yMin=0.2,
      yInitial=0.2,
      Ti=0.01)
      annotation (Placement(transformation(extent={{-34,-160},{-46,-172}})));
    Modelica.Blocks.Sources.RealExpression Temp_IWC3(y=7)
      annotation (Placement(transformation(extent={{8,-146},{-6,-128}})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction15(volume=1e-4,
        TInitial=288.15)                                           annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=0,
          origin={-246,-178})));
    TIL.LiquidComponents.Pumps.SimplePump Pump_IWC(
      m_flowFixed=0.2,
      presetVariableType="m_flow",
      use_massFlowRateInput=true,
      use_volumeFlowRateInput=false,
      liquidType=sim.liquidType1) annotation (Placement(transformation(
          extent={{8,-8},{-8,8}},
          rotation=0,
          origin={-74,-160})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC15
      annotation (Placement(transformation(extent={{-320,266},{-312,274}})));
    TIL.LiquidComponents.Boundaries.Boundary InletFloor3(
      boundaryType="m_flow",
      m_flowFixed=0.4,
      use_massFlowRateInput=true,
      TFixed=313.15)   annotation (Placement(transformation(
          extent={{-4,-10},{4,10}},
          rotation=0,
          origin={-280,-130})));
    TIL.LiquidComponents.Boundaries.Boundary InletFloor4(
      m_flowFixed=-0.4,
      boundaryType="p",
      TFixed=288.15)   annotation (Placement(transformation(
          extent={{-4,-10},{4,10}},
          rotation=0,
          origin={-282,-178})));
    TIL.HeatExchangers.FinAndTube.GasVLEFluid.CrossFlowHX HX_Chiller(
      fixedPressureDropInitialVLEFluid=false,
      fixedTInitialWall=false,
      pressureStateID=3,
      pVLEFluidStart=pressureState1.pInitial,
      pressureDropInitialVLEFluid=0,
      gasCellFlowType="flow A-B",
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
      redeclare model FinEfficiencyModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinEfficiency.Schmidt,
      redeclare model FinSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
      nCells=3,
      initVLEFluid="linearEnthalpyDistribution",
      hInitialVLEFluid_Cell1=213e3,
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=150),
      hInitialVLEFluid_CellN=429e3,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare TIL.HeatExchangers.FinAndTube.Geometry.KKI001 hxGeometry(
          nSerialTubes=8, nParallelTubes=14),
      m_flowVLEFluidStart=0.023,
      initHeatTransfer="alpha",
      alphaInitialVLEFluid=2500,
      TInitialVLEFluid=272.15,
      TInitialWall=273.57)
      annotation (Placement(transformation(extent={{-110,10},{-82,-18}})));

    TIL.GasComponents.Fans.SimpleFan simpleFan(use_volumeFlowRateInput=true)
      annotation (Placement(transformation(extent={{-104,-50},{-88,-34}})));
    TIL.GasComponents.Volumes.Volume volume(volume=75, TInitial=276.15)
      annotation (Placement(transformation(
          extent={{-4,-8},{4,8}},
          rotation=90,
          origin={-100,-60})));
    TIL.OtherComponents.Thermal.HeatBoundary Heat_Cooling(boundaryType="Q_flow",
        Q_flowFixed(displayUnit="kW") = -5000)  annotation (Placement(
          transformation(
          extent={{-4,-6},{4,6}},
          rotation=0,
          origin={-116,-60})));
    TIL.GasComponents.Sensors.Sensor_T sensor_T annotation (Placement(
          transformation(
          extent={{-4,4},{4,-4}},
          rotation=-90,
          origin={-106,-30})));
    TIL.OtherComponents.Controllers.PIController PI_PumpChiller(
      controllerType="PI",
      invertFeedback=true,
      yMin=1,
      initType="initialOutput",
      yMax=5,
      Ti=100,
      yInitial=2,
      k=1)
      annotation (Placement(transformation(extent={{-132,-36},{-120,-48}})));
    Modelica.Blocks.Sources.RealExpression Setpoint_Cooling(y=276.15)
      annotation (Placement(transformation(extent={{-166,-52},{-146,-32}})));
    TIL.GasComponents.Sensors.Sensor_T_degC sensor_T_degC19
      annotation (Placement(transformation(extent={{-82,-38},{-74,-30}})));
    TIL.HeatExchangers.FinAndTube.GasVLEFluid.CrossFlowHX HX_Freezer(
      fixedPressureDropInitialVLEFluid=false,
      fixedTInitialWall=false,
      hInitialVLEFluid_Cell1=250,
      hInitialVLEFluid_CellN=430,
      pressureStateID=4,
      hInitialVLEFluid=440e3,
      initVLEFluid="constantTemperature",
      gasCellFlowType="flow A-B",
      nCells=3,
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
      redeclare model FinEfficiencyModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinEfficiency.Schmidt,
      redeclare model FinSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
      pVLEFluidStart=pressureState3.pInitial,
      m_flowVLEFluidStart=0.03,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare TIL.HeatExchangers.FinAndTube.Geometry.KKI001 hxGeometry(
          nSerialTubes=8, nParallelTubes=10),
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=150),
      TInitialVLEFluid=243.15,
      TInitialWall=243.15)
      annotation (Placement(transformation(extent={{-144,-376},{-116,-404}})));

    TIL.GasComponents.Fans.SimpleFan simpleFan1(
                                               use_volumeFlowRateInput=true)
      annotation (Placement(transformation(extent={{-138,-436},{-122,-420}})));
    TIL.GasComponents.Volumes.Volume volume2(volume=60, TInitial=253.15)
      annotation (Placement(transformation(
          extent={{-4,-8},{4,8}},
          rotation=90,
          origin={-134,-450})));
    TIL.OtherComponents.Thermal.HeatBoundary Heat_Cooling1(
                                                          boundaryType="Q_flow",
        Q_flowFixed(displayUnit="kW") = -10000) annotation (Placement(
          transformation(
          extent={{-4,-6},{4,6}},
          rotation=0,
          origin={-152,-450})));
    TIL.GasComponents.Sensors.Sensor_T sensor_T2
                                                annotation (Placement(
          transformation(
          extent={{-4,4},{4,-4}},
          rotation=-90,
          origin={-142,-410})));
    TIL.OtherComponents.Controllers.PIController PI_PumpFreezer(
      controllerType="PI",
      invertFeedback=true,
      yMin=1,
      k=1,
      Ti=100,
      yInitial=1.5,
      yMax=5)
      annotation (Placement(transformation(extent={{-166,-422},{-154,-434}})));
    Modelica.Blocks.Sources.RealExpression Setpoint_Cooling1(y=253.15)
      annotation (Placement(transformation(extent={{-196,-438},{-176,-418}})));
    TIL.GasComponents.Sensors.Sensor_T_degC sensor_T_degC14
      annotation (Placement(transformation(extent={{-114,-426},{-106,-418}})));
    Modelica.Blocks.Sources.RealExpression off_value_GW(y=1e-12)
      annotation (Placement(transformation(extent={{-44,-216},{-64,-196}})));
   Modelica.Blocks.Logical.Hysteresis hysteresis(
     pre_y_start=false,
      uHigh=69,
      uLow=50)
     annotation (Placement(transformation(extent={{4,-228},{-12,-212}})));
   Modelica.Blocks.Logical.Not not1
     annotation (Placement(transformation(extent={{-20,-228},{-36,-212}})));
   Modelica.Blocks.Sources.RealExpression DHWT_Temp1(y=tank_DHW.summary.arrays.T_degC_liq_cell[
          10])
     annotation (Placement(transformation(extent={{30,-228},{12,-212}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction7(
      pressureStateID=2,
      volume=5e-5,
      hInitial=junction3.hInitial)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=-90,
          origin={-206,-390})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve6(
        use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=0,
          origin={-54,-500})));
    Modelica.Blocks.Sources.RealExpression sup_heat(y=2)
      annotation (Placement(transformation(extent={{68,-446},{48,-426}})));
    TIL.VLEFluidComponents.Sensors.Sensor_superheating sensor_superheating4
      annotation (Placement(transformation(extent={{74,-494},{82,-486}})));
    TIL.HeatExchangers.FinAndTube.GasVLEFluid.CrossFlowHX HX_Air(
      fixedPressureDropInitialVLEFluid=false,
      fixedTInitialWall=false,
      pVLEFluidStart=pressureState1.pInitial,
      pressureDropInitialVLEFluid=0,
      initHeatTransfer="alphaA",
      alphaAInitialVLEFluid=5000,
      gasCellFlowType="flow A-B",
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model FinEfficiencyModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinEfficiency.Schmidt,
      redeclare model FinSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
      nCells=3,
      hInitialVLEFluid_Cell1=213e3,
      hInitialVLEFluid_CellN=413e3,
      pressureStateID=8,
      initVLEFluid="constantEnthalpy",
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=150),
      redeclare TIL.HeatExchangers.FinAndTube.Geometry.KKI001 hxGeometry(
        nTubeSideParallelHydraulicFlows=3,
        finnedTubeLength=2,
        nSerialTubes=10,
        nParallelTubes=25),
      redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
      TInitialVLEFluid=272.15,
      TInitialWall=274.15)
      annotation (Placement(transformation(extent={{18,-486},{46,-514}})));

    TIL.OtherComponents.Controllers.PIController PI_ValveAir(
      controllerType="PI",
      invertFeedback=true,
      yMin=1e-9,
      yMax=0.5,
      use_activeInput=true,
      use_y_notActive=true,
      Ti=0.1,
      initType="initialOutput",
      k=1e-11,
      yInitial=3e-7)
      annotation (Placement(transformation(extent={{34,-452},{22,-440}})));
    TIL.VLEFluidComponents.Compressors.EffCompressor Compressor_parallell(
        use_mechanicalPort=true,
      use_relDisplacementInput=true,
      displacement=20e-6)
      annotation (Placement(transformation(extent={{234,-472},{218,-456}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p4
      annotation (Placement(transformation(extent={{178,-494},{186,-486}})));
    TIL.OtherComponents.Controllers.PIController PI_CompParallell(
      controllerType="PI",
      initType="initialOutput",
      use_activeInput=true,
      use_y_notActive=true,
      k=1e-3,
      invertFeedback=false,
      yMax=5,
      yMin=0.1,
      yInitial=1,
      Ti=1)
      annotation (Placement(transformation(extent={{172,-470},{184,-458}})));
    TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundary3(
        boundaryType="n",
      use_nInput=false,
      nFixed=50)
      annotation (Placement(transformation(extent={{206,-474},{214,-454}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction16(
      volume=5e-4,
      pressureStateID=1,
      hInitial=495e3)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=180,
          origin={186,142})));
    Modelica.Blocks.Sources.RealExpression off_value_GW1(y=0)
      annotation (Placement(transformation(extent={{68,-432},{48,-412}})));
    TIL.GasComponents.Boundaries.Boundary
      boundaryUnderdetermined1(boundaryType="p")
      annotation (Placement(transformation(extent={{56,-490},{64,-470}})));
    TIL.GasComponents.Boundaries.Boundary               boundaryOverdetermined1(
      streamVariablesInputType="T",
      V_flowFixed=-0.5,
      boundaryType="p",
      use_volumeFlowRateInput=false,
      TFixed=277.25)
      annotation (Placement(transformation(extent={{-38,-540},{-30,-520}})));
    TIL.GasComponents.Sensors.Sensor_T_degC sensor_T_degC22
      annotation (Placement(transformation(extent={{8,-480},{16,-472}})));
    Modelica.Blocks.Sources.RealExpression off_value_GW2(y=0)
      annotation (Placement(transformation(extent={{208,-456},{188,-436}})));
    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX HX_Ammonia_SH(
      liquidType_b=sim.liquidType1,
      vleFluidType_a=sim.vleFluidType2,
      pressureStateID=5,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.Plate.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      initLiquid_b="linearTemperatureDistribution",
      hInitialVLEFluid_a=1000e3,
      initVLEFluid_a="linearEnthalpyDistribution",
      hInitialVLEFluid_a_CellN=300e3,
      nCells=3,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        phi=30,
        wallThickness=0.0009,
        patternAmplitude=0.0011,
        numberOfPlates=200,
        length=0.3,
        width=0.2),
      m_flowStart_b=0.8,
      hInitialVLEFluid_a_Cell1=650e3,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      TInitialLiquid_b_Cell1=308.15,
      TInitialLiquid_b_CellN=298.15,
      m_flowStart_a=0.1,
      pStart_a=1300000) annotation (Placement(transformation(
          extent={{-14,-14},{14,14}},
          rotation=0,
          origin={-392,164})));

   TIL.VLEFluidComponents.Valves.OrificeValve valve8(
       use_effectiveFlowAreaInput=true, vleFluidType=sim.vleFluidType2)
     annotation (Placement(transformation(
         extent={{8,-4},{-8,4}},
         rotation=0,
         origin={-362,-94})));
   TIL.VLEFluidComponents.Compressors.EffCompressor2 Compressor_propane(
      use_mechanicalPort=true,
      vleFluidType=sim.vleFluidType2,
      displacement=2e-4,
      use_relDisplacementInput=true) annotation (Placement(transformation(
          extent={{8,-8},{-8,8}},
          rotation=0,
          origin={-622,-6})));
   TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundary4(
       boundaryType="n", use_nInput=true)
     annotation (Placement(transformation(extent={{-4,-10},{4,10}},
         rotation=0,
         origin={-648,-6})));
   TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX HX_Propane_IW(
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      initHeatTransfer_a="alpha",
      alphaInitial_a=1900,
      vleFluidType_a=sim.vleFluidType2,
      pressureStateID=6,
      hInitialVLEFluid_a=1000e3,
      initVLEFluid_a="linearEnthalpyDistribution",
      initLiquid_b="linearTemperatureDistribution",
      m_flowStart_a=0.1,
      hInitialVLEFluid_a_Cell1=300e3,
      nCells=3,
      hInitialVLEFluid_a_CellN=500e3,
      m_flowStart_b=1,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.Plate.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        wallThickness=0.0009,
        patternAmplitude=0.0011,
        phi=30,
        length=0.3,
        width=0.2,
        numberOfPlates=100),
      TInitialVLEFluid_a=303.15,
      TInitialLiquid_b=291.15,
      TInitialLiquid_b_Cell1=280.15,
      TInitialLiquid_b_CellN=288.15,
      pStart_a=600000)   annotation (Placement(transformation(
          extent={{14,14},{-14,-14}},
          rotation=0,
          origin={-484,-102})));

   TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState6(
     vleFluidType=sim.vleFluidType2,
      pressureStateID=5,
      pInitial=1300000)
     annotation (Placement(transformation(extent={{-6,-6},{6,6}},
         rotation=90,
         origin={-622,14})));
   TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState7(
     pressureStateID=6,
     vleFluidType=sim.vleFluidType2,
      pInitial=600000)
     annotation (Placement(transformation(extent={{-6,-6},{6,6}},
         rotation=90,
         origin={-622,-28})));
   TIL.OtherComponents.Controllers.PIController PI_ValveProIW(
      controllerType="PI",
      invertFeedback=true,
      initType="initialOutput",
      yMax=5e-5,
      use_activeInput=true,
      use_y_notActive=true,
      yInitial=2.6e-6,
      yMin=1e-8,
      k=1e-11,
      Ti=1) annotation (Placement(transformation(
          extent={{6,6},{-6,-6}},
          rotation=180,
          origin={-390,-64})));
   Modelica.Blocks.Sources.RealExpression asupheat(y=2)
      annotation (Placement(transformation(extent={{-412,-68},{-400,-60}})));
   TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC30
     annotation (Placement(transformation(extent={{-464,-126},{-456,-118}})));
   TIL.VLEFluidComponents.Sensors.Sensor_superheating sensor_superheating6(
       vleFluidType=sim.vleFluidType2, useTimeConstant=false)
     annotation (Placement(transformation(extent={{-512,-92},{-504,-84}})));
   TIL.VLEFluidComponents.Sensors.Sensor_m_flow sensor_m_flow13(vleFluidType=
         sim.vleFluidType2)
     annotation (Placement(transformation(extent={{-590,152},{-582,160}})));
   TIL.VLEFluidComponents.Sensors.Sensor_q      sensor_T_degC23(vleFluidType=
         sim.vleFluidType2, useTimeConstant=false)
     annotation (Placement(transformation(extent={{-350,160},{-342,168}})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint(vleFluidType=sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-552,160},{-544,168}})));
    Modelica.Blocks.Sources.RealExpression Temp_IWC1(y=7)
      annotation (Placement(transformation(extent={{-494,-164},{-514,-144}})));
    TIL.OtherComponents.Controllers.PIController PI_Pump_IWC1(
      controllerType="PI",
      initType="initialOutput",
      yMax=10,
      Ti=0.01,
      invertFeedback=false,
      use_activeInput=true,
      use_y_notActive=true,
      yInitial=0.7,
      k=1e-5,
      yMin=0.01)
      annotation (Placement(transformation(extent={{-528,-148},{-540,-160}})));
    TIL.LiquidComponents.Pumps.SimplePump simplePump3(presetVariableType=
          "m_flow", use_massFlowRateInput=true)
      annotation (Placement(transformation(extent={{-552,-156},{-568,-140}})));
    Modelica.Blocks.Logical.Switch switch3
      annotation (Placement(transformation(extent={{-10,416},{-30,436}})));
   Modelica.Blocks.Sources.Constant AmmoniaOn1(k=2)
      annotation (Placement(transformation(extent={{26,440},{6,460}})));
   Modelica.Blocks.Sources.Constant AmmoniaOn2(k=1e-7)
      annotation (Placement(transformation(extent={{26,392},{6,412}})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction17(volume=1e-4,
        TInitial=280.15)                                           annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=0,
          origin={-232,-130})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction18(volume=1e-4,
        TInitial=288.15)                                           annotation (
        Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=0,
          origin={-232,-178})));
    TIL.LiquidComponents.Sensors.Sensor_m_flow sensor_m_flow1
      annotation (Placement(transformation(extent={{-198,-182},{-190,-174}})));
    TIL.LiquidComponents.Sensors.Sensor_m_flow sensor_m_flow2
      annotation (Placement(transformation(extent={{-266,-230},{-274,-222}})));
    Modelica.Blocks.Sources.RealExpression off_IWPump(y=1e-7)
      annotation (Placement(transformation(extent={{20,-190},{6,-176}})));
   Modelica.Blocks.Sources.RealExpression IWT_Temp1(y=tank_IW.summary.arrays.T_degC_liq_cell[
          1])
      annotation (Placement(transformation(extent={{58,-156},{40,-142}})));
   Modelica.Blocks.Logical.Hysteresis hysteresis1(
      pre_y_start=true,
      uLow=7,
      uHigh=14)
     annotation (Placement(transformation(extent={{12,-162},{0,-150}})));
   Modelica.Blocks.Logical.Switch switch4
     annotation (Placement(transformation(extent={{28,-162},{16,-150}})));
   Modelica.Blocks.Sources.RealExpression IWT_Temp10(y=tank_IW.summary.arrays.T_degC_liq_cell[
          4])
     annotation (Placement(transformation(extent={{58,-168},{40,-154}})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(
                                                         vleFluidType=sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-460,-90},{-452,-82}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC2(vleFluidType=
          sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-570,160},{-562,168}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC9(vleFluidType=
          sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-428,-90},{-420,-82}})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(
                                                         vleFluidType=sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-332,160},{-324,168}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC12(
                                                                vleFluidType=
          sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-310,160},{-302,168}})));
    TIL.LiquidComponents.Sensors.Sensor_m_flow sensor_m_flow4
      annotation (Placement(transformation(extent={{-526,-114},{-518,-106}})));
    TIL.LiquidComponents.Sensors.Sensor_m_flow sensor_m_flow5
      annotation (Placement(transformation(extent={{-360,168},{-368,176}})));
   Modelica.Blocks.Sources.RealExpression SHT_Temp(y=tank_SH.summary.arrays.T_degC_liq_cell[
          1])
      annotation (Placement(transformation(extent={{-906,16},{-888,30}})));
   Modelica.Blocks.Logical.Hysteresis hysteresis2(
     pre_y_start=false,
      uHigh=33,
      uLow=26)
     annotation (Placement(transformation(extent={{-854,12},{-842,24}})));
   Modelica.Blocks.Logical.Not not3
     annotation (Placement(transformation(extent={{-838,12},{-826,24}})));
   Modelica.Blocks.Sources.Constant AmmoniaOn(k=50)
      annotation (Placement(transformation(extent={{-764,16},{-748,32}})));
   TIL.OtherComponents.Controllers.PIController PI_CompAmmonia1(
      controllerType="PI",
      invertFeedback=false,
      initType="initialOutput",
      yMin=1,
      yInitial=1,
      use_activeInput=true,
      use_y_notActive=true,
      activationTime=40000,
      Ti=0.1,
      yMax=1.5,
      k=0.01)     annotation (Placement(transformation(
          extent={{-6,-6},{6,6}},
          rotation=0,
          origin={-700,-48})));
   Modelica.Blocks.Sources.RealExpression RelDispl1(y=34.5)
     annotation (Placement(transformation(extent={{-744,-56},{-726,-40}})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping2(
      n=1,
      x_start={3},
      f=0.1)
     annotation (Placement(transformation(extent={{-680,-58},{-660,-38}})));
   Modelica.Blocks.Logical.Switch switch2
     annotation (Placement(transformation(extent={{-874,12},{-862,24}})));
   Modelica.Blocks.Sources.RealExpression DHWT_Temp2(y=tank_SH.summary.arrays.T_degC_liq_cell[
          4])
     annotation (Placement(transformation(extent={{-906,6},{-888,20}})));
   Modelica.Blocks.Sources.Constant AmmoniaOff(k=1)
      annotation (Placement(transformation(extent={{-766,-40},{-750,-24}})));
    Modelica.Blocks.Logical.Switch switch1
      annotation (Placement(transformation(extent={{-722,-14},{-702,6}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_airvalve1(y=hysteresis1.y)
      annotation (Placement(transformation(extent={{-58,-94},{-74,-80}})));
    TIL.HeatExchangers.FinAndTube.GasVLEFluid.CrossFlowHX    HX_propaneAir(
      fixedPressureDropInitialVLEFluid=false,
      fixedTInitialWall=false,
      pressureDropInitialVLEFluid=0,
      initHeatTransfer="alphaA",
      gasCellFlowType="flow A-B",
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
      redeclare model FinEfficiencyModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinEfficiency.Schmidt,
      redeclare model FinSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
      nCells=3,
      initVLEFluid="linearEnthalpyDistribution",
      vleFluidType=sim.vleFluidType2,
      pVLEFluidStart=pressureState7.pInitial,
      hInitialVLEFluid_Cell1=600e3,
      hInitialVLEFluid_CellN=300e3,
      gasType=sim.gasType1,
      pressureStateID=6,
      m_flowVLEFluidStart=0,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=150),
      redeclare TIL.HeatExchangers.FinAndTube.Geometry.KKI001 hxGeometry(
        finnedTubeLength=2,
        nSerialTubes=10,
        nParallelTubes=25),
      TInitialVLEFluid=272.15,
      TInitialWall=274.15,
      alphaAInitialVLEFluid=2500)
      annotation (Placement(transformation(extent={{-446,30},{-474,2}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction19(
      vleFluidType=sim.vleFluidType2,
      pressureStateID=6,
      hInitial=587e3,
      volume=5e-4)
      annotation (Placement(transformation(extent={{4,-4},{-4,4}},
          rotation=90,
          origin={-590,-46})));
    TIL.GasComponents.Boundaries.Boundary boundary2(
      boundaryType="p",
      streamVariablesInputType="T",
      gasType=sim.gasType1,
      TFixed=283.15)
      annotation (Placement(transformation(extent={{-4,-10},{4,10}},
          rotation=90,
          origin={-460,42})));
    TIL.GasComponents.Boundaries.Boundary boundary3(
      streamVariablesInputType="T",
      gasType=sim.gasType1,
      V_flowFixed=-3,
      boundaryType="p",
      TFixed=277.25)
      annotation (Placement(transformation(extent={{-4,-10},{4,10}},
          rotation=-90,
          origin={-462,-30})));
   TIL.VLEFluidComponents.Valves.OrificeValve valve7(
       use_effectiveFlowAreaInput=true, vleFluidType=sim.vleFluidType2)
     annotation (Placement(transformation(
         extent={{8,4},{-8,-4}},
         rotation=0,
         origin={-374,16})));
    Modelica.Blocks.Sources.BooleanExpression on_off_propane_valves(y=
          hysteresis3.y)
      annotation (Placement(transformation(extent={{-570,-54},{-558,-42}})));
   TIL.OtherComponents.Controllers.PIController PI_ValveProAirEvap(
      controllerType="PI",
      invertFeedback=true,
      initType="initialOutput",
      yMax=5e-5,
      use_activeInput=true,
      use_y_notActive=true,
      yInitial=2e-6,
      yMin=1e-8,
      k=1e-11,
      Ti=1) annotation (Placement(transformation(
          extent={{6,-6},{-6,6}},
          rotation=180,
          origin={-404,-14})));
   TIL.VLEFluidComponents.Sensors.Sensor_superheating sensor_superheating1(
       vleFluidType=sim.vleFluidType2, useTimeConstant=false)
     annotation (Placement(transformation(extent={{-512,22},{-504,30}})));
   Modelica.Blocks.Sources.RealExpression asupheat3(y=2)
      annotation (Placement(transformation(extent={{-426,-16},{-416,-8}})));
   Modelica.Blocks.Logical.Not not2
     annotation (Placement(transformation(extent={{-546,-40},{-536,-30}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction20(
      volume=1e-5,
      vleFluidType=sim.vleFluidType2,
      pressureStateID=5,
      hInitial=300e3)
      annotation (Placement(transformation(extent={{4,4},{-4,-4}},
          rotation=90,
          origin={-304,-46})));
   Modelica.Blocks.Sources.RealExpression asupheat1(y=1e-8)
      annotation (Placement(transformation(extent={{-468,-48},{-458,-38}})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping1(
      n=1,
      x_start={50},
      f=0.001)
     annotation (Placement(transformation(extent={{-684,-16},{-664,4}})));
   Modelica.Blocks.Sources.RealExpression asupheat4(y=1e-7)
      annotation (Placement(transformation(extent={{-550,-178},{-536,-166}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_airvalve4(y=not3.y)
      annotation (Placement(transformation(extent={{-378,214},{-394,226}})));
   Modelica.Blocks.Sources.RealExpression asupheat5(y=1e-7)
      annotation (Placement(transformation(extent={{-442,248},{-428,260}})));
    Modelica.Blocks.Logical.And and1
      annotation (Placement(transformation(extent={{-528,-40},{-518,-30}})));
    Modelica.Blocks.Logical.And and2
      annotation (Placement(transformation(extent={{-528,-60},{-518,-50}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_airvalve2(y=or2.y)
      annotation (Placement(transformation(extent={{-550,-54},{-536,-44}})));
    TILFileReader.FileReader fileReader(
      fileType=TILFileReader.Internals.FileTypes.CSVFile,
      decimalSeparator=TILFileReader.Internals.DecimalSeparators.ColonSeparator,
      fileName="C:/Dymola/Input_Dymola.csv")
      annotation (Placement(transformation(extent={{188,406},{208,426}})));
    TILFileReader.Variables.RealVariableName realVariableName(
                 interpolationMethod=TILFileReader.Internals.InterpolationMethods.NoInterpolation,
      factor=1,
      offset=0.001,
      variableName="DHW_70")
      annotation (Placement(transformation(extent={{200,376},{180,396}})));
    TIL.GasComponents.Fans.SimpleFan simpleFan3(V_flowFixed=3,
        use_volumeFlowRateInput=true)
      annotation (Placement(transformation(extent={{-8,-8},{8,8}},
          rotation=0,
          origin={-460,-14})));
    Modelica.Blocks.Logical.Switch switch5
      annotation (Placement(transformation(extent={{-486,-18},{-476,-8}})));
   Modelica.Blocks.Sources.RealExpression asupheat6(y=10)
      annotation (Placement(transformation(extent={{-502,-14},{-492,-4}})));
   Modelica.Blocks.Sources.RealExpression asupheat7(y=1e-2)
      annotation (Placement(transformation(extent={{-502,-22},{-492,-12}})));
    Modelica.Blocks.Sources.RealExpression Superheat_realinput4(y=1e-12)
      annotation (Placement(transformation(extent={{-52,-112},{-70,-100}})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping5(
      n=1,
      f=0.1,
      x_start={6.4e-6})
     annotation (Placement(transformation(extent={{-114,-92},{-126,-80}})));
    TILFileReader.FileReader fileReader1(
      fileType=TILFileReader.Internals.FileTypes.CSVFile,
      decimalSeparator=TILFileReader.Internals.DecimalSeparators.ColonSeparator,
      fileName="C:/Dymola/Input_Dymola.csv")
      annotation (Placement(transformation(extent={{-322,-144},{-302,-164}})));
    TILFileReader.Variables.RealVariableName realVariableSC(
      interpolationMethod=TILFileReader.Internals.InterpolationMethods.NoInterpolation,
      factor=1,
      variableName="SC_A_TEK10",
      offset=0.001)
      annotation (Placement(transformation(extent={{-322,-118},{-302,-138}})));

   Modelica.Blocks.Sources.RealExpression IWT_Temp2(y=tank_IW.summary.arrays.T_degC_liq_cell[
          10])
      annotation (Placement(transformation(extent={{-908,-14},{-890,0}})));
   Modelica.Blocks.Logical.Hysteresis hysteresis3(
      pre_y_start=true,
      uLow=7,
      uHigh=14.5)
     annotation (Placement(transformation(extent={{-852,-18},{-840,-6}})));
   Modelica.Blocks.Logical.Switch switch6
     annotation (Placement(transformation(extent={{-874,-18},{-862,-6}})));
   Modelica.Blocks.Sources.RealExpression IWT_Temp3(y=tank_IW.summary.arrays.T_degC_liq_cell[
          6])
     annotation (Placement(transformation(extent={{-908,-24},{-890,-10}})));
    TIL.VLEFluidComponents.Separators.IdealSeparator idealSeparator3(
      mixingRatioInitial={0.1},
      mdotStart=0.1,
      V=0.001,
      initialFillingLevel=0,
      hStart=433e3,
      pressureStateID=8)
      annotation (Placement(transformation(extent={{146,-514},{158,-494}})));
    TIL.GasComponents.Fans.SimpleFan simpleFan4(V_flowFixed=3,
        use_volumeFlowRateInput=true)
      annotation (Placement(transformation(extent={{-8,8},{8,-8}},
          rotation=90,
          origin={-8,-530})));
    Modelica.Blocks.Logical.Switch switch7
      annotation (Placement(transformation(extent={{-62,-576},{-42,-556}})));
   Modelica.Blocks.Sources.RealExpression asupheat8(y=10)
      annotation (Placement(transformation(extent={{-96,-564},{-82,-552}})));
   Modelica.Blocks.Sources.RealExpression asupheat9(y=1e-7)
      annotation (Placement(transformation(extent={{-96,-580},{-82,-568}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_airvalve3(y=not5.y)
      annotation (Placement(transformation(extent={{-124,-576},{-104,-556}})));
    TILFileReader.FileReader fileReader2(
      fileType=TILFileReader.Internals.FileTypes.CSVFile,
      decimalSeparator=TILFileReader.Internals.DecimalSeparators.ColonSeparator,
      fileName="C:/Dymola/Input_Dymola.csv")
      annotation (Placement(transformation(extent={{-10,-10},{10,10}},
          rotation=90,
          origin={-382,272})));
    TILFileReader.Variables.RealVariableName realVariableSC1(
      interpolationMethod=TILFileReader.Internals.InterpolationMethods.NoInterpolation,
      factor=1,
      variableName="SH_A_TEK10",
      offset=0.001)
      annotation (Placement(transformation(extent={{-364,254},{-344,274}})));
   Modelica.Blocks.Logical.Switch switch9
     annotation (Placement(transformation(extent={{-4,-262},{-16,-250}})));
    Modelica.Blocks.Sources.RealExpression off_IWPump1(y=-1e-7)
      annotation (Placement(transformation(extent={{20,-268},{6,-254}})));
    Modelica.Blocks.Sources.RealExpression off_IWPump2(y=-0.106)
      annotation (Placement(transformation(extent={{20,-258},{6,-244}})));
    Modelica.Blocks.Sources.RealExpression Bypass_Pressure5(y=HX_Air.summary.Q_flow_vle)
      annotation (Placement(transformation(extent={{134,-494},{154,-474}})));
    Modelica.Blocks.Sources.RealExpression off_value_GW5(y=25000)
      annotation (Placement(transformation(extent={{134,-464},{154,-444}})));
    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState5(
        pressureStateID=8, pInitial=3000000)
      annotation (Placement(transformation(extent={{-22,-506},{-10,-494}})));
   Modelica.Blocks.Logical.Hysteresis hysteresis5(
     pre_y_start=false,
      uLow=60,
      uHigh=69)
     annotation (Placement(transformation(extent={{146,-430},{130,-414}})));
   Modelica.Blocks.Logical.Not not5
     annotation (Placement(transformation(extent={{122,-430},{106,-414}})));
   Modelica.Blocks.Sources.RealExpression DHWT_Temp5(y=tank_DHW.summary.arrays.T_degC_liq_cell[
          15])
     annotation (Placement(transformation(extent={{196,-434},{178,-418}})));
    Modelica.Blocks.Interaction.Show.BooleanValue booleanValue(use_activePort=false,
        active=hysteresis1.y)
      annotation (Placement(transformation(extent={{0,-98},{22,-74}})));
    Modelica.Blocks.Interaction.Show.BooleanValue booleanValue1(use_activePort=false,
        active=not1.y)
      annotation (Placement(transformation(extent={{40,-236},{62,-212}})));
    Modelica.Blocks.Interaction.Show.BooleanValue booleanValue2(use_activePort=false,
        active=not5.y)
      annotation (Placement(transformation(extent={{204,-404},{226,-380}})));
    Modelica.Blocks.Interaction.Show.BooleanValue booleanValue3(use_activePort=false,
        active=and2.y)
      annotation (Placement(transformation(extent={{-288,-94},{-266,-70}})));
    Modelica.Blocks.Interaction.Show.BooleanValue booleanValue4(use_activePort=false,
        active=and1.y)
      annotation (Placement(transformation(extent={{-400,24},{-378,48}})));
    Modelica.Blocks.Interaction.Show.BooleanValue booleanValue6(use_activePort=false,
        active=not3.y)
      annotation (Placement(transformation(extent={{-494,228},{-472,252}})));
    TIL.LiquidComponents.HydraulicCapacitors.HydraulicCapacitor
      hydraulicCapacitor2(
                         C=1e20,
      fixedInitialPressure=true,
      massInitial=1,
      m_flowStart=0.3,
      TInitial=288.15)
      annotation (Placement(transformation(extent={{-3,-7},{3,7}},
          rotation=0,
          origin={-143,-175})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping6(
      n=1,
      x_start={9.77e-7},
      f=0.01)
     annotation (Placement(transformation(extent={{-98,-222},{-110,-210}})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping7(
      n=1,
      f=0.01,
      x_start={-0.09185})
     annotation (Placement(transformation(extent={{-26,-262},{-38,-250}})));
    TIL.LiquidComponents.Tubes.Tube tube(
      redeclare model TubeSideHeatTransferModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallHeatConductionModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model PressureDropModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      enableHeatPorts=true,
      initLiquid="linearTemperatureDistribution",
      m_flowStart=0.47,
      redeclare TIL.LiquidComponents.Tubes.Geometry.Tube6x1 tubeGeometry,
      nCells=2,
      TInitialWall=298.15,
      TInitialLiquid_Cell1=298.15,
      TInitialLiquid_CellN=299.15)
      annotation (Placement(transformation(extent={{-152,206},{-136,210}})));

    TIL.VLEFluidComponents.Tubes.Tube tube1(
      pressureStateID=3,
      redeclare model WallHeatConductionModel =
          TIL.VLEFluidComponents.Tubes.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model PressureDropModel =
          TIL.VLEFluidComponents.Tubes.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      enableHeatPorts=true,
      initVLEFluid="linearEnthalpyDistribution",
      redeclare TIL.VLEFluidComponents.Tubes.Geometry.Tube6x1 tubeGeometry,
      nCells=2,
      m_flowStart=-0.033,
      redeclare model TubeSideHeatTransferModel =
          TIL.VLEFluidComponents.Tubes.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      hInitialVLEFluid_Cell1=423e3,
      hInitialVLEFluid_CellN=493e3,
      TInitialWall=313.15,
      pStart=3300000) annotation (Placement(transformation(
          extent={{8,2},{-8,-2}},
          rotation=90,
          origin={120,-168})));

   Modelica.Blocks.Sources.RealExpression DHWT_Temp3(
                                                    y=tank_SH.summary.arrays.T_degC_liq_cell[
         1])
     annotation (Placement(transformation(extent={{-8,234},{-26,250}})));
   Modelica.Blocks.Logical.Hysteresis hysteresis4(
     pre_y_start=false,
      uHigh=34.8,
      uLow=34)
     annotation (Placement(transformation(extent={{-72,228},{-88,244}})));
   Modelica.Blocks.Logical.Not not4
     annotation (Placement(transformation(extent={{-96,228},{-112,244}})));
   Modelica.Blocks.Sources.RealExpression DHWT_Temp4(y=tank_SH.summary.arrays.T_degC_liq_cell[
          5])
     annotation (Placement(transformation(extent={{-10,218},{-28,234}})));
    Modelica.Blocks.Logical.Switch switch8
      annotation (Placement(transformation(extent={{-42,224},{-62,244}})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint2(y=1e-7)
      annotation (Placement(transformation(extent={{-186,214},{-206,234}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_propane_valves1(
                                                                    y=
          hysteresis3.y)
      annotation (Placement(transformation(extent={{-494,-148},{-510,-136}})));
    TIL.HeatExchangers.FinAndTube.GasVLEFluid.CrossFlowHX    HX_propaneDump(
      fixedPressureDropInitialVLEFluid=false,
      fixedTInitialWall=false,
      pressureDropInitialVLEFluid=0,
      gasCellFlowType="flow A-B",
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
      redeclare model FinEfficiencyModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinEfficiency.Schmidt,
      redeclare model FinSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
      nCells=3,
      vleFluidType=sim.vleFluidType2,
      hInitialVLEFluid_Cell1=600e3,
      hInitialVLEFluid_CellN=300e3,
      gasType=sim.gasType1,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      pVLEFluidStart=pressureState6.pInitial,
      pressureStateID=5,
      initVLEFluid="constantEnthalpy",
      hInitialVLEFluid=640e3,
      m_flowVLEFluidStart=0.1,
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=150),
      redeclare TIL.HeatExchangers.FinAndTube.Geometry.KKI001 hxGeometry(
        finnedTubeLength=2,
        nSerialTubes=12,
        nParallelTubes=30),
      TInitialVLEFluid=272.15,
      TInitialWall=323.15)
      annotation (Placement(transformation(extent={{-532,144},{-504,172}})));
    TIL.GasComponents.Boundaries.Boundary boundary4(
      boundaryType="p",
      streamVariablesInputType="T",
      gasType=sim.gasType1,
      TFixed=283.15)
      annotation (Placement(transformation(extent={{-4,-10},{4,10}},
          rotation=90,
          origin={-518,118})));
    TIL.GasComponents.Fans.SimpleFan simpleFan5(V_flowFixed=3,
        use_volumeFlowRateInput=true)
      annotation (Placement(transformation(extent={{8,8},{-8,-8}},
          rotation=90,
          origin={-544,200})));
    Modelica.Blocks.Logical.Switch switch10
      annotation (Placement(transformation(extent={{-628,208},{-608,228}})));
   Modelica.Blocks.Sources.RealExpression asupheat10(
                                                    y=10)
      annotation (Placement(transformation(extent={{-650,220},{-636,232}})));
   Modelica.Blocks.Sources.RealExpression asupheat11(y=1e-6)
      annotation (Placement(transformation(extent={{-650,204},{-636,216}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_propane_valves2(
                                                                    y=
          hysteresis3.y)
      annotation (Placement(transformation(extent={{-696,216},{-680,228}})));
    Modelica.Blocks.Logical.And and3
      annotation (Placement(transformation(extent={{-668,212},{-656,224}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_propane_valves3(y=
          hysteresis2.y)
      annotation (Placement(transformation(extent={{-696,206},{-680,218}})));
    TIL.GasComponents.Boundaries.Boundary boundary5(
      streamVariablesInputType="T",
      gasType=sim.gasType1,
      V_flowFixed=-3,
      boundaryType="p",
      TFixed=277.25)
      annotation (Placement(transformation(extent={{-4,-10},{4,10}},
          rotation=0,
          origin={-574,200})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping8(
      n=1,
      f=0.01,
      x_start={1e-12})
     annotation (Placement(transformation(extent={{-596,208},{-576,228}})));
   Modelica.Blocks.Sources.RealExpression asupheat2(y=3e-6)
      annotation (Placement(transformation(extent={{-468,-56},{-458,-46}})));
    Modelica.Blocks.Logical.Switch switch11
      annotation (Placement(transformation(extent={{-450,-52},{-440,-42}})));
   Modelica.Blocks.Sources.RealExpression RelDispl2(y=1)
     annotation (Placement(transformation(extent={{-724,-42},{-706,-26}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p5(vleFluidType=sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-614,166},{-606,174}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p6(vleFluidType=sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-606,-40},{-598,-32}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC13
      annotation (Placement(transformation(extent={{134,376},{142,384}})));
    Or2 or2(
      SH_Layer=tank_SH.summary.arrays.T_degC_liq_cell[5],
      SH_Temp=30,
      IW_Layer=tank_IW.summary.arrays.T_degC_liq_cell[5],
      IW_Temp=9)
      annotation (Placement(transformation(extent={{-766,-14},{-746,6}})));
   Modelica.Blocks.Logical.Switch switch12
     annotation (Placement(transformation(extent={{166,-426},{154,-414}})));
   Modelica.Blocks.Sources.RealExpression DHWT_Temp6(y=tank_DHW.summary.arrays.T_degC_liq_cell[
          10])
     annotation (Placement(transformation(extent={{194,-422},{176,-406}})));
    Modelica.Blocks.Math.Add add_GasCooler(k2=-1) annotation (Placement(
          transformation(
          extent={{-6,-6},{6,6}},
          rotation=-90,
          origin={-4,108})));
    ComControl comControl(
      Reldisp=Comp_Pro_reldisp,
      u1=tank_SH.summary.arrays.T_degC_liq_cell[20],
      u2=tank_SH.summary.arrays.T_degC_liq_cell[15],
      RelTreshold=1.5)
      annotation (Placement(transformation(extent={{-738,-90},{-718,-70}})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping4(
      n=1,
      x_start={1e-12},
      f=0.1)
     annotation (Placement(transformation(extent={{-384,-20},{-376,-12}})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping3(
      n=1,
      x_start={1e-12},
      f=0.1)
     annotation (Placement(transformation(extent={{-370,-70},{-362,-62}})));
  equation
    Comp_MT_W=Compressor_MT.shaftPower;
    Comp_MT_reldisp=Compressor_MT.relDisplacement_in;
    Comp_LT_W=Compressor_LT.shaftPower;
    Comp_LT_reldisp=Compressor_LT.relDisplacement_in;
    Com_Parll_reldisp=Compressor_parallell.relDisplacement_in;
    Com_Parll_W=Compressor_parallell.shaftPower;
    Comp_Pro_W=Compressor_propane.shaftPower+0.001;
    Comp_Pro_reldisp=Compressor_propane.relDisplacement_in;

    GC1_Q=HX1.summary.path_b.Q_flow_liq;
    GC2_Q=HX2.summary.path_b.Q_flow_liq;
    GC3_Q=HX3.summary.path_b.Q_flow_liq;
    HX_GW_Q=-GreyWater_HX.summary.Q_flow;
    HX_CO2_IW_Q=HX_CO2_IW.summary.Q_flow;
    HX_DHWdump_Q=-parallelFlowHX.summary.Q_flow_liq;
    HX_RefRoom_Q=HX_Chiller.summary.Q_flow_vle;
    HX_Freezer_Q=HX_Freezer.summary.Q_flow_vle;
    HX_CO2air=HX_Air.summary.Q_flow_vle;
    HX_ProSH=-HX_Ammonia_SH.summary.Q_flow;
    HX_ProIW=HX_Propane_IW.summary.Q_flow;
    HX_ProAir=HX_propaneAir.summary.Q_flow_vle;
    HX_prop_dump=HX_propaneDump.summary.Q_flow_vle;
    connect(floorHeatingSetpoint.y, PI_Floor.u_s) annotation (Line(points={{-187,
            238},{-187,240},{-218.4,240}},       color={0,0,127}));
    connect(sensor_T_degC5.sensorValue, PI_Floor.u_m) annotation (Line(points={{-200,
            276},{-224,276},{-224,245.8}},color={0,0,127}));
    connect(sensor_T_degC3.port, valve.portA) annotation (Line(
        points={{-190,146},{-190,142},{-216,142},{-216,112}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_p.port, valve.portA) annotation (Line(
        points={{-202,128},{-216,128},{-216,112}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_p.sensorValue, PI_HPValve.u_m) annotation (Line(points={{-195.8,
            128},{-192,128},{-192,109.8}}, color={0,0,127}));
    connect(HighPressure.y, PI_HPValve.u_s)
      annotation (Line(points={{-171,104},{-186,104},{-186.4,104}},
                                                         color={0,0,127}));
    connect(PI_HPValve.y, valve.effectiveFlowArea_in) annotation (Line(points={{-198.4,
            104},{-198.4,104},{-211,104}},         color={0,0,127}));
    connect(statePoint1.sensorPort, pressureState.portB) annotation (Line(
        points={{132,146},{132,142},{156,142}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_H_flow.portA, pressureState.portB) annotation (Line(
        points={{93,142},{104,142},{124,142},{156,142}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_H_flow1.portB, valve.portA) annotation (Line(
        points={{-159,142},{-216,142},{-216,112}},
        color={153,204,0},
        thickness=0.5));
    connect(valve.portB, pressureState2.portB) annotation (Line(
        points={{-216,96},{-216,80}},
        color={153,204,0},
        thickness=0.5));
    connect(pressureState2.portA, idealSeparator.portInlet) annotation (Line(
        points={{-216,68},{-216,68},{-216,50},{-211,50}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_ValveCooling.y, valve1.effectiveFlowArea_in) annotation (Line(
          points={{-68.4,34},{-186,34},{-186,1}}, color={0,0,127}));
    connect(Superheat_realinput.y, PI_ValveCooling.u_s)
      annotation (Line(points={{-37,34},{-56.4,34}},      color={0,0,127}));
    connect(idealSeparator.portGas, valve2.portA) annotation (Line(
        points={{-201,50},{-176,50},{-176,52},{-150,52}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_p1.port, valve2.portA) annotation (Line(
        points={{-168,56},{-168,52},{-150,52}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_bypass.y, valve2.effectiveFlowArea_in) annotation (Line(points={
            {-137.6,78},{-132,78},{-132,57},{-142,57}}, color={0,0,127}));
    connect(PI_bypass.u_m, sensor_p1.sensorValue) annotation (Line(points={{
            -144,72.2},{-146,72.2},{-146,62.2},{-168,62.2}}, color={0,0,127}));
    connect(Bypass_Pressure1.y, PI_bypass.u_s) annotation (Line(points={{-171,
            80},{-171,78},{-149.6,78}}, color={0,0,127}));
    connect(Bypass_Pressure2.y, PI_Comp.u_s) annotation (Line(points={{125,46},{124,
            46},{136.4,46}},      color={0,0,127}));
    connect(pressureState1.portA, junction.portA) annotation (Line(
        points={{48,-4},{48,-4},{72,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(valve2.portB, junction.portB) annotation (Line(
        points={{-134,52},{76,52},{76,0}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_q.port, pressureState1.portB) annotation (Line(
        points={{6,0},{6,-4},{36,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_p2.port, Compressor_MT.portA) annotation (Line(
        points={{142,28},{186,28},{186,54}},
        color={153,204,0},
        thickness=0.5));
    connect(Compressor_MT.portB, sensor_m_flow.portA) annotation (Line(
        points={{186,70},{186,70},{186,107}},
        color={153,204,0},
        thickness=0.5));
    connect(floorHeatingSetpoint1.y, PI_DHW.u_s) annotation (Line(points={{-105,
            344},{-105,344},{-128.4,344}},                       color={0,0,127}));
    connect(PI_DHW.y, simplePump.m_flow_in) annotation (Line(points={{-140.4,
            344},{-154,344}},                       color={0,0,127}));
    connect(PI_DHW.u_m, sensor_T_degC1.sensorValue) annotation (Line(points={{-134,
            338.2},{-134,338.2},{-134,278},{72,278}},
          color={0,0,127}));
    connect(sensor_q3.port, idealSeparator.portInlet) annotation (Line(
        points={{-242,58},{-216,58},{-216,50},{-211,50}},
        color={153,204,0},
        thickness=0.5));
    connect(Superheat_realinput1.y,PI_ValveIWC. u_s)
      annotation (Line(points={{-70.9,-96},{-82,-96},{-82,-86},{-90.4,-86}},
                                                       color={0,0,127}));
    connect(junction3.portA, idealSeparator.portLiquid) annotation (Line(
        points={{-206,8.88178e-016},{-206,36}},
        color={153,204,0},
        thickness=0.5));
    connect(junction3.portB, valve1.portA) annotation (Line(
        points={{-202,-4},{-198,-4},{-194,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(junction.portC, junction4.portC) annotation (Line(
        points={{80,-4},{86,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_Valve_Freezer.u_s,Superheat_realinput3. y) annotation (Line(
          points={{-114.4,-340},{-103,-340}},           color={0,0,127}));
    connect(PI_Valve_Freezer.y,valve5. effectiveFlowArea_in) annotation (Line(
          points={{-126.4,-340},{-188,-340},{-188,-385}},             color={0,
            0,127}));
    connect(PI_Valve_Freezer.u_m,sensor_superheating3. sensorValue)
      annotation (Line(points={{-120,-345.8},{-48,-345.8},{-48,-380},{-48,-378},
            {-48,-377.8}},                                  color={0,0,127}));
    connect(Bypass_Pressure3.y,PI_LP_Comp. u_s)
      annotation (Line(points={{71,-342},{74,-342},{82.4,-342}},
                                                         color={0,0,127}));
    connect(sensor_p3.port, Compressor_LT.portA) annotation (Line(
        points={{88,-374},{88,-378},{120,-378},{120,-344}},
        color={153,204,0},
        thickness=0.5));
    connect(pressureState3.portA, Compressor_LT.portA) annotation (Line(
        points={{28,-390},{28,-386},{120,-386},{120,-344}},
        color={153,204,0},
        thickness=0.5));
    connect(junction3.portC, junction5.portA) annotation (Line(
        points={{-206,-8},{-206,-8},{-206,-110}},
        color={153,204,0},
        thickness=0.5));
    connect(junction5.portB, valve3.portA) annotation (Line(
        points={{-202,-114},{-202,-114},{-194,-114}},
        color={153,204,0},
        thickness=0.5));
    connect(Superheat_realinput2.y,PI_Valve_GreyWater. u_s) annotation (Line(
          points={{-21,-200},{-21,-200},{-34,-200},{-40,-200},{-40,-216},{-72.4,
            -216}},                                    color={0,0,127}));
    connect(junction5.portC, junction2.portA) annotation (Line(
        points={{-206,-118},{-206,-240}},
        color={153,204,0},
        thickness=0.5));
    connect(junction2.portB, valve4.portA) annotation (Line(
        points={{-202,-244},{-198,-244},{-192,-244}},
        color={153,204,0},
        thickness=0.5));

    connect(valve3.portB, HX_CO2_IW.portA_a) annotation (Line(
        points={{-178,-114},{-112,-114}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC11.port, HX_CO2_IW.portA_b) annotation (Line(
        points={{-128,-124},{-128,-130},{-112,-130}},
        color={0,170,238},
        thickness=0.5));

    connect(sensor_T_degC17.port, hydraulicCapacitor1.portB) annotation (Line(
        points={{104,388},{104,384},{74,384}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_m_flow3.portA, hydraulicCapacitor1.portA) annotation (Line(
        points={{55,384},{55,384},{66,384}},
        color={0,170,238},
        thickness=0.5));
    connect(rotatoryBoundary1.rotatoryFlange, Compressor_MT.rotatoryFlange)
      annotation (Line(
        points={{158,62},{168,62},{178,62}},
        color={135,135,135},
        thickness=0.5));
    connect(rotatoryBoundary2.rotatoryFlange, Compressor_LT.rotatoryFlange)
      annotation (Line(
        points={{102,-336},{112,-336}},
        color={135,135,135},
        thickness=0.5));

    connect(tank_DHW.portB, junction9.portC) annotation (Line(
        points={{102,352},{102,352},{104,352},{104,358}},
        color={0,170,238},
        thickness=0.5));
    connect(tank_DHW.portA, junction10.portB) annotation (Line(
        points={{102,320},{104,320},{104,314},{108,314}},
        color={0,170,238},
        thickness=0.5));
    connect(junction10.portA, hydraulicCapacitor1.portB) annotation (Line(
        points={{112,310},{78,310},{78,384},{74,384}},
        color={0,170,238},
        thickness=0.5));
    connect(parallelFlowHX.portB_liq, sensor_m_flow3.portB) annotation (Line(
        points={{-32,384},{-32,384},{49,384}},
        color={0,170,238},
        thickness=0.5));
    connect(parallelFlowHX.portA_liq, simplePump.portA) annotation (Line(
        points={{-60,384},{-164,384},{-164,346}},
        color={0,170,238},
        thickness=0.5));
    connect(simpleFan2.portB, parallelFlowHX.portA_gas) annotation (Line(
        points={{-46,416},{-46,416},{-46,398}},
        color={255,153,0},
        thickness=0.5));
    connect(boundary.port, simpleFan2.portA) annotation (Line(
        points={{-46,444},{-46,444},{-46,432}},
        color={255,153,0},
        thickness=0.5));
    connect(parallelFlowHX.portB_gas, boundary1.port) annotation (Line(
        points={{-46,370},{-46,356}},
        color={255,153,0},
        thickness=0.5));
    connect(sensor_T_degC.port, simplePump.portA) annotation (Line(
        points={{-146,390},{-146,384},{-164,384},{-164,346}},
        color={0,170,238},
        thickness=0.5));
    connect(floorHeatingSetpoint3.y, greaterThreshold.u)
      annotation (Line(points={{57,428},{57,428},{50,428}},
                                                       color={0,0,127}));
    connect(junction13.portC, junction11.portB) annotation (Line(
        points={{-274,262},{-274,262},{-282,262}},
        color={0,170,238},
        thickness=0.5));
    connect(junction12.portB, junction14.portC) annotation (Line(
        points={{-282,208},{-274,208}},
        color={0,170,238},
        thickness=0.5));
    connect(tank_SH.portB, junction11.portA) annotation (Line(
        points={{-288,250},{-286,250},{-286,258}},
        color={0,170,238},
        thickness=0.5));
    connect(InletFloor2.port, junction12.portC) annotation (Line(
        points={{-332,208},{-290,208}},
        color={0,170,238},
        thickness=0.5));
    connect(InletFloor1.port, junction11.portC) annotation (Line(
        points={{-332,262},{-332,262},{-302,262},{-300,262},{-290,262}},
        color={0,170,238},
        thickness=0.5));
    connect(PI_Floor1.y, simplePump2.m_flow_in) annotation (Line(points={{-428.4,
            234},{-428.4,234},{-454,234}},        color={0,0,127}));
    connect(floorHeatingSetpoint5.y, PI_Floor1.u_s) annotation (Line(points={{-397,
            234},{-397,234},{-416.4,234}},      color={0,0,127}));
    connect(PI_Floor1.u_m, sensor_T_degC18.sensorValue) annotation (Line(points={{-422,
            228.2},{-422,226},{-430,226},{-452,226}},         color={0,0,127}));
    connect(sensor_T_degC10.port, junction8.portB) annotation (Line(
        points={{-266,-126},{-266,-130},{-250,-130}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC18.port, simplePump2.portA) annotation (Line(
        points={{-452,220},{-458,220},{-464,220},{-464,232}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC15.port, junction11.portC) annotation (Line(
        points={{-316,266},{-316,262},{-300,262},{-290,262}},
        color={0,170,238},
        thickness=0.5));
    connect(InletFloor4.port, junction15.portB) annotation (Line(
        points={{-282,-178},{-282,-178},{-250,-178}},
        color={0,170,238},
        thickness=0.5));
    connect(InletFloor3.port, junction8.portB) annotation (Line(
        points={{-280,-130},{-250,-130}},
        color={0,170,238},
        thickness=0.5));
    connect(HX1.portA_a, sensor_H_flow.portB) annotation (Line(
        points={{76,142},{87,142}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC8.port, HX1.portB_b) annotation (Line(
        points={{40,162},{40,158},{48,158}},
        color={0,170,238},
        thickness=0.5));
    connect(junction9.portA, HX1.portA_b) annotation (Line(
        points={{100,362},{88,362},{88,158},{76,158}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC1.port, HX1.portA_b) annotation (Line(
        points={{72,272},{88,272},{88,158},{76,158}},
        color={0,170,238},
        thickness=0.5));
    connect(HX2.portA_a, HX1.portB_a) annotation (Line(
        points={{-22,140},{13,142},{48,142}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC7.port, HX1.portB_a) annotation (Line(
        points={{14,146},{14,142},{48,142}},
        color={153,204,0},
        thickness=0.5));
    connect(HX3.portB_a, sensor_H_flow1.portA) annotation (Line(
        points={{-140,142},{-153,142}},
        color={153,204,0},
        thickness=0.5));
    connect(HX3.portA_a, HX2.portB_a) annotation (Line(
        points={{-112,142},{-50,142},{-50,140}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC6.port, HX2.portB_a) annotation (Line(
        points={{-90,146},{-90,140},{-50,140}},
        color={153,204,0},
        thickness=0.5));
    connect(simplePump.portB, HX3.portB_b) annotation (Line(
        points={{-164,330},{-164,330},{-164,158},{-140,158}},
        color={0,170,238},
        thickness=0.5));
    connect(HX3.portA_b, HX1.portB_b) annotation (Line(
        points={{-112,158},{-100,158},{-100,172},{30,172},{30,158},{48,158}},
        color={0,170,238},
        thickness=0.5));
    connect(Heat_Cooling.heatPort,volume. heatPort) annotation (Line(
        points={{-116,-60},{-116,-60},{-106,-60}},
        color={204,0,0},
        thickness=0.5));
    connect(PI_PumpChiller.y, simpleFan.V_flow_in) annotation (Line(points={{-119.6,
            -42},{-119.6,-42},{-106,-42}}, color={0,0,127}));
    connect(sensor_T.sensorValue, PI_PumpChiller.u_m) annotation (Line(points={
            {-108,-30},{-126,-30},{-126,-36.2}}, color={0,0,127}));
    connect(Setpoint_Cooling.y, PI_PumpChiller.u_s) annotation (Line(points={{-145,
            -42},{-145,-42},{-131.6,-42}}, color={0,0,127}));
    connect(volume.portB, simpleFan.portA) annotation (Line(
        points={{-96,-56},{-96,-50}},
        color={255,153,0},
        thickness=0.5));
    connect(simpleFan.portB, HX_Chiller.portA_gas) annotation (Line(
        points={{-96,-34},{-96,-18}},
        color={255,153,0},
        thickness=0.5));
    connect(sensor_T.port, HX_Chiller.portA_gas) annotation (Line(
        points={{-102,-30},{-96,-30},{-96,-18}},
        color={255,153,0},
        thickness=0.5));
    connect(HX_Chiller.portB_gas, volume.portA) annotation (Line(
        points={{-96,10},{-96,10},{-96,18},{-68,18},{-68,-68},{-96,-68},{-96,-64}},
        color={255,153,0},
        thickness=0.5));

    connect(sensor_T_degC19.port, volume.portA) annotation (Line(
        points={{-78,-38},{-68,-38},{-68,-68},{-96,-68},{-96,-64}},
        color={255,153,0},
        thickness=0.5));
    connect(simpleFan1.portA,volume2. portB) annotation (Line(
        points={{-130,-436},{-130,-436},{-130,-446}},
        color={255,153,0},
        thickness=0.5));
    connect(Heat_Cooling1.heatPort,volume2. heatPort) annotation (Line(
        points={{-152,-450},{-140,-450}},
        color={204,0,0},
        thickness=0.5));
    connect(PI_PumpFreezer.y, simpleFan1.V_flow_in) annotation (Line(points={{-153.6,
            -428},{-153.6,-428},{-140,-428}}, color={0,0,127}));
    connect(sensor_T2.sensorValue, PI_PumpFreezer.u_m) annotation (Line(points=
            {{-144,-410},{-160,-410},{-160,-422.2}}, color={0,0,127}));
    connect(Setpoint_Cooling1.y, PI_PumpFreezer.u_s) annotation (Line(points={{
            -175,-428},{-175,-428},{-165.6,-428}}, color={0,0,127}));
    connect(simpleFan1.portB, HX_Freezer.portA_gas) annotation (Line(
        points={{-130,-420},{-130,-420},{-130,-404}},
        color={255,153,0},
        thickness=0.5));
    connect(sensor_T2.port, HX_Freezer.portA_gas) annotation (Line(
        points={{-138,-410},{-130,-410},{-130,-404}},
        color={255,153,0},
        thickness=0.5));
    connect(HX_Freezer.portB_gas, volume2.portA) annotation (Line(
        points={{-130,-376},{-130,-376},{-130,-370},{-130,-366},{-98,-366},{-98,
            -460},{-130,-460},{-130,-454}},
        color={255,153,0},
        thickness=0.5));
    connect(sensor_T_degC14.port, volume2.portA) annotation (Line(
        points={{-110,-426},{-110,-426},{-98,-426},{-98,-460},{-130,-460},{-130,
            -454}},
        color={255,153,0},
        thickness=0.5));
    connect(valve5.portB, HX_Freezer.portA_vle) annotation (Line(
        points={{-180,-390},{-162,-390},{-144,-390}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_Freezer.portB_vle, pressureState3.portB) annotation (Line(
        points={{-116,-390},{-38,-390},{16,-390}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_superheating3.port, pressureState3.portB) annotation (Line(
        points={{-48,-384},{-48,-390},{16,-390}},
        color={153,204,0},
        thickness=0.5));
    connect(junction6.portC, junction4.portB) annotation (Line(
        points={{90,-110},{90,-110},{90,-8}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_CO2_IW.portB_a, junction6.portB) annotation (Line(
        points={{-84,-114},{2,-114},{86,-114}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_q4.port, junction6.portB) annotation (Line(
        points={{-22,-110},{-22,-114},{86,-114}},
        color={153,204,0},
        thickness=0.5));
    connect(off_value_GW.y, PI_Valve_GreyWater.y_notActive) annotation (Line(
          points={{-65,-206},{-78,-206},{-78,-210.2}}, color={0,0,127}));
   connect(not1.u,hysteresis. y) annotation (Line(points={{-18.4,-220},{-18.4,
            -220},{-12.8,-220}},
                        color={255,0,255}));
    connect(DHWT_Temp1.y, hysteresis.u) annotation (Line(points={{11.1,-220},{
            11.1,-220},{5.6,-220}}, color={0,0,127}));
    connect(not1.y, PI_Valve_GreyWater.activeInput) annotation (Line(points={{-36.8,
            -220},{-54,-220},{-54,-219.8},{-72.4,-219.8}},       color={255,0,
            255}));
    connect(junction7.portA, junction2.portC) annotation (Line(
        points={{-206,-386},{-206,-248}},
        color={153,204,0},
        thickness=0.5));
    connect(junction7.portB, valve5.portA) annotation (Line(
        points={{-202,-390},{-199,-390},{-196,-390}},
        color={153,204,0},
        thickness=0.5));
    connect(junction7.portC, valve6.portA) annotation (Line(
        points={{-206,-394},{-206,-394},{-206,-498},{-206,-500},{-62,-500}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_ValveAir.u_s, sup_heat.y) annotation (Line(points={{33.6,-446},{
            38,-446},{38,-436},{42,-436},{47,-436}}, color={0,0,127}));
    connect(PI_ValveAir.u_m, sensor_superheating4.sensorValue) annotation (Line(
          points={{28,-451.8},{28,-452},{28,-470},{78,-470},{78,-487.8}}, color=
           {0,0,127}));
    connect(PI_ValveAir.y, valve6.effectiveFlowArea_in) annotation (Line(points=
           {{21.6,-446},{-54,-446},{-54,-495}}, color={0,0,127}));
    connect(rotatoryBoundary3.rotatoryFlange, Compressor_parallell.rotatoryFlange)
      annotation (Line(
        points={{210,-464},{218,-464}},
        color={135,135,135},
        thickness=0.5));
    connect(junction16.portC, pressureState.portA) annotation (Line(
        points={{182,142},{176,142},{168,142}},
        color={153,204,0},
        thickness=0.5));
    connect(junction16.portB, sensor_m_flow.portB) annotation (Line(
        points={{186,138},{186,138},{186,113}},
        color={153,204,0},
        thickness=0.5));
    connect(junction16.portA, Compressor_parallell.portB) annotation (Line(
        points={{190,142},{226,142},{226,40},{226,-328},{226,-456}},
        color={153,204,0},
        thickness=0.5));
    connect(off_value_GW1.y, PI_ValveAir.y_notActive) annotation (Line(points={
            {47,-422},{28,-422},{28,-440.2}}, color={0,0,127}));
    connect(boundaryUnderdetermined1.port, HX_Air.portB_gas) annotation (Line(
        points={{60,-480},{32,-480},{32,-486}},
        color={255,153,0},
        thickness=0.5));
    connect(sensor_T_degC22.port, HX_Air.portB_gas) annotation (Line(
        points={{12,-480},{32,-480},{32,-486}},
        color={255,153,0},
        thickness=0.5));
    connect(off_value_GW2.y, PI_CompParallell.y_notActive) annotation (Line(
          points={{187,-446},{184,-446},{184,-458.2},{178,-458.2}}, color={0,0,
            127}));
    connect(PI_ValveCooling.u_m, sensor_q.sensorValue) annotation (Line(points={{-62,
            28.2},{-26,28.2},{-26,6.2},{6,6.2}},       color={0,0,127}));
    connect(HX_Ammonia_SH.portA_b, simplePump2.portA) annotation (Line(
        points={{-406,172},{-406,172},{-444,172},{-444,172},{-426,172},{-464,172},
            {-464,232}},
        color={0,170,238},
        thickness=0.5));
    connect(PI_Floor.y, simplePump1.m_flow_in) annotation (Line(points={{-230.4,
            240},{-236,240},{-236,218}}, color={0,0,127}));
    connect(junction14.portA, hydraulicCapacitor3.portB) annotation (Line(
        points={{-270,204},{-270,204},{-270,190},{-270,171.5},{-284,171.5}},
        color={0,170,238},
        thickness=0.5));
    connect(rotatoryBoundary4.rotatoryFlange, Compressor_propane.rotatoryFlange)
      annotation (Line(
        points={{-648,-6},{-648,-6},{-630,-6}},
        color={135,135,135},
        thickness=0.5));
    connect(asupheat.y, PI_ValveProIW.u_s) annotation (Line(points={{-399.4,-64},
            {-398,-64},{-395.6,-64}}, color={0,0,127}));

    connect(Compressor_propane.portA, pressureState7.portA) annotation (Line(
        points={{-622,-14},{-622,-22}},
        color={153,204,0},
        thickness=0.5));
    connect(pressureState6.portB, Compressor_propane.portB) annotation (Line(
        points={{-622,8},{-622,8},{-622,2}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_m_flow13.portA, pressureState6.portA) annotation (Line(
        points={{-589,156},{-622,156},{-622,20}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_Propane_IW.portA_a, valve8.portB) annotation (Line(
        points={{-470,-94},{-420,-94},{-370,-94}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_superheating6.port,HX_Propane_IW. portB_a) annotation (Line(
        points={{-508,-92},{-508,-94},{-498,-94}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_Pump_IWC1.y, simplePump3.m_flow_in)
      annotation (Line(points={{-540.4,-154},{-550,-154}},
                                                         color={0,0,127}));
    connect(junction14.portB, simplePump1.portA) annotation (Line(
        points={{-266,208},{-238,208}},
        color={0,170,238},
        thickness=0.5));
    connect(valve1.portB, HX_Chiller.portA_vle) annotation (Line(
        points={{-178,-4},{-110,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_Chiller.portB_vle, pressureState1.portB) annotation (Line(
        points={{-82,-4},{36,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(idealSeparator1.portGas, Compressor_MT.portA) annotation (Line(
        points={{149,-4},{186,-4},{186,54}},
        color={153,204,0},
        thickness=0.5));
    connect(tank_IW.portA, junction15.portA) annotation (Line(
        points={{-246,-168},{-246,-168},{-246,-174}},
        color={0,170,238},
        thickness=0.5));
    connect(HX_CO2_IW.portB_b, Pump_IWC.portB) annotation (Line(
        points={{-84,-130},{-74,-130},{-74,-152}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_p4.port, Compressor_parallell.portA) annotation (Line(
        points={{182,-494},{182,-500},{226,-500},{226,-472}},
        color={153,204,0},
        thickness=0.5));
    connect(simplePump2.portB, junction13.portA) annotation (Line(
        points={{-464,248},{-464,248},{-464,290},{-270,290},{-270,266}},
        color={0,170,238},
        thickness=0.5));
    connect(junction10.portC, OutletDHW3.port) annotation (Line(
        points={{116,314},{160,314},{160,314}},
        color={0,170,238},
        thickness=0.5));
    connect(junction9.portB, OutletDHW2.port) annotation (Line(
        points={{104,366},{104,370},{162,370}},
        color={0,170,238},
        thickness=0.5));
    connect(tank_SH.portA, junction12.portA) annotation (Line(
        points={{-288,218},{-286,218},{-286,212}},
        color={0,170,238},
        thickness=0.5));
    connect(switch3.y, simpleFan2.V_flow_in) annotation (Line(points={{-31,426},
            {-36,426},{-36,424}}, color={0,0,127}));
    connect(AmmoniaOn1.y, switch3.u1) annotation (Line(points={{5,450},{2,450},
            {-4,450},{-4,434},{-8,434}}, color={0,0,127}));
    connect(AmmoniaOn2.y, switch3.u3) annotation (Line(points={{5,402},{0,402},
            {0,418},{-8,418}}, color={0,0,127}));
    connect(switch3.u2, greaterThreshold.y) annotation (Line(points={{-8,426},{
            10,426},{10,428},{27,428}}, color={255,0,255}));
    connect(junction8.portC, junction17.portB) annotation (Line(
        points={{-242,-130},{-240,-130},{-236,-130}},
        color={0,170,238},
        thickness=0.5));
    connect(junction17.portC, HX_CO2_IW.portA_b) annotation (Line(
        points={{-228,-130},{-112,-130}},
        color={0,170,238},
        thickness=0.5));
    connect(HX_Propane_IW.portA_b, junction17.portA) annotation (Line(
        points={{-470,-110},{-376,-110},{-232,-110},{-232,-126}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC30.port, junction17.portA) annotation (Line(
        points={{-460,-126},{-442,-126},{-442,-110},{-232,-110},{-232,-126}},
        color={0,170,238},
        thickness=0.5));
    connect(junction15.portC, junction18.portB) annotation (Line(
        points={{-242,-178},{-242,-178},{-236,-178}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_m_flow2.portA, junction18.portA) annotation (Line(
        points={{-267,-226},{-250,-226},{-232,-226},{-232,-182}},
        color={0,170,238},
        thickness=0.5));
    connect(simplePump3.portA, sensor_m_flow2.portB) annotation (Line(
        points={{-560,-156},{-560,-156},{-560,-224},{-560,-226},{-273,-226}},
        color={0,170,238},
        thickness=0.5));
    connect(PI_Pump_IWC.y, Pump_IWC.m_flow_in) annotation (Line(points={{-46.4,
            -166},{-62,-166},{-64,-166}}, color={0,0,127}));
    connect(off_IWPump.y, PI_Pump_IWC.y_notActive) annotation (Line(points={{
            5.3,-183},{5.3,-180},{-40,-180},{-40,-171.8}}, color={0,0,127}));
    connect(switch4.y, hysteresis1.u) annotation (Line(points={{15.4,-156},{
            12.2,-156},{13.2,-156}}, color={0,0,127}));
    connect(IWT_Temp1.y, switch4.u1) annotation (Line(points={{39.1,-149},{32,
            -149},{32,-151.2},{29.2,-151.2}}, color={0,0,127}));
    connect(switch4.u3, IWT_Temp10.y) annotation (Line(points={{29.2,-160.8},{
            35.6,-160.8},{35.6,-161},{39.1,-161}}, color={0,0,127}));
    connect(hysteresis1.y, switch4.u2) annotation (Line(points={{-0.6,-156},{-2,
            -156},{-2,-164},{34,-164},{34,-156},{29.2,-156}}, color={255,0,255}));
    connect(hysteresis1.y, PI_Pump_IWC.activeInput) annotation (Line(points={{
            -0.6,-156},{-14,-156},{-14,-158},{-14,-162.2},{-34.4,-162.2}},
          color={255,0,255}));
    connect(statePoint2.sensorPort, valve8.portB) annotation (Line(
        points={{-456,-90},{-456,-94},{-370,-94}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC9.port, valve8.portB) annotation (Line(
        points={{-424,-90},{-424,-94},{-370,-94}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_m_flow4.portB,HX_Propane_IW. portB_b) annotation (Line(
        points={{-519,-110},{-508,-110},{-498,-110}},
        color={0,170,238},
        thickness=0.5));
    connect(HX_Ammonia_SH.portB_b, sensor_m_flow5.portB) annotation (Line(
        points={{-378,172},{-367,172}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_m_flow5.portA, hydraulicCapacitor3.portA) annotation (Line(
        points={{-361,172},{-328,172},{-328,171.5},{-290,171.5}},
        color={0,170,238},
        thickness=0.5));
    connect(not3.u,hysteresis2. y) annotation (Line(points={{-839.2,18},{-839.2,
            18},{-841.4,18}},          color={255,0,255}));
    connect(RelDispl1.y, PI_CompAmmonia1.u_s) annotation (Line(points={{-725.1,-48},
            {-716,-48},{-705.6,-48}},   color={0,0,127}));
    connect(PI_CompAmmonia1.y, criticalDamping2.u) annotation (Line(points={{-693.6,
            -48},{-688,-48},{-682,-48}},     color={0,0,127}));
    connect(switch2.y,hysteresis2. u)
      annotation (Line(points={{-861.4,18},{-861.4,18},{-855.2,18}},
                                                         color={0,0,127}));
    connect(SHT_Temp.y, switch2.u1) annotation (Line(points={{-887.1,23},{
            -887.1,22.8},{-875.2,22.8}}, color={0,0,127}));
   connect(DHWT_Temp2.y,switch2. u3)
     annotation (Line(points={{-887.1,13},{-887.1,13.2},{-875.2,13.2}},
                                                        color={0,0,127}));
   connect(not3.y,switch2. u2) annotation (Line(points={{-825.4,18},{-814,18},{
            -814,10},{-884,10},{-884,18},{-875.2,18}},
         color={255,0,255}));
    connect(AmmoniaOff.y,switch1. u3) annotation (Line(points={{-749.2,-32},{-734,
            -32},{-734,-12},{-724,-12}}, color={0,0,127}));
    connect(AmmoniaOn.y,switch1. u1) annotation (Line(points={{-747.2,24},{-734,24},
            {-734,4},{-724,4}},          color={0,0,127}));
    connect(criticalDamping2.y, Compressor_propane.relDisplacement_in)
      annotation (Line(points={{-659,-48},{-640,-48},{-640,-12},{-633,-12}},
                                                                         color=
            {0,0,127}));
    connect(PI_ValveProIW.u_m, sensor_superheating6.sensorValue) annotation (
        Line(points={{-390,-69.8},{-390,-69.8},{-390,-80},{-508,-80},{-508,
            -85.8}}, color={0,0,127}));
    connect(PI_Pump_IWC.u_s, sensor_T_degC11.sensorValue) annotation (Line(
          points={{-34.4,-166},{-26,-166},{-26,-118},{-128,-118}}, color={0,0,
            127}));
    connect(PI_Pump_IWC.u_m, Temp_IWC3.y) annotation (Line(points={{-40,-160.2},
            {-42,-160.2},{-42,-136},{-42,-137},{-6.7,-137}}, color={0,0,127}));
    connect(Temp_IWC1.y, PI_Pump_IWC1.u_s) annotation (Line(points={{-515,-154},{-528.4,
            -154}},                     color={0,0,127}));
    connect(PI_ValveIWC.activeInput, on_off_airvalve1.y) annotation (Line(
          points={{-90.4,-82.2},{-81.2,-82.2},{-81.2,-87},{-74.8,-87}}, color={
            255,0,255}));
    connect(boundary2.port,HX_propaneAir. portB_gas) annotation (Line(
        points={{-460,42},{-460,34},{-460,30}},
        color={255,153,0},
        thickness=0.5));
    connect(valve7.portB,HX_propaneAir. portA_vle) annotation (Line(
        points={{-382,16},{-446,16}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_superheating1.port,HX_propaneAir. portB_vle) annotation (
        Line(
        points={{-508,22},{-508,16},{-474,16}},
        color={153,204,0},
        thickness=0.5));
    connect(asupheat3.y, PI_ValveProAirEvap.u_s) annotation (Line(points={{
            -415.5,-12},{-415.5,-14},{-409.6,-14}}, color={0,0,127}));
    connect(junction20.portC, valve8.portA) annotation (Line(
        points={{-304,-50},{-304,-50},{-304,-94},{-304,-94},{-304,-94},{-354,-94}},
        color={153,204,0},
        thickness=0.5));
    connect(junction20.portA, valve7.portA) annotation (Line(
        points={{-304,-42},{-304,16},{-366,16}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_Ammonia_SH.portB_a, junction20.portB) annotation (Line(
        points={{-378,156},{-378,156},{-262,156},{-262,-46},{-300,-46}},
        color={153,204,0},
        thickness=0.5));

    connect(switch1.y, criticalDamping1.u) annotation (Line(points={{-701,-4},{-692,
            -4},{-692,-6},{-686,-6}},          color={0,0,127}));
    connect(rotatoryBoundary4.n_in, criticalDamping1.y) annotation (Line(points={{-652,-6},
            {-663,-6}},                        color={0,0,127}));
    connect(on_off_airvalve4.y, PI_Floor1.activeInput) annotation (Line(points={{-394.8,
            220},{-402,220},{-402,230.2},{-416.4,230.2}},          color={255,0,
            255}));
    connect(asupheat5.y, PI_Floor1.y_notActive) annotation (Line(points={{
            -427.3,254},{-424,254},{-424,239.8},{-422,239.8}}, color={0,0,127}));
    connect(PI_Pump_IWC1.u_m, sensor_T_degC30.sensorValue) annotation (Line(
          points={{-534,-148.2},{-534,-148.2},{-534,-124},{-460,-124},{-460,-120}},
                       color={0,0,127}));
    connect(PI_Pump_IWC1.y_notActive, asupheat4.y) annotation (Line(points={{-534,
            -159.8},{-534,-172},{-535.3,-172}},   color={0,0,127}));
    connect(not2.y, and1.u1) annotation (Line(points={{-535.5,-35},{-535.5,-35},{-529,
            -35}},               color={255,0,255}));
    connect(on_off_airvalve2.y, and1.u2) annotation (Line(points={{-535.3,-49},{-534,
            -49},{-534,-39},{-529,-39}}, color={255,0,255}));
    connect(on_off_airvalve2.y, and2.u1) annotation (Line(points={{-535.3,-49},{-534,
            -49},{-534,-55},{-529,-55}},   color={255,0,255}));
    connect(fileReader.tfr_signals,realVariableName. tfr_signals)
      annotation (Line(points={{194,408},{194,408},{194,394}},
                                                         color={127,0,0}));
    connect(realVariableName.value, OutletDHW2.m_flow_in) annotation (Line(
          points={{182,386},{174,386},{174,372},{166,372}}, color={0,0,127}));
    connect(simpleFan3.portA, boundary3.port) annotation (Line(
        points={{-460,-22},{-460,-30},{-462,-30}},
        color={255,153,0},
        thickness=0.5));
    connect(asupheat6.y, switch5.u1) annotation (Line(points={{-491.5,-9},{-491.5,
            -9},{-490,-9},{-487,-9}},
                                   color={0,0,127}));
    connect(Superheat_realinput4.y, PI_ValveIWC.y_notActive) annotation (Line(
          points={{-70.9,-106},{-70.9,-106},{-96,-106},{-96,-91.8}}, color={0,0,
            127}));
    connect(criticalDamping5.u, PI_ValveIWC.y) annotation (Line(points={{-112.8,
            -86},{-104,-86},{-102.4,-86}},            color={0,0,127}));
    connect(criticalDamping5.y, valve3.effectiveFlowArea_in) annotation (Line(
          points={{-126.6,-86},{-186,-86},{-186,-90},{-186,-109}},
          color={0,0,127}));
    connect(realVariableSC.value, InletFloor3.m_flow_in) annotation (Line(
          points={{-304,-128},{-284,-128}},             color={0,0,127}));
    connect(switch6.y,hysteresis3. u) annotation (Line(points={{-861.4,-12},{
            -868,-12},{-853.2,-12}}, color={0,0,127}));
    connect(idealSeparator3.portGas, Compressor_parallell.portA) annotation (
        Line(
        points={{157,-500},{226,-500},{226,-472}},
        color={153,204,0},
        thickness=0.5));
    connect(idealSeparator3.portInlet, HX_Air.portB_vle) annotation (Line(
        points={{147,-500},{46,-500}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_superheating4.port, HX_Air.portB_vle) annotation (Line(
        points={{78,-494},{80,-494},{80,-500},{46,-500}},
        color={153,204,0},
        thickness=0.5));
    connect(asupheat8.y,switch7. u1) annotation (Line(points={{-81.3,-558},{-72,
            -558},{-64,-558}},     color={0,0,127}));
    connect(boundaryOverdetermined1.port, simpleFan4.portA) annotation (Line(
        points={{-34,-530},{-16,-530}},
        color={255,153,0},
        thickness=0.5));
    connect(simpleFan4.portB, HX_Air.portA_gas) annotation (Line(
        points={{0,-530},{32,-530},{32,-514}},
        color={255,153,0},
        thickness=0.5));
    connect(switch7.y, simpleFan4.V_flow_in) annotation (Line(points={{-41,-566},
            {-28,-566},{-8,-566},{-8,-540}}, color={0,0,127}));
    connect(asupheat9.y, switch7.u3) annotation (Line(points={{-81.3,-574},{
            -72.65,-574},{-64,-574}}, color={0,0,127}));
    connect(on_off_airvalve3.y, switch7.u2) annotation (Line(points={{-103,-566},
            {-98,-566},{-64,-566}}, color={255,0,255}));
    connect(fileReader2.tfr_signals, realVariableSC1.tfr_signals) annotation (
        Line(points={{-374,268},{-368,268},{-368,282},{-358,282},{-358,272}},
          color={127,0,0}));
    connect(realVariableSC1.value, InletFloor1.m_flow_in) annotation (Line(
          points={{-346,264},{-340,264},{-336,264}}, color={0,0,127}));
    connect(switch9.u2, not1.y) annotation (Line(points={{-2.8,-256},{-4,-256},
            {-4,-234},{-36.8,-234},{-36.8,-220}},  color={255,0,255}));
    connect(switch9.u3, off_IWPump1.y) annotation (Line(points={{-2.8,-260.8},{
            -2.4,-260.8},{-2.4,-261},{5.3,-261}},     color={0,0,127}));
    connect(switch9.u1, off_IWPump2.y) annotation (Line(points={{-2.8,-251.2},{
            -1.4,-251.2},{-1.4,-251},{5.3,-251}},     color={0,0,127}));
    connect(off_value_GW5.y, PI_CompParallell.u_s) annotation (Line(points={{155,
            -454},{164,-454},{164,-464},{172.4,-464}},     color={0,0,127}));
    connect(Bypass_Pressure5.y, PI_CompParallell.u_m) annotation (Line(points={{155,
            -484},{168,-484},{168,-482},{178,-482},{178,-469.8}},      color={0,
            0,127}));
    connect(pressureState5.portA, HX_Air.portA_vle) annotation (Line(
        points={{-10,-500},{4,-500},{18,-500}},
        color={153,204,0},
        thickness=0.5));
    connect(pressureState5.portB, valve6.portB) annotation (Line(
        points={{-22,-500},{-46,-500},{-46,-500}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_ValveIWC.u_m, sensor_q4.sensorValue) annotation (Line(points={{
            -96,-80.2},{-96,-72},{-22,-72},{-22,-103.8}}, color={0,0,127}));
    connect(not5.u, hysteresis5.y) annotation (Line(points={{123.6,-422},{123.6,
            -422},{129.2,-422}}, color={255,0,255}));
    connect(not5.y, PI_ValveAir.activeInput) annotation (Line(points={{105.2,
            -422},{76,-422},{76,-452},{33.6,-452},{33.6,-449.8}}, color={255,0,
            255}));
    connect(not5.y, PI_CompParallell.activeInput) annotation (Line(points={{105.2,
            -422},{100,-422},{100,-462},{100,-467.8},{172.4,-467.8}},
          color={255,0,255}));
    connect(PI_LP_Comp.y, Compressor_LT.relDisplacement_in)
      annotation (Line(points={{94.4,-342},{109,-342}},color={0,0,127}));
    connect(PI_LP_Comp.u_m, sensor_p3.sensorValue)
      annotation (Line(points={{88,-347.8},{88,-367.8}}, color={0,0,127}));
    connect(boundaryUnderdetermined.port, GreyWater_HX.portB_liq) annotation (
        Line(
        points={{-160,-258},{-118,-258}},
        color={0,170,238},
        thickness=0.5));
    connect(GreyWater_HX.portA_liq, boundaryOverdetermined.port) annotation (Line(
        points={{-90,-258},{-70,-258},{-50,-258}},
        color={0,170,238},
        thickness=0.5));
    connect(valve4.portB, GreyWater_HX.portA_vle) annotation (Line(
        points={{-176,-244},{-111.778,-244}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_CompParallell.y, Compressor_parallell.relDisplacement_in)
      annotation (Line(points={{184.4,-464},{200,-464},{200,-470},{215,-470}},
          color={0,0,127}));
    connect(PI_Comp.y, Compressor_MT.relDisplacement_in) annotation (Line(points={
            {148.4,46},{150,46},{175,46},{175,56}}, color={0,0,127}));
    connect(sensor_p2.sensorValue, PI_Comp.u_m)
      annotation (Line(points={{142,34.2},{142,40.2}}, color={0,0,127}));
    connect(sensor_m_flow1.portA, junction18.portC) annotation (Line(
        points={{-197,-178},{-212,-178},{-228,-178}},
        color={0,170,238},
        thickness=0.5));
    connect(hydraulicCapacitor2.portA, sensor_m_flow1.portB) annotation (Line(
        points={{-146,-178.5},{-168,-178.5},{-168,-178},{-191,-178}},
        color={0,170,238},
        thickness=0.5));
    connect(hydraulicCapacitor2.portB, Pump_IWC.portA) annotation (Line(
        points={{-140,-178.5},{-74,-178.5},{-74,-168}},
        color={0,170,238},
        thickness=0.5));
    connect(tank_IW.portB, junction8.portA) annotation (Line(
        points={{-246,-140},{-246,-140},{-246,-134}},
        color={0,170,238},
        thickness=0.5));
    connect(criticalDamping6.u, PI_Valve_GreyWater.y)
      annotation (Line(points={{-96.8,-216},{-84.4,-216}}, color={0,0,127}));
    connect(criticalDamping6.y, valve4.effectiveFlowArea_in) annotation (Line(
          points={{-110.6,-216},{-146,-216},{-184,-216},{-184,-239}}, color={0,
            0,127}));
    connect(criticalDamping7.u, switch9.y)
      annotation (Line(points={{-24.8,-256},{-16.6,-256}}, color={0,0,127}));
    connect(criticalDamping7.y, boundaryOverdetermined.m_flow_in) annotation (
        Line(points={{-38.6,-256},{-38.6,-256},{-46,-256}}, color={0,0,127}));
    connect(junction1.portA, idealSeparator1.portInlet) annotation (Line(
        points={{124,-4},{124,-4},{139,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(junction1.portC, junction4.portA) annotation (Line(
        points={{116,-4},{116,-4},{94,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(GreyWater_HX.portB_vle, junction6.portA) annotation (Line(
        points={{-96.2222,-272},{-70,-272},{-70,-242},{84,-242},{84,-118},{90,
            -118}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_superheating2.port, GreyWater_HX.portB_vle) annotation (Line(
        points={{-78,-236},{-70,-236},{-70,-272},{-96.2222,-272}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_Valve_GreyWater.u_m, sensor_superheating2.sensorValue)
      annotation (Line(points={{-78,-221.8},{-78,-221.8},{-78,-229.8}}, color={
            0,0,127}));
    connect(simplePump3.portB, sensor_m_flow4.portA) annotation (Line(
        points={{-560,-140},{-560,-140},{-560,-110},{-525,-110}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC5.port, junction13.portB) annotation (Line(
        points={{-200,270},{-200,262},{-266,262}},
        color={0,170,238},
        thickness=0.5));
    connect(HX2.portA_b, junction13.portB) annotation (Line(
        points={{-22,156},{-4,156},{-4,158},{14,158},{14,262},{-266,262}},
        color={0,170,238},
        thickness=0.5));
    connect(not4.u,hysteresis4. y) annotation (Line(points={{-94.4,236},{-94.4,
            236},{-88.8,236}},         color={255,0,255}));
    connect(switch8.y,hysteresis4. u) annotation (Line(points={{-63,234},{-66,
            234},{-66,236},{-70.4,236}}, color={0,0,127}));
    connect(not4.y,switch8. u2) annotation (Line(points={{-112.8,236},{-114,236},
            {-114,260},{-32,260},{-32,234},{-40,234}}, color={255,0,255}));
    connect(PI_Floor.activeInput, not4.y) annotation (Line(points={{-218.4,
            243.8},{-196,243.8},{-196,252},{-112.8,252},{-112.8,236}}, color={
            255,0,255}));
    connect(floorHeatingSetpoint2.y, PI_Floor.y_notActive) annotation (Line(
          points={{-207,224},{-216,224},{-224,224},{-224,234.2}}, color={0,0,
            127}));
    connect(tube.portA, simplePump1.portB) annotation (Line(
        points={{-152,208},{-222,208}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC4.port, simplePump1.portB) annotation (Line(
        points={{-178,210},{-178,210},{-178,208},{-222,208}},
        color={0,170,238},
        thickness=0.5));
    connect(tube.portB, HX2.portB_b) annotation (Line(
        points={{-136,208},{-68,208},{-68,156},{-50,156}},
        color={0,170,238},
        thickness=0.5));
    connect(switch8.u3, DHWT_Temp4.y) annotation (Line(points={{-40,226},{-28.9,226}},
                               color={0,0,127}));
    connect(switch8.u1, DHWT_Temp3.y) annotation (Line(points={{-40,242},{-26.9,242}},
                               color={0,0,127}));
    connect(tube1.heatPort, tube.heatPort) annotation (Line(
        points={{122,-168},{236,-168},{326,-168},{326,218},{-144,218},{-144,210}},
        color={204,0,0},
        thickness=0.5));

    connect(tube1.portA, junction1.portB) annotation (Line(
        points={{120,-160},{120,-8}},
        color={153,204,0},
        thickness=0.5));
    connect(Compressor_LT.portB, tube1.portB) annotation (Line(
        points={{120,-328},{120,-328},{120,-176}},
        color={153,204,0},
        thickness=0.5));
    connect(IWT_Temp2.y, switch6.u1) annotation (Line(points={{-889.1,-7},{
            -889.55,-7},{-889.55,-7.2},{-875.2,-7.2}}, color={0,0,127}));
    connect(IWT_Temp3.y, switch6.u3) annotation (Line(points={{-889.1,-17},{
            -875.2,-17},{-875.2,-16.8}},
                                       color={0,0,127}));
    connect(hysteresis3.y, switch6.u2) annotation (Line(points={{-839.4,-12},{
            -834,-12},{-834,-22},{-882,-22},{-882,-12},{-875.2,-12}},
                                                                 color={255,0,
            255}));
    connect(on_off_propane_valves1.y, PI_Pump_IWC1.activeInput) annotation (
        Line(points={{-510.8,-142},{-520,-142},{-520,-150.2},{-528.4,-150.2}},
          color={255,0,255}));
    connect(HX_propaneDump.portB_vle, HX_Ammonia_SH.portA_a) annotation (Line(
        points={{-504,158},{-504,156},{-406,156}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_propaneDump.portA_vle, sensor_m_flow13.portB) annotation (Line(
        points={{-532,158},{-558,158},{-558,156},{-583,156}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC2.port, sensor_m_flow13.portB) annotation (Line(
        points={{-566,160},{-566,156},{-583,156}},
        color={153,204,0},
        thickness=0.5));
    connect(statePoint.sensorPort, sensor_m_flow13.portB) annotation (Line(
        points={{-548,160},{-548,156},{-583,156}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_propaneDump.portB_gas, boundary4.port) annotation (Line(
        points={{-518,144},{-518,118}},
        color={255,153,0},
        thickness=0.5));
    connect(simpleFan5.portB,HX_propaneDump. portA_gas) annotation (Line(
        points={{-536,200},{-518,200},{-518,172}},
        color={255,153,0},
        thickness=0.5));
    connect(asupheat10.y, switch10.u1)
      annotation (Line(points={{-635.3,226},{-630,226}}, color={0,0,127}));
    connect(asupheat11.y, switch10.u3) annotation (Line(points={{-635.3,210},{-635.3,
            210},{-630,210}},        color={0,0,127}));
    connect(on_off_propane_valves2.y, and3.u1) annotation (Line(points={{-679.2,222},
            {-672,222},{-672,218},{-669.2,218}},      color={255,0,255}));
    connect(on_off_propane_valves3.y, and3.u2) annotation (Line(points={{-679.2,212},
            {-672,212},{-672,213.2},{-669.2,213.2}},      color={255,0,255}));
    connect(boundary5.port, simpleFan5.portA) annotation (Line(
        points={{-574,200},{-564,200},{-552,200}},
        color={255,153,0},
        thickness=0.5));
    connect(switch10.y, criticalDamping8.u) annotation (Line(points={{-607,218},{-602.5,
            218},{-598,218}}, color={0,0,127}));
    connect(criticalDamping8.y, simpleFan5.V_flow_in) annotation (Line(points={{-575,
            218},{-544,218},{-544,210}}, color={0,0,127}));
    connect(fileReader1.tfr_signals, realVariableSC.tfr_signals) annotation (Line(
          points={{-316,-146},{-316,-141},{-316,-136}}, color={127,0,0}));
    connect(junction19.portC, sensor_superheating6.port) annotation (Line(
        points={{-590,-50},{-590,-94},{-508,-94},{-508,-92},{-508,-92}},
        color={153,204,0},
        thickness=0.5));
    connect(junction19.portA, HX_propaneAir.portB_vle) annotation (Line(
        points={{-590,-42},{-590,16},{-474,16}},
        color={153,204,0},
        thickness=0.5));
    connect(junction19.portB, pressureState7.portB) annotation (Line(
        points={{-594,-46},{-622,-46},{-622,-34}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_ValveProAirEvap.u_m, sensor_superheating1.sensorValue)
      annotation (Line(points={{-404,-8.2},{-404,-8.2},{-404,32},{-508,32},{
            -508,28.2}}, color={0,0,127}));
    connect(simpleFan3.portB, HX_propaneAir.portA_gas) annotation (Line(
        points={{-460,-6},{-460,-2},{-460,2}},
        color={255,153,0},
        thickness=0.5));
    connect(switch5.y, simpleFan3.V_flow_in) annotation (Line(points={{-475.5,
            -13},{-475.5,-14},{-470,-14}},
                                      color={0,0,127}));
    connect(asupheat7.y, switch5.u3) annotation (Line(points={{-491.5,-17},{-491.5,
            -17},{-487,-17}}, color={0,0,127}));
    connect(and1.y, switch5.u2) annotation (Line(points={{-517.5,-35},{-512,-35},{
            -490,-35},{-490,-13},{-487,-13}}, color={255,0,255}));
    connect(and1.y, PI_ValveProAirEvap.activeInput) annotation (Line(points={{
            -517.5,-35},{-414,-35},{-414,-10.2},{-409.6,-10.2}}, color={255,0,
            255}));
    connect(not2.u, on_off_propane_valves.y) annotation (Line(points={{-547,-35},{
            -557.4,-35},{-557.4,-48}}, color={255,0,255}));
    connect(on_off_propane_valves.y, and2.u2) annotation (Line(points={{-557.4,-48},
            {-558,-48},{-558,-58},{-558,-59},{-529,-59}}, color={255,0,255}));
    connect(and2.y, PI_ValveProIW.activeInput) annotation (Line(points={{-517.5,
            -55},{-416,-55},{-416,-67.8},{-395.6,-67.8}}, color={255,0,255}));
    connect(statePoint3.sensorPort, junction20.portB) annotation (Line(
        points={{-328,160},{-328,156},{-262,156},{-262,-46},{-300,-46}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC23.port, junction20.portB) annotation (Line(
        points={{-346,160},{-346,156},{-262,156},{-262,-46},{-300,-46}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC12.port, junction20.portB) annotation (Line(
        points={{-306,160},{-306,156},{-262,156},{-262,-46},{-300,-46}},
        color={153,204,0},
        thickness=0.5));
    connect(asupheat1.y, switch11.u1) annotation (Line(points={{-457.5,-43},{-457.5,
            -43},{-451,-43}}, color={0,0,127}));
    connect(asupheat2.y, switch11.u3)
      annotation (Line(points={{-457.5,-51},{-451,-51}}, color={0,0,127}));
    connect(switch11.y, PI_ValveProAirEvap.y_notActive) annotation (Line(points
          ={{-439.5,-47},{-404,-47},{-404,-19.8}}, color={0,0,127}));
    connect(switch11.y, PI_ValveProIW.y_notActive) annotation (Line(points={{
            -439.5,-47},{-390,-47},{-390,-58.2}}, color={0,0,127}));
    connect(on_off_airvalve2.y, switch11.u2) annotation (Line(points={{-535.3,-49},
            {-534,-49},{-534,-46},{-451,-46},{-451,-47}}, color={255,0,255}));
    connect(and3.y, switch10.u2) annotation (Line(points={{-655.4,218},{-630,218}},
                         color={255,0,255}));
    connect(not3.y, PI_CompAmmonia1.activeInput) annotation (Line(points={{-825.4,
            18},{-820,18},{-814,18},{-814,-51.8},{-705.6,-51.8}}, color={255,0,255}));
    connect(RelDispl2.y, PI_CompAmmonia1.y_notActive) annotation (Line(points={{-705.1,
            -34},{-700,-34},{-700,-42.2}}, color={0,0,127}));
    connect(sensor_p5.port, pressureState6.portA) annotation (Line(
        points={{-610,166},{-610,156},{-622,156},{-622,20}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_p6.port, pressureState7.portB) annotation (Line(
        points={{-602,-40},{-604,-40},{-604,-46},{-622,-46},{-622,-34}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC13.port, OutletDHW2.port) annotation (Line(
        points={{138,376},{138,376},{138,370},{162,370}},
        color={0,170,238},
        thickness=0.5));
    connect(or2.y, switch1.u2)
      annotation (Line(points={{-745,-4},{-724,-4}}, color={255,0,255}));
    connect(not3.y, or2.u1) annotation (Line(points={{-825.4,18},{-804,18},{
            -768,18},{-768,-4}}, color={255,0,255}));
    connect(hysteresis3.y, or2.u2) annotation (Line(points={{-839.4,-12},{-804,
            -12},{-768,-12}}, color={255,0,255}));
    connect(switch12.y, hysteresis5.u) annotation (Line(points={{153.4,-420},{
            150,-420},{150,-422},{147.6,-422}}, color={0,0,127}));
    connect(DHWT_Temp6.y, switch12.u1) annotation (Line(points={{175.1,-414},{
            167.2,-414},{167.2,-415.2}}, color={0,0,127}));
    connect(DHWT_Temp5.y, switch12.u3) annotation (Line(points={{177.1,-426},{
            170,-426},{170,-424.8},{167.2,-424.8}}, color={0,0,127}));
    connect(not5.y, switch12.u2) annotation (Line(points={{105.2,-422},{100,
            -422},{100,-436},{172,-436},{172,-420},{167.2,-420}}, color={255,0,
            255}));
    connect(sensor_H_flow1.sensorValue, add_GasCooler.u2) annotation (Line(points=
           {{-156,139},{-82,139},{-82,115.2},{-7.6,115.2}}, color={0,0,127}));
    connect(add_GasCooler.u1, sensor_H_flow.sensorValue) annotation (Line(points={
            {-0.4,115.2},{44.8,115.2},{44.8,139},{90,139}}, color={0,0,127}));
    connect(comControl.y1, PI_CompAmmonia1.u_m) annotation (Line(points={{
            -716.7,-79.5},{-700,-79.5},{-700,-53.8}}, color={0,0,127}));
    connect(criticalDamping3.u, PI_ValveProIW.y) annotation (Line(points={{
            -370.8,-66},{-376,-66},{-376,-64},{-383.6,-64}}, color={0,0,127}));
    connect(criticalDamping4.u, PI_ValveProAirEvap.y) annotation (Line(points={
            {-384.8,-16},{-392,-16},{-392,-14},{-397.6,-14}}, color={0,0,127}));
    connect(criticalDamping4.y, valve7.effectiveFlowArea_in) annotation (Line(
          points={{-375.6,-16},{-374,-16},{-374,11}}, color={0,0,127}));
    connect(criticalDamping3.y, valve8.effectiveFlowArea_in) annotation (Line(
          points={{-361.6,-66},{-362,-66},{-362,-89}}, color={0,0,127}));
    annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-920,
              -460},{280,480}})), Diagram(coordinateSystem(preserveAspectRatio=false,
                     extent={{-920,-460},{280,480}}), graphics={Text(
            extent={{-220,-176},{-236,-168}},
            lineColor={0,0,0},
            textString="IWT Top"), Text(
            extent={{-208,-148},{-236,-136}},
            lineColor={0,0,0},
            textString="IWT Bottom
          ")}));
  end Autumn_run;

  model Winter_run
    output Real COP_total_CO2=(tube.summary.Q_flow_liq+GC1_Q+GC2_Q+GC3_Q+HX_CO2_IW_Q+HX_RefRoom_Q+HX_Freezer_Q-HX_DHWdump_Q)/(Comp_MT_W+Comp_LT_W+Com_Parll_W);
    output Real COP_h_CO2=(tube.summary.Q_flow_liq+GC1_Q+GC2_Q+GC3_Q-HX_DHWdump_Q)/(Comp_MT_W+Comp_LT_W+Com_Parll_W);
    output Real COP_c_CO2=(HX_CO2_IW_Q+HX_RefRoom_Q+HX_Freezer_Q)/(Comp_MT_W+Comp_LT_W+Com_Parll_W);
    output Real COP_h_Prop=(HX_ProSH/Comp_Pro_W);
    output Real COP_c_Prop=(HX_ProIW/Comp_Pro_W);
    output Real Q_SH_Demand=(InletFloor1.summary.h-InletFloor2.summary.h)*InletFloor1.m_flow_in;

    output Real T_GC_CO2out=sensor_T_degC3.sensorValue;
    output Real q_HP_valve_CO2=sensor_q3.sensorValue;
    output Real p_HP_Prop=sensor_p5.sensorValue;
    output Real p_LP_Prop=sensor_p6.sensorValue;
    output Real T_IW_consumer=sensor_T_degC10.sensorValue;
    output Real T_SH_consumer=sensor_T_degC15.sensorValue;
    output Real T_DHW_consumer=sensor_T_degC13.sensorValue;

    output Real Comp_MT_W;
    output Real Comp_MT_reldisp;
    output Real Comp_LT_W;
    output Real Comp_LT_reldisp;
    output Real Com_Parll_reldisp;
    output Real Com_Parll_W;
    output Real Comp_Pro_W;
    output Real Comp_Pro_reldisp;

    output Real Prop_HP_ON=Compressor_propane.n;

    output Real GC1_Q;
    output Real GC2_Q;
    output Real GC3_Q;
    output Real GC_total=add_GasCooler.y;
    output Real HX_GW_Q;
    output Real HX_CO2_IW_Q;
    output Real HX_DHWdump_Q;
    output Real HX_RefRoom_Q;
    output Real HX_Freezer_Q;
    output Real HX_CO2air;
    output Real HX_ProSH;
    output Real HX_ProIW;
    output Real HX_ProAir;

    output Real tankSH_1=tank_SH.summary.arrays.T_degC_liq_cell[1];
    output Real tankSH_2=tank_SH.summary.arrays.T_degC_liq_cell[2];
    output Real tankSH_3=tank_SH.summary.arrays.T_degC_liq_cell[3];
    output Real tankSH_4=tank_SH.summary.arrays.T_degC_liq_cell[4];
    output Real tankSH_5=tank_SH.summary.arrays.T_degC_liq_cell[5];
    output Real tankSH_6=tank_SH.summary.arrays.T_degC_liq_cell[6];
    output Real tankSH_7=tank_SH.summary.arrays.T_degC_liq_cell[7];
    output Real tankSH_8=tank_SH.summary.arrays.T_degC_liq_cell[8];
    output Real tankSH_9=tank_SH.summary.arrays.T_degC_liq_cell[9];
    output Real tankSH_10=tank_SH.summary.arrays.T_degC_liq_cell[10];
    output Real tankSH_11=tank_SH.summary.arrays.T_degC_liq_cell[11];
    output Real tankSH_12=tank_SH.summary.arrays.T_degC_liq_cell[12];
    output Real tankSH_13=tank_SH.summary.arrays.T_degC_liq_cell[13];
    output Real tankSH_14=tank_SH.summary.arrays.T_degC_liq_cell[14];
    output Real tankSH_15=tank_SH.summary.arrays.T_degC_liq_cell[15];
    output Real tankSH_16=tank_SH.summary.arrays.T_degC_liq_cell[16];
    output Real tankSH_17=tank_SH.summary.arrays.T_degC_liq_cell[17];
    output Real tankSH_18=tank_SH.summary.arrays.T_degC_liq_cell[18];
    output Real tankSH_19=tank_SH.summary.arrays.T_degC_liq_cell[19];
    output Real tankSH_20=tank_SH.summary.arrays.T_degC_liq_cell[20];

    output Real tankIW_1=tank_IW.summary.arrays.T_degC_liq_cell[1];
    output Real tankIW_2=tank_IW.summary.arrays.T_degC_liq_cell[2];
    output Real tankIW_3=tank_IW.summary.arrays.T_degC_liq_cell[3];
    output Real tankIW_4=tank_IW.summary.arrays.T_degC_liq_cell[4];
    output Real tankIW_5=tank_IW.summary.arrays.T_degC_liq_cell[5];
    output Real tankIW_6=tank_IW.summary.arrays.T_degC_liq_cell[6];
    output Real tankIW_7=tank_IW.summary.arrays.T_degC_liq_cell[7];
    output Real tankIW_8=tank_IW.summary.arrays.T_degC_liq_cell[8];
    output Real tankIW_9=tank_IW.summary.arrays.T_degC_liq_cell[9];
    output Real tankIW_10=tank_IW.summary.arrays.T_degC_liq_cell[10];
    output Real tankIW_11=tank_IW.summary.arrays.T_degC_liq_cell[11];
    output Real tankIW_12=tank_IW.summary.arrays.T_degC_liq_cell[12];
    output Real tankIW_13=tank_IW.summary.arrays.T_degC_liq_cell[13];
    output Real tankIW_14=tank_IW.summary.arrays.T_degC_liq_cell[14];
    output Real tankIW_15=tank_IW.summary.arrays.T_degC_liq_cell[15];
    output Real tankIW_16=tank_IW.summary.arrays.T_degC_liq_cell[16];
    output Real tankIW_17=tank_IW.summary.arrays.T_degC_liq_cell[17];
    output Real tankIW_18=tank_IW.summary.arrays.T_degC_liq_cell[18];
    output Real tankIW_19=tank_IW.summary.arrays.T_degC_liq_cell[19];
    output Real tankIW_20=tank_IW.summary.arrays.T_degC_liq_cell[20];

    output Real tankDHW_1=tank_DHW.summary.arrays.T_degC_liq_cell[1];
    output Real tankDHW_2=tank_DHW.summary.arrays.T_degC_liq_cell[2];
    output Real tankDHW_3=tank_DHW.summary.arrays.T_degC_liq_cell[3];
    output Real tankDHW_4=tank_DHW.summary.arrays.T_degC_liq_cell[4];
    output Real tankDHW_5=tank_DHW.summary.arrays.T_degC_liq_cell[5];
    output Real tankDHW_6=tank_DHW.summary.arrays.T_degC_liq_cell[6];
    output Real tankDHW_7=tank_DHW.summary.arrays.T_degC_liq_cell[7];
    output Real tankDHW_8=tank_DHW.summary.arrays.T_degC_liq_cell[8];
    output Real tankDHW_9=tank_DHW.summary.arrays.T_degC_liq_cell[9];
    output Real tankDHW_10=tank_DHW.summary.arrays.T_degC_liq_cell[10];
    output Real tankDHW_11=tank_DHW.summary.arrays.T_degC_liq_cell[11];
    output Real tankDHW_12=tank_DHW.summary.arrays.T_degC_liq_cell[12];
    output Real tankDHW_13=tank_DHW.summary.arrays.T_degC_liq_cell[13];
    output Real tankDHW_14=tank_DHW.summary.arrays.T_degC_liq_cell[14];
    output Real tankDHW_15=tank_DHW.summary.arrays.T_degC_liq_cell[15];
    output Real tankDHW_16=tank_DHW.summary.arrays.T_degC_liq_cell[16];
    output Real tankDHW_17=tank_DHW.summary.arrays.T_degC_liq_cell[17];
    output Real tankDHW_18=tank_DHW.summary.arrays.T_degC_liq_cell[18];
    output Real tankDHW_19=tank_DHW.summary.arrays.T_degC_liq_cell[19];
    output Real tankDHW_20=tank_DHW.summary.arrays.T_degC_liq_cell[20];

    inner TIL.SystemInformationManager sim(redeclare
        TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
      redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
      redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType2,
      redeclare TILMedia.GasTypes.TILMedia_MoistAir gasType2,
      redeclare MB_Finished.Refprop_Propane
                                vleFluidType2,
      redeclare TILMedia.GasTypes.TILMedia_MoistAir gasType1,
      removeSingularity=true)
      annotation (Placement(transformation(extent={{186,276},{206,296}})));

    TIL.LiquidComponents.Pumps.SimplePump simplePump(
      presetVariableType="m_flow",
      use_volumeFlowRateInput=false,
      m_flowFixed=0.3,
      use_massFlowRateInput=true)
                annotation (Placement(transformation(
          extent={{-8,-8},{8,8}},
          rotation=180,
          origin={-164,338})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC
      annotation (Placement(transformation(extent={{-150,390},{-142,398}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC1
      annotation (Placement(transformation(extent={{68,272},{76,280}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC3
      annotation (Placement(transformation(extent={{-194,146},{-186,154}})));

    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState(pInitial=
          10000000)
      annotation (Placement(transformation(extent={{156,136},{168,148}})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
      annotation (Placement(transformation(extent={{128,146},{136,154}})));
    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX       HX2(
      pressureStateID=1,
      initVLEFluid_a="linearEnthalpyDistribution",
      initHeatTransfer_a="alpha",
      m_flowStart_b=PI_Floor.yInitial,
      pStart_a=pressureState.pInitial,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.Plate.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare TIL.HeatExchangers.Plate.Geometry.PlateGeometry hxGeometry(
        length=0.6,
        width=0.2,
        phi=30,
        wallThickness=0.0009,
        patternAmplitude=0.0011,
        patternWaveLength=12.6e-3,
        numberOfPlates=300),
      initLiquid_b="linearTemperatureDistribution",
      m_flowStart_a=0.2,
      hInitialVLEFluid_a_CellN=260e3,
      hInitialVLEFluid_a_Cell1=354e3,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      nCells=3,
      TInitialVLEFluid_a=278.15,
      TInitialLiquid_b=313.15,
      TInitialLiquid_b_Cell1=308.15,
      TInitialLiquid_b_CellN=298.15)
      annotation (Placement(transformation(extent={{-22,136},{-50,164}})));

    TIL.LiquidComponents.Pumps.SimplePump simplePump1(
      presetVariableType="m_flow",
      use_massFlowRateInput=true,
      use_volumeFlowRateInput=false)
                annotation (Placement(transformation(
          extent={{-8,-8},{8,8}},
          rotation=270,
          origin={-230,208})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC4
      annotation (Placement(transformation(extent={{-182,210},{-174,218}})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint(y=35)
      annotation (Placement(transformation(extent={{-166,228},{-186,248}})));
    TIL.OtherComponents.Controllers.PIController PI_Floor(
      controllerType="PI",
      invertFeedback=true,
      yMax=10,
      initType="initialOutput",
      yInitial=0.47,
      Ti=0.1,
      k=1e-1,
      use_activeInput=true,
      use_y_notActive=true,
      yMin=1e-7)
      annotation (Placement(transformation(extent={{-218,246},{-230,234}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC5(
        initialSensorValue=40, useTimeConstant=false)
      annotation (Placement(transformation(extent={{-204,270},{-196,278}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC6
      annotation (Placement(transformation(extent={{-94,146},{-86,154}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC7
      annotation (Placement(transformation(extent={{10,146},{18,154}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC8
      annotation (Placement(transformation(extent={{36,162},{44,170}})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve(
        use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=-90,
          origin={-216,104})));

    TIL.OtherComponents.Controllers.PIController PI_HPValve(
      controllerType="PI",
      invertFeedback=true,
      Ti=0.01,
      yMax=1e-2,
      yMin=1e-12,
      yInitial=2e-6,
      k=1e-10)
      annotation (Placement(transformation(extent={{-186,110},{-198,98}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p(
      tau=1,
      useTimeConstant=false,
      initialSensorValue=10000000)                   annotation (Placement(
          transformation(
          extent={{-4,-4},{4,4}},
          rotation=-90,
          origin={-198,128})));
    Modelica.Blocks.Sources.RealExpression HighPressure(y=100e5)
      annotation (Placement(transformation(extent={{-150,94},{-170,114}})));
    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX       HX3(
      pressureStateID=1,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      initVLEFluid_a="linearEnthalpyDistribution",
      initHeatTransfer_a="alpha",
      alphaInitial_a=1900,
      m_flowStart_b=PI_DHW.yInitial,
      pStart_a=pressureState.pInitial,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        length=0.6,
        width=0.2,
        wallThickness=0.0009,
        patternAmplitude=0.0011,
        numberOfPlates=300,
        phi=30),
      initLiquid_b="linearTemperatureDistribution",
      m_flowStart_a=0.2,
      hInitialVLEFluid_a_Cell1=260e3,
      hInitialVLEFluid_a_CellN=227e3,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.Plate.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      nCells=3,
      TInitialVLEFluid_a=303.15,
      TInitialLiquid_b=328.15,
      TInitialLiquid_b_Cell1=296.15,
      TInitialLiquid_b_CellN=283.15)
      annotation (Placement(transformation(extent={{-112,136},{-140,164}})));

    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX       HX1(
      pressureStateID=1,
      initVLEFluid_a="linearEnthalpyDistribution",
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      initHeatTransfer_a="alpha",
      alphaInitial_a=1900,
      m_flowStart_b=PI_DHW.yInitial,
      pStart_a=pressureState.pInitial,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        length=0.6,
        width=0.2,
        wallThickness=0.0009,
        patternAmplitude=0.0011,
        numberOfPlates=300,
        phi=30),
      initLiquid_b="linearTemperatureDistribution",
      hInitialVLEFluid_a_Cell1=494e3,
      hInitialVLEFluid_a_CellN=360e3,
      m_flowStart_a=0.20,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.Plate.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      nCells=3,
      TInitialVLEFluid_a=551.3,
      TInitialLiquid_b=621.3,
      TInitialLiquid_b_Cell1=343.15,
      TInitialLiquid_b_CellN=296.15)
      annotation (Placement(transformation(extent={{76,136},{48,164}})));

    TIL.VLEFluidComponents.Sensors.Sensor_H_flow sensor_H_flow
      annotation (Placement(transformation(extent={{94,146},{86,138}})));
    TIL.VLEFluidComponents.Sensors.Sensor_H_flow sensor_H_flow1
      annotation (Placement(transformation(extent={{-152,146},{-160,138}})));
    Modelica.Blocks.Math.Add add_GasCooler(k2=-1) annotation (Placement(
          transformation(
          extent={{-6,-6},{6,6}},
          rotation=-90,
          origin={56,110})));

    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState1(
        pressureStateID=3, pInitial=3400000)
      annotation (Placement(transformation(extent={{36,-10},{48,2}})));
    TIL.VLEFluidComponents.Sensors.Sensor_q sensor_q
      annotation (Placement(transformation(extent={{2,0},{10,8}})));
    TIL.VLEFluidComponents.Separators.IdealSeparator idealSeparator(
        pressureStateID=2,
      hStart=233e3,
      mixingRatioInitial={0.1},
      V=1,
      initialFillingLevel=0.5,
      mdotStart=0.1)
      annotation (Placement(transformation(extent={{-212,36},{-200,56}})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve1(
        use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=0,
          origin={-186,-4})));
    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState2(
        pressureStateID=2, pInitial=4000000)
      annotation (Placement(transformation(extent={{-6,-6},{6,6}},
          rotation=-90,
          origin={-216,74})));
    TIL.OtherComponents.Controllers.PIController PI_ValveCooling(
      controllerType="PI",
      invertFeedback=true,
      yMin=1e-9,
      yMax=1e-5,
      initType="initialOutput",
      k=1e-10,
      yInitial=7.08e-7,
      Ti=0.1) annotation (Placement(transformation(extent={{-56,28},{-68,40}})));
    Modelica.Blocks.Sources.RealExpression Superheat_realinput(y=0.85)
      annotation (Placement(transformation(extent={{-16,24},{-36,44}})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve2(
        use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=0,
          origin={-142,52})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p1
      annotation (Placement(transformation(extent={{-172,56},{-164,64}})));
    TIL.OtherComponents.Controllers.PIController PI_bypass(
      controllerType="PI",
      invertFeedback=true,
      yInitial=1e-7,
      yMax=1e-3,
      k=1e-7,
      Ti=10,
      yMin=0)
      annotation (Placement(transformation(extent={{-150,72},{-138,84}})));
    Modelica.Blocks.Sources.RealExpression Bypass_Pressure1(y=40e5)
      annotation (Placement(transformation(extent={{-192,70},{-172,90}})));
    TIL.VLEFluidComponents.Compressors.EffCompressor Compressor_MT(
        use_mechanicalPort=true,
      use_relDisplacementInput=true,
      displacement=20e-6)
      annotation (Placement(transformation(extent={{194,54},{178,70}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p2
      annotation (Placement(transformation(extent={{138,28},{146,36}})));
    TIL.OtherComponents.Controllers.PIController PI_Comp(
      controllerType="PI",
      invertFeedback=true,
      yMax=10,
      yMin=0.01,
      yInitial=3,
      Ti=100,
      k=10)
      annotation (Placement(transformation(extent={{136,40},{148,52}})));
    Modelica.Blocks.Sources.RealExpression Bypass_Pressure2(y=34e5)
      annotation (Placement(transformation(extent={{104,36},{124,56}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction(
      pressureStateID=3,
      volume=5e-4,
      hInitial=397e3)
      annotation (Placement(transformation(extent={{72,-8},{80,0}})));

    TIL.VLEFluidComponents.Sensors.Sensor_m_flow sensor_m_flow annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=90,
          origin={186,110})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint1(y=70)
      annotation (Placement(transformation(extent={{-84,334},{-104,354}})));
    TIL.OtherComponents.Controllers.PIController PI_DHW(
      controllerType="PI",
      invertFeedback=true,
      yMin=0.01,
      yMax=1,
      Ti=1,
      yInitial=0.10,
      k=1e-2,
      initType="initialOutput")
      annotation (Placement(transformation(extent={{-128,338},{-140,350}})));
    TIL.VLEFluidComponents.Sensors.Sensor_q sensor_q3(initialSensorValue=0.1,
        useTimeConstant=false)
      annotation (Placement(transformation(extent={{-246,58},{-238,66}})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve3(effectiveFlowAreaFixed=
          4.6e-5, use_effectiveFlowAreaInput=true)
                                         annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=0,
          origin={-186,-114})));
    TIL.OtherComponents.Controllers.PIController PI_ValveIWC(
      controllerType="PI",
      invertFeedback=true,
      yMin=1e-8,
      yMax=5e-5,
      use_activeInput=true,
      use_y_notActive=true,
      yInitial=6.4e-6,
      Ti=0.01,
      k=1e-9)
      annotation (Placement(transformation(extent={{-90,-80},{-102,-92}})));
    TIL.VLEFluidComponents.Sensors.Sensor_q sensor_q4
      annotation (Placement(transformation(extent={{-26,-110},{-18,-102}})));
    Modelica.Blocks.Sources.RealExpression Superheat_realinput1(y=0.95)
      annotation (Placement(transformation(extent={{-52,-102},{-70,-90}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC11(liquidType=sim.liquidType1)
                                                               annotation (
        Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=180,
          origin={-128,-120})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction3(
      pressureStateID=2,
      volume=5e-5,
      hInitial=213e3)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=-90,
          origin={-206,-4})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction4(
      pressureStateID=3,
      hInitial=435e3,
      volume=5e-3)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=180,
          origin={90,-4})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction5(
      pressureStateID=2,
      volume=5e-5,
      hInitial=junction3.hInitial)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=-90,
          origin={-206,-114})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve5(
        use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=0,
          origin={-188,-390})));
    TIL.OtherComponents.Controllers.PIController PI_Valve_Freezer(
      controllerType="PI",
      invertFeedback=true,
      initType="initialOutput",
      yInitial=6.5e-7,
      k=1e-12,
      yMax=1e-5,
      yMin=1e-8,
      Ti=1)
      annotation (Placement(transformation(extent={{-114,-346},{-126,-334}})));
    Modelica.Blocks.Sources.RealExpression Superheat_realinput3(
                                                               y=2)
      annotation (Placement(transformation(extent={{-82,-350},{-102,-330}})));
    TIL.VLEFluidComponents.Sensors.Sensor_superheating sensor_superheating3
      annotation (Placement(transformation(extent={{-52,-384},{-44,-376}})));
    TIL.VLEFluidComponents.Compressors.EffCompressor Compressor_LT(
        use_mechanicalPort=true, use_relDisplacementInput=true)
      annotation (Placement(transformation(extent={{128,-344},{112,-328}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p3
      annotation (Placement(transformation(extent={{84,-374},{92,-366}})));
    TIL.OtherComponents.Controllers.PIController PI_LP_Comp(
      controllerType="PI",
      invertFeedback=true,
      yMin=1,
      Ti=100,
      yMax=3,
      k=1e-6,
      yInitial=1.1)
      annotation (Placement(transformation(extent={{82,-348},{94,-336}})));
    Modelica.Blocks.Sources.RealExpression Bypass_Pressure3(y=14.2e5)
      annotation (Placement(transformation(extent={{50,-352},{70,-332}})));
    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState3(
        pressureStateID=4, pInitial=1420000)
      annotation (Placement(transformation(extent={{16,-396},{28,-384}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction1(
      pressureStateID=3,
      volume=5e-3,
      hInitial=467e3)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=180,
          origin={120,-4})));
    TIL.HeatExchangers.ShellAndTube.VLEFluidLiquid.Evaporator    GreyWater_HX(
      pressureStateID=3,
      nCells=3,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.ShellAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.ShellAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.ShellAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      TInitialSuperheating=1,
      initLiquid="linearTemperatureDistribution",
      redeclare model ShellSideSinglePhaseHeatTransferModel =
          TIL.HeatExchangers.ShellAndTube.TransportPhenomena.ShellSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model ShellSideEvaporationHeatTransferModel =
          TIL.HeatExchangers.ShellAndTube.TransportPhenomena.ShellSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      initialFillingLevel=0.8,
      redeclare TIL.HeatExchangers.ShellAndTube.Geometry.ShellAndTubeGeometry
        hxGeometry(
        topClearance=0.01,
        bottomClearance=0.01,
        tubeOuterDiameter=10e-3,
        tubeWallThickness=1.5e-3,
        tubeActiveLength=1.5,
        shellInnerDiameter=0.4,
        nTotalTubes=60),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      TInitialWall=273.65,
      TInitialLiquid_Cell1=275.15,
      TInitialLiquid_CellN=293.15,
      m_flowStartLiquid=0.09185)
      annotation (Placement(transformation(extent={{-118,-244},{-90,-272}})));

    TIL.VLEFluidComponents.Valves.OrificeValve valve4(
        use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=0,
          origin={-184,-244})));
    TIL.OtherComponents.Controllers.PIController PI_Valve_GreyWater(
      controllerType="PI",
      invertFeedback=true,
      use_activeInput=true,
      use_y_notActive=true,
      k=1e-12,
      Ti=1,
      yMin=9.7e-7,
      yMax=5e-6,
      yInitial=1.1e-6)
      annotation (Placement(transformation(extent={{-72,-222},{-84,-210}})));
    Modelica.Blocks.Sources.RealExpression Superheat_realinput2(y=1)
      annotation (Placement(transformation(extent={{0,-210},{-20,-190}})));
    TIL.VLEFluidComponents.Sensors.Sensor_superheating sensor_superheating2(
        initialSensorValue=1, useTimeConstant=false)
      annotation (Placement(transformation(extent={{-82,-236},{-74,-228}})));
    TIL.LiquidComponents.Boundaries.BoundaryUnderdetermined
      boundaryUnderdetermined
      annotation (Placement(transformation(extent={{-164,-268},{-156,-248}})));
    TIL.LiquidComponents.Boundaries.BoundaryOverdetermined
      boundaryOverdetermined(
      streamVariablesInputType="T",
      boundaryType="p, m_flow",
      m_flowFixed=-0.09185,
      use_massFlowRateInput=true,
      TFixed=293.15)
      annotation (Placement(transformation(extent={{-46,-268},{-54,-248}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction2(
      pressureStateID=2,
      volume=5e-5,
      hInitial=junction3.hInitial)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=-90,
          origin={-206,-244})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction6(
      pressureStateID=3,
      volume=5e-4,
      hInitial=446e3)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=90,
          origin={90,-114})));
    TIL.VLEFluidComponents.Separators.IdealSeparator idealSeparator1(
      pressureStateID=3,
      hStart=junction.hInitial,
      mixingRatioInitial={1},
      V=1,
      mdotStart=0.2,
      initialFillingLevel=0)
      annotation (Placement(transformation(extent={{138,-18},{150,2}})));

    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX HX_CO2_IW(
      initVLEFluid_a="linearEnthalpyDistribution",
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
      pressureStateID=3,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      m_flowStart_a=PI_ValveIWC.yInitial,
      pStart_a=pressureState1.pInitial,
      m_flowStart_b=PI_Pump_IWC.yInitial,
      initHeatTransfer_a="alpha",
      alphaInitial_a=1500,
      hInitialVLEFluid_a_CellN=junction4.hInitial,
      hInitialVLEFluid_a_Cell1=junction3.hInitial,
      liquidType_b=sim.liquidType1,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
          numberOfPlates=80),
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      cellOrientation_a="A",
      nCells=5,
      initLiquid_b="linearTemperatureDistribution",
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      TInitialVLEFluid_a=273.15,
      TInitialLiquid_b=280.15,
      TInitialLiquid_b_Cell1=280.15,
      TInitialLiquid_b_CellN=288.15)
      annotation (Placement(transformation(extent={{-112,-108},{-84,-136}})));

    TIL.LiquidComponents.HydraulicCapacitors.HydraulicCapacitor
      hydraulicCapacitor1(
                         C=1e20,
      fixedInitialPressure=true,
      massInitial=1,
      m_flowStart=0.3,
      TInitial=283.15)
      annotation (Placement(transformation(extent={{66,380},{74,396}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC17
      annotation (Placement(transformation(extent={{100,388},{108,396}})));
    TIL.LiquidComponents.Sensors.Sensor_m_flow sensor_m_flow3
      annotation (Placement(transformation(extent={{56,380},{48,388}})));
    TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundary1(
        boundaryType="n",
      use_nInput=false,
      nFixed=50)
      annotation (Placement(transformation(extent={{154,52},{162,72}})));
    TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundary2(
        boundaryType="n",
      use_nInput=false,
      nFixed=50)
      annotation (Placement(transformation(extent={{98,-346},{106,-326}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC10(liquidType=sim.liquidType1)
                                                               annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=0,
          origin={-266,-122})));
    TIL.LiquidComponents.Tubes.Tube tank_IW(
      redeclare model PressureDropModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      initLiquid="linearTemperatureDistribution",
      m_flowStart=0.5,
      redeclare model TubeSideHeatTransferModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1),
      redeclare model WallHeatConductionModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.WallHeatTransfer.ConstantR
          (constantR=1/4000),
      tubeGeometry(
        wallThickness=0.05,
        crossSectionType=TIL.Internals.CrossSectionType.Circular,
        innerDiameter=1,
        length=60.15),
      nCells=20,
      TInitialWall=288.15,
      TInitialLiquid_Cell1=288.15,
      TInitialLiquid_CellN=288.15) annotation (Placement(transformation(
          extent={{14,-4},{-14,4}},
          rotation=-90,
          origin={-246,-154})));

    TIL.LiquidComponents.JunctionElements.VolumeJunction junction8(volume=1e-4,
        TInitial=280.15)                                           annotation (
        Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=0,
          origin={-246,-130})));
    TIL.LiquidComponents.Tubes.Tube tank_DHW(
      nCells=20,
      redeclare model TubeSideHeatTransferModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1900),
      redeclare model WallHeatConductionModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model PressureDropModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      m_flowStart=3,
      redeclare TIL.LiquidComponents.Tubes.Geometry.TubeGeometry tubeGeometry(
          innerDiameter=1, length=12.73),
      initLiquid="constantTemperature",
      TInitialLiquid=283.15,
      TInitialWall=283.15,
      TInitialLiquid_Cell1=283.15,
      TInitialLiquid_CellN=343.15)
                           annotation (Placement(transformation(
          extent={{-16,-4},{16,4}},
          rotation=90,
          origin={102,336})));

    TIL.LiquidComponents.Boundaries.Boundary OutletDHW2(
      streamVariablesInputType="T",
      use_temperatureInput=false,
      boundaryType="m_flow",
      m_flowFixed=0.5,
      use_massFlowRateInput=true,
      TFixed=353.15)
      annotation (Placement(transformation(extent={{166,360},{158,380}})));
    TIL.LiquidComponents.Boundaries.Boundary OutletDHW3(
                                                       boundaryType="p",
      streamVariablesInputType="T",
      use_temperatureInput=false,
      TFixed=278.15)
      annotation (Placement(transformation(extent={{156,304},{164,324}})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction9(volume=5e-3, TInitial=
         343.15)
      annotation (Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=-90,
          origin={104,362})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction10(volume=5e-3,
        TInitial=283.15)
      annotation (Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=0,
          origin={112,314})));
    TIL.HeatExchangers.FinAndTube.MoistAirLiquid.CrossFlowHX    parallelFlowHX(
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      moistAirCellFlowType="flow A-B",
      redeclare model FinSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
      gasType=sim.gasType2,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=10000),
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=10000),
      nCells=3,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
      redeclare model FinEfficiencyModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinEfficiency.Schmidt,
      redeclare TIL.HeatExchangers.FinAndTube.Geometry.KKI001 hxGeometry(
          nSerialTubes=20, nParallelTubes=20),
      m_flowLiquidStart=0.122,
      m_flowMoistAirStart=1e-7,
      TInitialLiquid=283.15,
      TInitialWall=283.15)
      annotation (Placement(transformation(extent={{-60,370},{-32,398}})));

    TIL.GasComponents.Fans.SimpleFan simpleFan2(use_volumeFlowRateInput=true,
        gasType=sim.gasType2) annotation (Placement(transformation(
          extent={{-8,-8},{8,8}},
          rotation=180,
          origin={-46,424})));
    TIL.GasComponents.Boundaries.Boundary boundary(
      streamVariablesInputType="T",
      boundaryType="p",
      gasType=sim.gasType2,
      use_temperatureInput=false,
      TFixed=264.15)
      annotation (Placement(transformation(extent={{-4,-10},{4,10}},
          rotation=-90,
          origin={-46,444})));
    TIL.GasComponents.Boundaries.Boundary boundary1(
      boundaryType="p",
      streamVariablesInputType="T",
      gasType=sim.gasType2,
      TFixed=283.15)
      annotation (Placement(transformation(extent={{-4,-10},{4,10}},
          rotation=90,
          origin={-46,356})));
    Modelica.Blocks.Logical.GreaterThreshold greaterThreshold(threshold=10)
      annotation (Placement(transformation(extent={{50,404},{30,424}})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint3(y=
          sensor_T_degC17.sensorValue)
      annotation (Placement(transformation(extent={{80,404},{60,424}})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction11(volume=8e-3,
        TInitial=308.15)                                           annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=180,
          origin={-286,262})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction12(volume=8e-3,
        TInitial=298.15)                                           annotation (
        Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=180,
          origin={-286,208})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction13(volume=8e-3,
        TInitial=308.15)                                           annotation (
        Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=180,
          origin={-270,262})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction14(volume=8e-3,
        TInitial=298.15)                                           annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=180,
          origin={-270,208})));
    TIL.LiquidComponents.Tubes.Tube tank_SH(
      redeclare model PressureDropModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      enableHeatPorts=false,
      initLiquid="linearTemperatureDistribution",
      redeclare model TubeSideHeatTransferModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1),
      redeclare model WallHeatConductionModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.WallHeatTransfer.ConstantR
          (constantR=1/4000),
      m_flowStart=-0.3,
      nCells=20,
      tubeGeometry(
        wallThickness=0.05,
        crossSectionType=TIL.Internals.CrossSectionType.Circular,
        innerDiameter=1,
        length=60.93),
      TInitialWall=298.15,
      TInitialLiquid_Cell1=298.15,
      TInitialLiquid_CellN=298.15) annotation (Placement(transformation(
          extent={{16,-4},{-16,4}},
          rotation=-90,
          origin={-288,234})));

    TIL.LiquidComponents.Boundaries.Boundary InletFloor1(
      boundaryType="m_flow",
      m_flowFixed=0.8,
      use_massFlowRateInput=true,
      TFixed=308.15)   annotation (Placement(transformation(
          extent={{-4,-10},{4,10}},
          rotation=0,
          origin={-332,262})));
    TIL.LiquidComponents.Boundaries.Boundary InletFloor2(
      m_flowFixed=-0.8,
      boundaryType="p",
      TFixed=298.15)   annotation (Placement(transformation(
          extent={{-4,-10},{4,10}},
          rotation=0,
          origin={-332,208})));
    TIL.LiquidComponents.Pumps.SimplePump simplePump2(
      presetVariableType="m_flow",
      use_massFlowRateInput=true,
      use_volumeFlowRateInput=false)
                annotation (Placement(transformation(
          extent={{8,-8},{-8,8}},
          rotation=0,
          origin={-464,240})));
    TIL.OtherComponents.Controllers.PIController PI_Floor1(
      controllerType="PI",
      invertFeedback=true,
      k=0.1,
      Ti=10,
      yMax=10,
      yMin=1e-7,
      yInitial=0.8,
      use_activeInput=true,
      use_y_notActive=true)
      annotation (Placement(transformation(extent={{-416,228},{-428,240}})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint5(y=35)
      annotation (Placement(transformation(extent={{-376,224},{-396,244}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC18
      annotation (Placement(transformation(extent={{-456,220},{-448,228}})));
    TIL.LiquidComponents.HydraulicCapacitors.HydraulicCapacitor
      hydraulicCapacitor3(
                         C=1e20,
      fixedInitialPressure=true,
      massInitial=1,
      m_flowStart=0.3)
      annotation (Placement(transformation(extent={{-290,168},{-284,182}})));
    TIL.OtherComponents.Controllers.PIController PI_Pump_IWC(
      controllerType="PI",
      initType="initialOutput",
      use_activeInput=true,
      use_y_notActive=true,
      invertFeedback=true,
      yMax=6,
      k=1e-4,
      yMin=0.2,
      yInitial=0.2,
      Ti=0.01)
      annotation (Placement(transformation(extent={{-34,-160},{-46,-172}})));
    Modelica.Blocks.Sources.RealExpression Temp_IWC3(y=7)
      annotation (Placement(transformation(extent={{8,-146},{-6,-128}})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction15(volume=1e-4,
        TInitial=288.15)                                           annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=0,
          origin={-246,-178})));
    TIL.LiquidComponents.Pumps.SimplePump Pump_IWC(
      m_flowFixed=0.2,
      presetVariableType="m_flow",
      use_massFlowRateInput=true,
      use_volumeFlowRateInput=false,
      liquidType=sim.liquidType1) annotation (Placement(transformation(
          extent={{8,-8},{-8,8}},
          rotation=0,
          origin={-74,-160})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC15
      annotation (Placement(transformation(extent={{-320,266},{-312,274}})));
    TIL.LiquidComponents.Boundaries.Boundary InletFloor3(
      boundaryType="m_flow",
      m_flowFixed=0.4,
      use_massFlowRateInput=true,
      TFixed=313.15)   annotation (Placement(transformation(
          extent={{-4,-10},{4,10}},
          rotation=0,
          origin={-280,-130})));
    TIL.LiquidComponents.Boundaries.Boundary InletFloor4(
      m_flowFixed=-0.4,
      boundaryType="p",
      TFixed=288.15)   annotation (Placement(transformation(
          extent={{-4,-10},{4,10}},
          rotation=0,
          origin={-282,-178})));
    TIL.HeatExchangers.FinAndTube.GasVLEFluid.CrossFlowHX HX_Chiller(
      fixedPressureDropInitialVLEFluid=false,
      fixedTInitialWall=false,
      pressureStateID=3,
      pVLEFluidStart=pressureState1.pInitial,
      pressureDropInitialVLEFluid=0,
      gasCellFlowType="flow A-B",
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
      redeclare model FinEfficiencyModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinEfficiency.Schmidt,
      redeclare model FinSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
      nCells=3,
      initVLEFluid="linearEnthalpyDistribution",
      hInitialVLEFluid_Cell1=213e3,
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=150),
      hInitialVLEFluid_CellN=429e3,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare TIL.HeatExchangers.FinAndTube.Geometry.KKI001 hxGeometry(
          nSerialTubes=8, nParallelTubes=14),
      m_flowVLEFluidStart=0.023,
      initHeatTransfer="alpha",
      alphaInitialVLEFluid=2500,
      TInitialVLEFluid=272.15,
      TInitialWall=273.57)
      annotation (Placement(transformation(extent={{-110,10},{-82,-18}})));

    TIL.GasComponents.Fans.SimpleFan simpleFan(use_volumeFlowRateInput=true)
      annotation (Placement(transformation(extent={{-104,-50},{-88,-34}})));
    TIL.GasComponents.Volumes.Volume volume(volume=75, TInitial=276.15)
      annotation (Placement(transformation(
          extent={{-4,-8},{4,8}},
          rotation=90,
          origin={-100,-60})));
    TIL.OtherComponents.Thermal.HeatBoundary Heat_Cooling(boundaryType="Q_flow",
        Q_flowFixed(displayUnit="kW") = -5000)  annotation (Placement(
          transformation(
          extent={{-4,-6},{4,6}},
          rotation=0,
          origin={-116,-60})));
    TIL.GasComponents.Sensors.Sensor_T sensor_T annotation (Placement(
          transformation(
          extent={{-4,4},{4,-4}},
          rotation=-90,
          origin={-106,-30})));
    TIL.OtherComponents.Controllers.PIController PI_PumpChiller(
      controllerType="PI",
      invertFeedback=true,
      yMin=1,
      initType="initialOutput",
      yMax=5,
      Ti=100,
      yInitial=2,
      k=1)
      annotation (Placement(transformation(extent={{-132,-36},{-120,-48}})));
    Modelica.Blocks.Sources.RealExpression Setpoint_Cooling(y=276.15)
      annotation (Placement(transformation(extent={{-166,-52},{-146,-32}})));
    TIL.GasComponents.Sensors.Sensor_T_degC sensor_T_degC19
      annotation (Placement(transformation(extent={{-82,-38},{-74,-30}})));
    TIL.HeatExchangers.FinAndTube.GasVLEFluid.CrossFlowHX HX_Freezer(
      fixedPressureDropInitialVLEFluid=false,
      fixedTInitialWall=false,
      hInitialVLEFluid_Cell1=250,
      hInitialVLEFluid_CellN=430,
      pressureStateID=4,
      hInitialVLEFluid=440e3,
      initVLEFluid="constantTemperature",
      gasCellFlowType="flow A-B",
      nCells=3,
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
      redeclare model FinEfficiencyModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinEfficiency.Schmidt,
      redeclare model FinSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
      pVLEFluidStart=pressureState3.pInitial,
      m_flowVLEFluidStart=0.03,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare TIL.HeatExchangers.FinAndTube.Geometry.KKI001 hxGeometry(
          nSerialTubes=8, nParallelTubes=10),
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=150),
      TInitialVLEFluid=243.15,
      TInitialWall=243.15)
      annotation (Placement(transformation(extent={{-144,-376},{-116,-404}})));

    TIL.GasComponents.Fans.SimpleFan simpleFan1(
                                               use_volumeFlowRateInput=true)
      annotation (Placement(transformation(extent={{-138,-436},{-122,-420}})));
    TIL.GasComponents.Volumes.Volume volume2(volume=60, TInitial=253.15)
      annotation (Placement(transformation(
          extent={{-4,-8},{4,8}},
          rotation=90,
          origin={-134,-450})));
    TIL.OtherComponents.Thermal.HeatBoundary Heat_Cooling1(
                                                          boundaryType="Q_flow",
        Q_flowFixed(displayUnit="kW") = -10000) annotation (Placement(
          transformation(
          extent={{-4,-6},{4,6}},
          rotation=0,
          origin={-152,-450})));
    TIL.GasComponents.Sensors.Sensor_T sensor_T2
                                                annotation (Placement(
          transformation(
          extent={{-4,4},{4,-4}},
          rotation=-90,
          origin={-142,-410})));
    TIL.OtherComponents.Controllers.PIController PI_PumpFreezer(
      controllerType="PI",
      invertFeedback=true,
      yMin=1,
      k=1,
      Ti=100,
      yInitial=1.5,
      yMax=5)
      annotation (Placement(transformation(extent={{-166,-422},{-154,-434}})));
    Modelica.Blocks.Sources.RealExpression Setpoint_Cooling1(y=253.15)
      annotation (Placement(transformation(extent={{-196,-438},{-176,-418}})));
    TIL.GasComponents.Sensors.Sensor_T_degC sensor_T_degC14
      annotation (Placement(transformation(extent={{-114,-426},{-106,-418}})));
    Modelica.Blocks.Sources.RealExpression off_value_GW(y=1e-12)
      annotation (Placement(transformation(extent={{-44,-216},{-64,-196}})));
   Modelica.Blocks.Logical.Hysteresis hysteresis(
     pre_y_start=false,
      uHigh=69,
      uLow=50)
     annotation (Placement(transformation(extent={{4,-228},{-12,-212}})));
   Modelica.Blocks.Logical.Not not1
     annotation (Placement(transformation(extent={{-20,-228},{-36,-212}})));
   Modelica.Blocks.Sources.RealExpression DHWT_Temp1(y=tank_DHW.summary.arrays.T_degC_liq_cell[
          10])
     annotation (Placement(transformation(extent={{30,-228},{12,-212}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction7(
      pressureStateID=2,
      volume=5e-5,
      hInitial=junction3.hInitial)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=-90,
          origin={-206,-390})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve6(
        use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=0,
          origin={-54,-500})));
    Modelica.Blocks.Sources.RealExpression sup_heat(y=2)
      annotation (Placement(transformation(extent={{68,-446},{48,-426}})));
    TIL.VLEFluidComponents.Sensors.Sensor_superheating sensor_superheating4
      annotation (Placement(transformation(extent={{74,-494},{82,-486}})));
    TIL.HeatExchangers.FinAndTube.GasVLEFluid.CrossFlowHX HX_Air(
      fixedPressureDropInitialVLEFluid=false,
      fixedTInitialWall=false,
      pVLEFluidStart=pressureState1.pInitial,
      pressureDropInitialVLEFluid=0,
      initHeatTransfer="alphaA",
      alphaAInitialVLEFluid=5000,
      gasCellFlowType="flow A-B",
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model FinEfficiencyModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinEfficiency.Schmidt,
      redeclare model FinSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
      nCells=3,
      hInitialVLEFluid_Cell1=213e3,
      hInitialVLEFluid_CellN=413e3,
      pressureStateID=8,
      initVLEFluid="constantEnthalpy",
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=150),
      redeclare TIL.HeatExchangers.FinAndTube.Geometry.KKI001 hxGeometry(
        nTubeSideParallelHydraulicFlows=3,
        finnedTubeLength=2,
        nSerialTubes=10,
        nParallelTubes=25),
      redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
      TInitialVLEFluid=272.15,
      TInitialWall=274.15)
      annotation (Placement(transformation(extent={{18,-486},{46,-514}})));

    TIL.OtherComponents.Controllers.PIController PI_ValveAir(
      controllerType="PI",
      invertFeedback=true,
      yMin=1e-9,
      yMax=0.5,
      use_activeInput=true,
      use_y_notActive=true,
      Ti=0.1,
      initType="initialOutput",
      k=1e-11,
      yInitial=3e-7)
      annotation (Placement(transformation(extent={{34,-452},{22,-440}})));
    TIL.VLEFluidComponents.Compressors.EffCompressor Compressor_parallell(
        use_mechanicalPort=true,
      use_relDisplacementInput=true,
      displacement=20e-6)
      annotation (Placement(transformation(extent={{234,-472},{218,-456}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p4
      annotation (Placement(transformation(extent={{178,-494},{186,-486}})));
    TIL.OtherComponents.Controllers.PIController PI_CompParallell(
      controllerType="PI",
      initType="initialOutput",
      use_activeInput=true,
      use_y_notActive=true,
      Ti=0.01,
      k=1e-3,
      invertFeedback=false,
      yMax=5,
      yMin=0.1,
      yInitial=1)
      annotation (Placement(transformation(extent={{174,-470},{186,-458}})));
    TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundary3(
        boundaryType="n",
      use_nInput=false,
      nFixed=50)
      annotation (Placement(transformation(extent={{206,-474},{214,-454}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction16(
      volume=5e-4,
      pressureStateID=1,
      hInitial=495e3)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=180,
          origin={186,142})));
    Modelica.Blocks.Sources.RealExpression off_value_GW1(y=0)
      annotation (Placement(transformation(extent={{68,-432},{48,-412}})));
    TIL.GasComponents.Boundaries.Boundary
      boundaryUnderdetermined1(boundaryType="p")
      annotation (Placement(transformation(extent={{56,-490},{64,-470}})));
    TIL.GasComponents.Boundaries.Boundary               boundaryOverdetermined1(
      streamVariablesInputType="T",
      V_flowFixed=-0.5,
      boundaryType="p",
      use_volumeFlowRateInput=false,
      TFixed=264.15)
      annotation (Placement(transformation(extent={{-38,-540},{-30,-520}})));
    TIL.GasComponents.Sensors.Sensor_T_degC sensor_T_degC22
      annotation (Placement(transformation(extent={{8,-480},{16,-472}})));
    Modelica.Blocks.Sources.RealExpression off_value_GW2(y=0)
      annotation (Placement(transformation(extent={{208,-456},{188,-436}})));
    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX HX_Ammonia_SH(
      liquidType_b=sim.liquidType1,
      vleFluidType_a=sim.vleFluidType2,
      pressureStateID=5,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.Plate.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      initLiquid_b="linearTemperatureDistribution",
      hInitialVLEFluid_a=1000e3,
      initVLEFluid_a="linearEnthalpyDistribution",
      hInitialVLEFluid_a_CellN=300e3,
      nCells=3,
      m_flowStart_b=0.8,
      hInitialVLEFluid_a_Cell1=650e3,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      m_flowStart_a=0.1,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        phi=30,
        wallThickness=0.0009,
        patternAmplitude=0.0011,
        numberOfPlates=300,
        length=0.4,
        width=0.25),
      TInitialLiquid_b_Cell1=308.15,
      TInitialLiquid_b_CellN=298.15,
      pStart_a=1300000) annotation (Placement(transformation(
          extent={{-14,-14},{14,14}},
          rotation=0,
          origin={-392,164})));

   TIL.VLEFluidComponents.Valves.OrificeValve valve8(
       use_effectiveFlowAreaInput=true, vleFluidType=sim.vleFluidType2)
     annotation (Placement(transformation(
         extent={{8,-4},{-8,4}},
         rotation=0,
         origin={-362,-94})));
   TIL.VLEFluidComponents.Compressors.EffCompressor2 Compressor_propane(
      use_mechanicalPort=true,
      vleFluidType=sim.vleFluidType2,
      displacement=2e-4,
      use_relDisplacementInput=true) annotation (Placement(transformation(
          extent={{8,-8},{-8,8}},
          rotation=0,
          origin={-622,-6})));
   TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundary4(
       boundaryType="n", use_nInput=true)
     annotation (Placement(transformation(extent={{-4,-10},{4,10}},
         rotation=0,
         origin={-648,-6})));
   TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX HX_Propane_IW(
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      initHeatTransfer_a="alpha",
      alphaInitial_a=1900,
      vleFluidType_a=sim.vleFluidType2,
      pressureStateID=6,
      hInitialVLEFluid_a=1000e3,
      initVLEFluid_a="linearEnthalpyDistribution",
      initLiquid_b="linearTemperatureDistribution",
      m_flowStart_a=0.1,
      hInitialVLEFluid_a_Cell1=300e3,
      nCells=3,
      hInitialVLEFluid_a_CellN=500e3,
      m_flowStart_b=1,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.Plate.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        wallThickness=0.0009,
        patternAmplitude=0.0011,
        phi=30,
        numberOfPlates=100,
        length=0.3,
        width=0.2),
      TInitialVLEFluid_a=303.15,
      TInitialLiquid_b=291.15,
      TInitialLiquid_b_Cell1=280.15,
      TInitialLiquid_b_CellN=288.15,
      pStart_a=600000)   annotation (Placement(transformation(
          extent={{14,14},{-14,-14}},
          rotation=0,
          origin={-484,-102})));

   TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState6(
     vleFluidType=sim.vleFluidType2,
      pressureStateID=5,
      pInitial=1300000)
     annotation (Placement(transformation(extent={{-6,-6},{6,6}},
         rotation=90,
         origin={-622,14})));
   TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState7(
     pressureStateID=6,
     vleFluidType=sim.vleFluidType2,
      pInitial=600000)
     annotation (Placement(transformation(extent={{-6,-6},{6,6}},
         rotation=90,
         origin={-622,-28})));
   TIL.OtherComponents.Controllers.PIController PI_ValveNH3(
     controllerType="PI",
     invertFeedback=true,
     initType="initialOutput",
      yMax=5e-5,
      use_activeInput=true,
      use_y_notActive=true,
      yInitial=2.6e-6,
      yMin=1e-8,
      k=1e-11,
      Ti=0.01)
     annotation (Placement(transformation(extent={{4,4},{-4,-4}},
         rotation=180,
         origin={-392,-66})));
   Modelica.Blocks.Sources.RealExpression asupheat(y=2)
      annotation (Placement(transformation(extent={{-412,-70},{-400,-62}})));
   TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC30
     annotation (Placement(transformation(extent={{-464,-126},{-456,-118}})));
   TIL.VLEFluidComponents.Sensors.Sensor_superheating sensor_superheating6(
       vleFluidType=sim.vleFluidType2)
     annotation (Placement(transformation(extent={{-512,-92},{-504,-84}})));
   TIL.VLEFluidComponents.Sensors.Sensor_m_flow sensor_m_flow13(vleFluidType=
         sim.vleFluidType2)
     annotation (Placement(transformation(extent={{-590,152},{-582,160}})));
   TIL.VLEFluidComponents.Sensors.Sensor_q      sensor_T_degC23(vleFluidType=
         sim.vleFluidType2, useTimeConstant=false)
     annotation (Placement(transformation(extent={{-350,160},{-342,168}})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint(vleFluidType=sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-552,160},{-544,168}})));
    Modelica.Blocks.Sources.RealExpression Temp_IWC1(y=7)
      annotation (Placement(transformation(extent={{-494,-164},{-514,-144}})));
    TIL.OtherComponents.Controllers.PIController PI_Pump_IWC1(
      controllerType="PI",
      initType="initialOutput",
      yMax=10,
      Ti=0.01,
      invertFeedback=false,
      use_activeInput=true,
      use_y_notActive=true,
      yInitial=0.7,
      k=1e-5,
      yMin=0.01)
      annotation (Placement(transformation(extent={{-528,-148},{-540,-160}})));
    TIL.LiquidComponents.Pumps.SimplePump simplePump3(presetVariableType=
          "m_flow", use_massFlowRateInput=true)
      annotation (Placement(transformation(extent={{-552,-156},{-568,-140}})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction17(volume=1e-4,
        TInitial=280.15)                                           annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=0,
          origin={-232,-130})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction18(volume=1e-4,
        TInitial=288.15)                                           annotation (
        Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=0,
          origin={-232,-178})));
    TIL.LiquidComponents.Sensors.Sensor_m_flow sensor_m_flow1
      annotation (Placement(transformation(extent={{-198,-182},{-190,-174}})));
    TIL.LiquidComponents.Sensors.Sensor_m_flow sensor_m_flow2
      annotation (Placement(transformation(extent={{-266,-230},{-274,-222}})));
    Modelica.Blocks.Sources.RealExpression off_IWPump(y=1e-7)
      annotation (Placement(transformation(extent={{20,-190},{6,-176}})));
   Modelica.Blocks.Sources.RealExpression IWT_Temp1(y=tank_IW.summary.arrays.T_degC_liq_cell[
          1])
      annotation (Placement(transformation(extent={{58,-156},{40,-142}})));
   Modelica.Blocks.Logical.Hysteresis hysteresis1(
      pre_y_start=true,
      uLow=7,
      uHigh=14)
     annotation (Placement(transformation(extent={{12,-162},{0,-150}})));
   Modelica.Blocks.Logical.Switch switch4
     annotation (Placement(transformation(extent={{28,-162},{16,-150}})));
   Modelica.Blocks.Sources.RealExpression IWT_Temp10(y=tank_IW.summary.arrays.T_degC_liq_cell[
          4])
     annotation (Placement(transformation(extent={{58,-168},{40,-154}})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(
                                                         vleFluidType=sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-460,-90},{-452,-82}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC2(vleFluidType=
          sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-570,160},{-562,168}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC9(vleFluidType=
          sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-428,-90},{-420,-82}})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(
                                                         vleFluidType=sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-332,160},{-324,168}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC12(
                                                                vleFluidType=
          sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-310,160},{-302,168}})));
    TIL.LiquidComponents.Sensors.Sensor_m_flow sensor_m_flow4
      annotation (Placement(transformation(extent={{-526,-114},{-518,-106}})));
    TIL.LiquidComponents.Sensors.Sensor_m_flow sensor_m_flow5
      annotation (Placement(transformation(extent={{-360,168},{-368,176}})));
   Modelica.Blocks.Sources.RealExpression SHT_Temp(y=tank_SH.summary.arrays.T_degC_liq_cell[
          1])
      annotation (Placement(transformation(extent={{-906,16},{-888,30}})));
   Modelica.Blocks.Logical.Hysteresis hysteresis2(
     pre_y_start=false,
      uHigh=33,
      uLow=26)
     annotation (Placement(transformation(extent={{-854,12},{-842,24}})));
   Modelica.Blocks.Logical.Not not3
     annotation (Placement(transformation(extent={{-838,12},{-826,24}})));
   Modelica.Blocks.Sources.Constant AmmoniaOn(k=50)
      annotation (Placement(transformation(extent={{-764,16},{-748,32}})));
   TIL.OtherComponents.Controllers.PIController PI_CompAmmonia1(
      controllerType="PI",
      invertFeedback=false,
      initType="initialOutput",
      use_activeInput=true,
      use_y_notActive=true,
      activationTime=40000,
      Ti=0.1,
      k=0.01,
      yMax=17,
      yMin=6,
      yInitial=6) annotation (Placement(transformation(
          extent={{-6,-6},{6,6}},
          rotation=0,
          origin={-698,-48})));
   Modelica.Blocks.Sources.RealExpression RelDispl1(y=34.5)
     annotation (Placement(transformation(extent={{-744,-56},{-726,-40}})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping2(
      n=1,
      f=0.1,
      x_start={8})
     annotation (Placement(transformation(extent={{-680,-58},{-660,-38}})));
   Modelica.Blocks.Logical.Switch switch2
     annotation (Placement(transformation(extent={{-874,12},{-862,24}})));
   Modelica.Blocks.Sources.RealExpression DHWT_Temp2(y=tank_SH.summary.arrays.T_degC_liq_cell[
          4])
     annotation (Placement(transformation(extent={{-906,6},{-888,20}})));
   Modelica.Blocks.Sources.Constant AmmoniaOff(k=1)
      annotation (Placement(transformation(extent={{-766,-40},{-750,-24}})));
    Modelica.Blocks.Logical.Switch switch1
      annotation (Placement(transformation(extent={{-722,-14},{-702,6}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_airvalve1(y=hysteresis1.y)
      annotation (Placement(transformation(extent={{-58,-94},{-74,-80}})));
    TIL.HeatExchangers.FinAndTube.GasVLEFluid.CrossFlowHX    HX_propaneAir(
      fixedPressureDropInitialVLEFluid=false,
      fixedTInitialWall=false,
      pressureDropInitialVLEFluid=0,
      initHeatTransfer="alphaA",
      gasCellFlowType="flow A-B",
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
      redeclare model FinEfficiencyModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinEfficiency.Schmidt,
      redeclare model FinSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
      nCells=3,
      initVLEFluid="linearEnthalpyDistribution",
      vleFluidType=sim.vleFluidType2,
      pVLEFluidStart=pressureState7.pInitial,
      hInitialVLEFluid_Cell1=600e3,
      hInitialVLEFluid_CellN=300e3,
      gasType=sim.gasType1,
      pressureStateID=6,
      m_flowVLEFluidStart=0,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=150),
      alphaAInitialVLEFluid=2500,
      redeclare TIL.HeatExchangers.FinAndTube.Geometry.KKI001 hxGeometry(
        finnedTubeLength=2,
        nSerialTubes=12,
        nParallelTubes=30),
      TInitialVLEFluid=272.15,
      TInitialWall=274.15)
      annotation (Placement(transformation(extent={{-446,30},{-474,2}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction19(
      vleFluidType=sim.vleFluidType2,
      pressureStateID=6,
      hInitial=587e3,
      volume=5e-4)
      annotation (Placement(transformation(extent={{4,-4},{-4,4}},
          rotation=90,
          origin={-590,-46})));
    TIL.GasComponents.Boundaries.Boundary boundary2(
      boundaryType="p",
      streamVariablesInputType="T",
      gasType=sim.gasType1,
      TFixed=283.15)
      annotation (Placement(transformation(extent={{-4,-10},{4,10}},
          rotation=90,
          origin={-460,42})));
    TIL.GasComponents.Boundaries.Boundary boundary3(
      streamVariablesInputType="T",
      gasType=sim.gasType1,
      V_flowFixed=-3,
      boundaryType="p",
      TFixed=264.15)
      annotation (Placement(transformation(extent={{-4,-10},{4,10}},
          rotation=-90,
          origin={-460,-30})));
   TIL.VLEFluidComponents.Valves.OrificeValve valve7(
       use_effectiveFlowAreaInput=true, vleFluidType=sim.vleFluidType2)
     annotation (Placement(transformation(
         extent={{8,4},{-8,-4}},
         rotation=0,
         origin={-374,16})));
    Modelica.Blocks.Sources.BooleanExpression on_off_propane_valves(y=
          hysteresis3.y)
      annotation (Placement(transformation(extent={{-570,-54},{-558,-42}})));
   TIL.OtherComponents.Controllers.PIController PI_ValveNH1(
     controllerType="PI",
     invertFeedback=true,
     initType="initialOutput",
      yMax=5e-5,
      use_activeInput=true,
      use_y_notActive=true,
      yInitial=2e-6,
      yMin=1e-8,
      k=1e-11,
      Ti=0.01)
     annotation (Placement(transformation(extent={{4,-4},{-4,4}},
         rotation=180,
         origin={-406,-12})));
   TIL.VLEFluidComponents.Sensors.Sensor_superheating sensor_superheating1(
       vleFluidType=sim.vleFluidType2)
     annotation (Placement(transformation(extent={{-512,22},{-504,30}})));
   Modelica.Blocks.Sources.RealExpression asupheat3(y=2)
      annotation (Placement(transformation(extent={{-426,-16},{-416,-8}})));
   Modelica.Blocks.Logical.Not not2
     annotation (Placement(transformation(extent={{-546,-40},{-536,-30}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction20(
      volume=1e-5,
      vleFluidType=sim.vleFluidType2,
      pressureStateID=5,
      hInitial=300e3)
      annotation (Placement(transformation(extent={{4,4},{-4,-4}},
          rotation=90,
          origin={-304,-46})));
   Modelica.Blocks.Sources.RealExpression asupheat1(y=1e-11)
      annotation (Placement(transformation(extent={{-468,-48},{-458,-38}})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping1(
      n=1,
      x_start={50},
      f=0.001)
     annotation (Placement(transformation(extent={{-684,-16},{-664,4}})));
   Modelica.Blocks.Sources.RealExpression asupheat4(y=1e-7)
      annotation (Placement(transformation(extent={{-550,-178},{-536,-166}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_airvalve4(y=not3.y)
      annotation (Placement(transformation(extent={{-378,214},{-394,226}})));
   Modelica.Blocks.Sources.RealExpression asupheat5(y=1e-7)
      annotation (Placement(transformation(extent={{-442,248},{-428,260}})));
    Modelica.Blocks.Logical.And and1
      annotation (Placement(transformation(extent={{-528,-40},{-518,-30}})));
    Modelica.Blocks.Logical.And and2
      annotation (Placement(transformation(extent={{-528,-60},{-518,-50}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_airvalve2(y=or2.y)
      annotation (Placement(transformation(extent={{-550,-54},{-536,-44}})));
    TILFileReader.FileReader fileReader(
      fileType=TILFileReader.Internals.FileTypes.CSVFile,
      decimalSeparator=TILFileReader.Internals.DecimalSeparators.ColonSeparator,
      fileName="C:/Dymola/Input_Dymola.csv")
      annotation (Placement(transformation(extent={{188,406},{208,426}})));
    TILFileReader.Variables.RealVariableName realVariableName(
                 interpolationMethod=TILFileReader.Internals.InterpolationMethods.NoInterpolation,
      factor=1,
      offset=0.001,
      variableName="DHW_70")
      annotation (Placement(transformation(extent={{200,376},{180,396}})));
    TIL.GasComponents.Fans.SimpleFan simpleFan3(V_flowFixed=3,
        use_volumeFlowRateInput=true)
      annotation (Placement(transformation(extent={{-8,-8},{8,8}},
          rotation=0,
          origin={-460,-14})));
    Modelica.Blocks.Logical.Switch switch5
      annotation (Placement(transformation(extent={{-486,-18},{-476,-8}})));
   Modelica.Blocks.Sources.RealExpression asupheat6(y=10)
      annotation (Placement(transformation(extent={{-502,-14},{-492,-4}})));
   Modelica.Blocks.Sources.RealExpression asupheat7(y=1e-6)
      annotation (Placement(transformation(extent={{-502,-22},{-492,-12}})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping3(
      n=1,
      x_start={3e-6},
      f=0.1)
     annotation (Placement(transformation(extent={{-380,-70},{-372,-62}})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping4(
      n=1,
      x_start={1e-12},
      f=0.1)
     annotation (Placement(transformation(extent={{-394,-16},{-386,-8}})));
    Modelica.Blocks.Sources.RealExpression Superheat_realinput4(y=1e-12)
      annotation (Placement(transformation(extent={{-52,-112},{-70,-100}})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping5(
      n=1,
      f=0.1,
      x_start={6.4e-6})
     annotation (Placement(transformation(extent={{-114,-92},{-126,-80}})));
    TILFileReader.FileReader fileReader1(
      fileType=TILFileReader.Internals.FileTypes.CSVFile,
      decimalSeparator=TILFileReader.Internals.DecimalSeparators.ColonSeparator,
      fileName="C:/Dymola/Input_Dymola.csv")
      annotation (Placement(transformation(extent={{-322,-144},{-302,-164}})));
    TILFileReader.Variables.RealVariableName realVariableSC(
      interpolationMethod=TILFileReader.Internals.InterpolationMethods.NoInterpolation,
      variableName="SC_A_TEK10",
      offset=0.001,
      factor=1)
      annotation (Placement(transformation(extent={{-322,-118},{-302,-138}})));

   Modelica.Blocks.Sources.RealExpression IWT_Temp2(y=tank_IW.summary.arrays.T_degC_liq_cell[
          10])
      annotation (Placement(transformation(extent={{-908,-14},{-890,0}})));
   Modelica.Blocks.Logical.Hysteresis hysteresis3(
      pre_y_start=true,
      uLow=7,
      uHigh=14.5)
     annotation (Placement(transformation(extent={{-852,-18},{-840,-6}})));
   Modelica.Blocks.Logical.Switch switch6
     annotation (Placement(transformation(extent={{-874,-18},{-862,-6}})));
   Modelica.Blocks.Sources.RealExpression IWT_Temp3(y=tank_IW.summary.arrays.T_degC_liq_cell[
          6])
     annotation (Placement(transformation(extent={{-908,-24},{-890,-10}})));
    TIL.VLEFluidComponents.Separators.IdealSeparator idealSeparator3(
      mixingRatioInitial={0.1},
      mdotStart=0.1,
      V=0.001,
      initialFillingLevel=0,
      hStart=433e3,
      pressureStateID=8)
      annotation (Placement(transformation(extent={{146,-514},{158,-494}})));
    TIL.GasComponents.Fans.SimpleFan simpleFan4(V_flowFixed=3,
        use_volumeFlowRateInput=true)
      annotation (Placement(transformation(extent={{-8,8},{8,-8}},
          rotation=90,
          origin={-8,-530})));
    Modelica.Blocks.Logical.Switch switch7
      annotation (Placement(transformation(extent={{-62,-576},{-42,-556}})));
   Modelica.Blocks.Sources.RealExpression asupheat8(y=10)
      annotation (Placement(transformation(extent={{-96,-564},{-82,-552}})));
   Modelica.Blocks.Sources.RealExpression asupheat9(y=1e-7)
      annotation (Placement(transformation(extent={{-96,-580},{-82,-568}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_airvalve3(y=not5.y)
      annotation (Placement(transformation(extent={{-124,-576},{-104,-556}})));
    TILFileReader.FileReader fileReader2(
      fileType=TILFileReader.Internals.FileTypes.CSVFile,
      decimalSeparator=TILFileReader.Internals.DecimalSeparators.ColonSeparator,
      fileName="C:/Dymola/Input_Dymola.csv")
      annotation (Placement(transformation(extent={{-10,-10},{10,10}},
          rotation=90,
          origin={-382,272})));
    TILFileReader.Variables.RealVariableName realVariableSC1(
      interpolationMethod=TILFileReader.Internals.InterpolationMethods.NoInterpolation,
      offset=0.001,
      variableName="SH_W_TEK10",
      factor=0.9)
      annotation (Placement(transformation(extent={{-364,254},{-344,274}})));
   Modelica.Blocks.Logical.Switch switch9
     annotation (Placement(transformation(extent={{-4,-262},{-16,-250}})));
    Modelica.Blocks.Sources.RealExpression off_IWPump1(y=-1e-7)
      annotation (Placement(transformation(extent={{20,-268},{6,-254}})));
    Modelica.Blocks.Sources.RealExpression off_IWPump2(y=-0.106)
      annotation (Placement(transformation(extent={{20,-258},{6,-244}})));
    Modelica.Blocks.Sources.RealExpression Bypass_Pressure5(y=HX_Air.summary.Q_flow_vle)
      annotation (Placement(transformation(extent={{134,-494},{154,-474}})));
    Modelica.Blocks.Sources.RealExpression off_value_GW5(y=25000)
      annotation (Placement(transformation(extent={{134,-464},{154,-444}})));
    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState5(
        pressureStateID=8, pInitial=3000000)
      annotation (Placement(transformation(extent={{-22,-506},{-10,-494}})));
   Modelica.Blocks.Logical.Hysteresis hysteresis5(
     pre_y_start=false,
      uLow=60,
      uHigh=69)
     annotation (Placement(transformation(extent={{146,-430},{130,-414}})));
   Modelica.Blocks.Logical.Not not5
     annotation (Placement(transformation(extent={{122,-430},{106,-414}})));
   Modelica.Blocks.Sources.RealExpression DHWT_Temp5(y=tank_DHW.summary.arrays.T_degC_liq_cell[
          15])
     annotation (Placement(transformation(extent={{196,-434},{178,-418}})));
    Modelica.Blocks.Interaction.Show.BooleanValue booleanValue(use_activePort=false,
        active=hysteresis1.y)
      annotation (Placement(transformation(extent={{0,-98},{22,-74}})));
    Modelica.Blocks.Interaction.Show.BooleanValue booleanValue1(use_activePort=false,
        active=not1.y)
      annotation (Placement(transformation(extent={{40,-236},{62,-212}})));
    Modelica.Blocks.Interaction.Show.BooleanValue booleanValue2(use_activePort=false,
        active=not5.y)
      annotation (Placement(transformation(extent={{204,-404},{226,-380}})));
    Modelica.Blocks.Interaction.Show.BooleanValue booleanValue3(use_activePort=false,
        active=and2.y)
      annotation (Placement(transformation(extent={{-288,-94},{-266,-70}})));
    Modelica.Blocks.Interaction.Show.BooleanValue booleanValue4(use_activePort=false,
        active=and1.y)
      annotation (Placement(transformation(extent={{-400,24},{-378,48}})));
    Modelica.Blocks.Interaction.Show.BooleanValue booleanValue6(use_activePort=false,
        active=not3.y)
      annotation (Placement(transformation(extent={{-494,228},{-472,252}})));
    TIL.LiquidComponents.HydraulicCapacitors.HydraulicCapacitor
      hydraulicCapacitor2(
                         C=1e20,
      fixedInitialPressure=true,
      massInitial=1,
      m_flowStart=0.3,
      TInitial=288.15)
      annotation (Placement(transformation(extent={{-3,-7},{3,7}},
          rotation=0,
          origin={-143,-175})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping6(
      n=1,
      x_start={9.77e-7},
      f=0.01)
     annotation (Placement(transformation(extent={{-98,-222},{-110,-210}})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping7(
      n=1,
      f=0.01,
      x_start={-0.09185})
     annotation (Placement(transformation(extent={{-26,-262},{-38,-250}})));
    TIL.LiquidComponents.Tubes.Tube tube(
      redeclare model TubeSideHeatTransferModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallHeatConductionModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model PressureDropModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      enableHeatPorts=true,
      initLiquid="linearTemperatureDistribution",
      m_flowStart=0.47,
      redeclare TIL.LiquidComponents.Tubes.Geometry.Tube6x1 tubeGeometry,
      nCells=2,
      TInitialWall=298.15,
      TInitialLiquid_Cell1=298.15,
      TInitialLiquid_CellN=299.15)
      annotation (Placement(transformation(extent={{-152,206},{-136,210}})));

    TIL.VLEFluidComponents.Tubes.Tube tube1(
      pressureStateID=3,
      redeclare model WallHeatConductionModel =
          TIL.VLEFluidComponents.Tubes.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model PressureDropModel =
          TIL.VLEFluidComponents.Tubes.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      enableHeatPorts=true,
      initVLEFluid="linearEnthalpyDistribution",
      redeclare TIL.VLEFluidComponents.Tubes.Geometry.Tube6x1 tubeGeometry,
      nCells=2,
      hInitialVLEFluid_Cell1=423e-3,
      hInitialVLEFluid_CellN=493e-3,
      m_flowStart=-0.033,
      redeclare model TubeSideHeatTransferModel =
          TIL.VLEFluidComponents.Tubes.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      TInitialWall=313.15,
      pStart=3300000) annotation (Placement(transformation(
          extent={{8,2},{-8,-2}},
          rotation=90,
          origin={120,-168})));

   Modelica.Blocks.Sources.RealExpression DHWT_Temp3(
                                                    y=tank_SH.summary.arrays.T_degC_liq_cell[
         1])
     annotation (Placement(transformation(extent={{-8,234},{-26,250}})));
   Modelica.Blocks.Logical.Hysteresis hysteresis4(
     pre_y_start=false,
      uHigh=34.8,
      uLow=34)
     annotation (Placement(transformation(extent={{-72,228},{-88,244}})));
   Modelica.Blocks.Logical.Not not4
     annotation (Placement(transformation(extent={{-96,228},{-112,244}})));
   Modelica.Blocks.Sources.RealExpression DHWT_Temp4(y=tank_SH.summary.arrays.T_degC_liq_cell[
          5])
     annotation (Placement(transformation(extent={{-10,218},{-28,234}})));
    Modelica.Blocks.Logical.Switch switch8
      annotation (Placement(transformation(extent={{-42,224},{-62,244}})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint2(y=1e-7)
      annotation (Placement(transformation(extent={{-186,214},{-206,234}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_propane_valves1(
                                                                    y=
          hysteresis3.y)
      annotation (Placement(transformation(extent={{-494,-148},{-510,-136}})));
    TIL.HeatExchangers.FinAndTube.GasVLEFluid.CrossFlowHX    HX_propaneDump(
      fixedPressureDropInitialVLEFluid=false,
      fixedTInitialWall=false,
      pressureDropInitialVLEFluid=0,
      gasCellFlowType="flow A-B",
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
      redeclare model FinEfficiencyModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinEfficiency.Schmidt,
      redeclare model FinSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
      nCells=3,
      vleFluidType=sim.vleFluidType2,
      hInitialVLEFluid_Cell1=600e3,
      hInitialVLEFluid_CellN=300e3,
      gasType=sim.gasType1,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      pVLEFluidStart=pressureState6.pInitial,
      pressureStateID=5,
      initVLEFluid="constantEnthalpy",
      hInitialVLEFluid=640e3,
      m_flowVLEFluidStart=0.1,
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=150),
      redeclare TIL.HeatExchangers.FinAndTube.Geometry.KKI001 hxGeometry(
        finnedTubeLength=2,
        nSerialTubes=12,
        nParallelTubes=30),
      TInitialVLEFluid=272.15,
      TInitialWall=303.15)
      annotation (Placement(transformation(extent={{-532,142},{-504,170}})));
    TIL.GasComponents.Boundaries.Boundary boundary4(
      boundaryType="p",
      streamVariablesInputType="T",
      gasType=sim.gasType1,
      TFixed=283.15)
      annotation (Placement(transformation(extent={{-4,-10},{4,10}},
          rotation=90,
          origin={-518,118})));
    TIL.GasComponents.Fans.SimpleFan simpleFan5(V_flowFixed=3,
        use_volumeFlowRateInput=true)
      annotation (Placement(transformation(extent={{8,8},{-8,-8}},
          rotation=90,
          origin={-544,200})));
    Modelica.Blocks.Logical.Switch switch10
      annotation (Placement(transformation(extent={{-628,208},{-608,228}})));
   Modelica.Blocks.Sources.RealExpression asupheat10(
                                                    y=10)
      annotation (Placement(transformation(extent={{-650,220},{-636,232}})));
   Modelica.Blocks.Sources.RealExpression asupheat11(y=1e-6)
      annotation (Placement(transformation(extent={{-650,204},{-636,216}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_propane_valves2(
                                                                    y=
          hysteresis3.y)
      annotation (Placement(transformation(extent={{-696,216},{-680,228}})));
    Modelica.Blocks.Logical.And and3
      annotation (Placement(transformation(extent={{-668,212},{-656,224}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_propane_valves3(y=
          hysteresis2.y)
      annotation (Placement(transformation(extent={{-696,206},{-680,218}})));
    TIL.GasComponents.Boundaries.Boundary boundary5(
      streamVariablesInputType="T",
      gasType=sim.gasType1,
      V_flowFixed=-3,
      boundaryType="p",
      TFixed=264.15)
      annotation (Placement(transformation(extent={{-4,-10},{4,10}},
          rotation=0,
          origin={-574,200})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping8(
      n=1,
      f=0.01,
      x_start={1e-12})
     annotation (Placement(transformation(extent={{-596,208},{-576,228}})));
   Modelica.Blocks.Sources.RealExpression asupheat2(y=3e-6)
      annotation (Placement(transformation(extent={{-468,-56},{-458,-46}})));
    Modelica.Blocks.Logical.Switch switch11
      annotation (Placement(transformation(extent={{-450,-52},{-440,-42}})));
   Modelica.Blocks.Sources.RealExpression RelDispl2(y=6)
     annotation (Placement(transformation(extent={{-722,-42},{-704,-26}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p5(vleFluidType=sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-614,166},{-606,174}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p6(vleFluidType=sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-606,-40},{-598,-32}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC13
      annotation (Placement(transformation(extent={{134,376},{142,384}})));
    MB_Finished.Or2 or2(
      IW_Layer=tank_IW.summary.arrays.T_degC_liq_cell[5],
      IW_Temp=9,
      SH_Layer=tank_SH.summary.arrays.T_degC_liq_cell[1],
      SH_Temp=34)
      annotation (Placement(transformation(extent={{-766,-14},{-746,6}})));
   Modelica.Blocks.Logical.Switch switch12
     annotation (Placement(transformation(extent={{166,-426},{154,-414}})));
   Modelica.Blocks.Sources.RealExpression DHWT_Temp6(y=tank_DHW.summary.arrays.T_degC_liq_cell[
          10])
     annotation (Placement(transformation(extent={{194,-422},{176,-406}})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint4(y=1e-7)
      annotation (Placement(transformation(extent={{48,438},{28,458}})));
    TIL.OtherComponents.Controllers.PIController PI_DHWdump(
      controllerType="PI",
      invertFeedback=true,
      initType="initialOutput",
      use_activeInput=true,
      use_y_notActive=true,
      yMax=3,
      yInitial=1e-7,
      yMin=1e-7,
      Ti=0.1,
      k=1e-4) annotation (Placement(transformation(extent={{-4,418},{-16,430}})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint6(y=10)
      annotation (Placement(transformation(extent={{52,420},{32,440}})));
    MB_Finished.ComControl comControl(
      RelTreshold=10,
      Reldisp=Comp_Pro_reldisp,
      u1=tank_SH.summary.arrays.T_degC_liq_cell[20],
      u2=tank_SH.summary.arrays.T_degC_liq_cell[15])
      annotation (Placement(transformation(extent={{-778,-90},{-758,-70}})));
  equation
    Comp_MT_W=Compressor_MT.shaftPower;
    Comp_MT_reldisp=Compressor_MT.relDisplacement_in;
    Comp_LT_W=Compressor_LT.shaftPower;
    Comp_LT_reldisp=Compressor_LT.relDisplacement_in;
    Com_Parll_reldisp=Compressor_parallell.relDisplacement_in;
    Com_Parll_W=Compressor_parallell.shaftPower;
    Comp_Pro_W=Compressor_propane.shaftPower+0.001;
    Comp_Pro_reldisp=Compressor_propane.relDisplacement_in;

    GC1_Q=HX1.summary.path_b.Q_flow_liq;
    GC2_Q=HX2.summary.path_b.Q_flow_liq;
    GC3_Q=HX3.summary.path_b.Q_flow_liq;
    HX_GW_Q=-GreyWater_HX.summary.Q_flow;
    HX_CO2_IW_Q=HX_CO2_IW.summary.Q_flow;
    HX_DHWdump_Q=-parallelFlowHX.summary.Q_flow_liq;
    HX_RefRoom_Q=HX_Chiller.summary.Q_flow_vle;
    HX_Freezer_Q=HX_Freezer.summary.Q_flow_vle;
    HX_CO2air=HX_Air.summary.Q_flow_vle;
    HX_ProSH=-HX_Ammonia_SH.summary.Q_flow;
    HX_ProIW=HX_Propane_IW.summary.Q_flow;
    HX_ProAir=HX_propaneAir.summary.Q_flow_vle;
    connect(floorHeatingSetpoint.y, PI_Floor.u_s) annotation (Line(points={{-187,
            238},{-187,240},{-218.4,240}},       color={0,0,127}));
    connect(sensor_T_degC5.sensorValue, PI_Floor.u_m) annotation (Line(points={{-200,
            276},{-224,276},{-224,245.8}},color={0,0,127}));
    connect(sensor_T_degC3.port, valve.portA) annotation (Line(
        points={{-190,146},{-190,142},{-216,142},{-216,112}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_p.port, valve.portA) annotation (Line(
        points={{-202,128},{-216,128},{-216,112}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_p.sensorValue, PI_HPValve.u_m) annotation (Line(points={{-195.8,
            128},{-192,128},{-192,109.8}}, color={0,0,127}));
    connect(HighPressure.y, PI_HPValve.u_s)
      annotation (Line(points={{-171,104},{-186,104},{-186.4,104}},
                                                         color={0,0,127}));
    connect(PI_HPValve.y, valve.effectiveFlowArea_in) annotation (Line(points={{-198.4,
            104},{-198.4,104},{-211,104}},         color={0,0,127}));
    connect(statePoint1.sensorPort, pressureState.portB) annotation (Line(
        points={{132,146},{132,142},{156,142}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_H_flow.portA, pressureState.portB) annotation (Line(
        points={{93,142},{104,142},{124,142},{156,142}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_H_flow1.sensorValue, add_GasCooler.u2) annotation (Line(
          points={{-156,139},{-156,139},{-156,117.2},{52.4,117.2}}, color={0,0,
            127}));
    connect(sensor_H_flow.sensorValue, add_GasCooler.u1) annotation (Line(
          points={{90,139},{90,140},{90,117.2},{59.6,117.2}}, color={0,0,127}));
    connect(sensor_H_flow1.portB, valve.portA) annotation (Line(
        points={{-159,142},{-216,142},{-216,112}},
        color={153,204,0},
        thickness=0.5));
    connect(valve.portB, pressureState2.portB) annotation (Line(
        points={{-216,96},{-216,80}},
        color={153,204,0},
        thickness=0.5));
    connect(pressureState2.portA, idealSeparator.portInlet) annotation (Line(
        points={{-216,68},{-216,68},{-216,50},{-211,50}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_ValveCooling.y, valve1.effectiveFlowArea_in) annotation (Line(
          points={{-68.4,34},{-186,34},{-186,1}}, color={0,0,127}));
    connect(Superheat_realinput.y, PI_ValveCooling.u_s)
      annotation (Line(points={{-37,34},{-56.4,34}},      color={0,0,127}));
    connect(idealSeparator.portGas, valve2.portA) annotation (Line(
        points={{-201,50},{-176,50},{-176,52},{-150,52}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_p1.port, valve2.portA) annotation (Line(
        points={{-168,56},{-168,52},{-150,52}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_bypass.y, valve2.effectiveFlowArea_in) annotation (Line(points={
            {-137.6,78},{-132,78},{-132,57},{-142,57}}, color={0,0,127}));
    connect(PI_bypass.u_m, sensor_p1.sensorValue) annotation (Line(points={{
            -144,72.2},{-146,72.2},{-146,62.2},{-168,62.2}}, color={0,0,127}));
    connect(Bypass_Pressure1.y, PI_bypass.u_s) annotation (Line(points={{-171,
            80},{-171,78},{-149.6,78}}, color={0,0,127}));
    connect(Bypass_Pressure2.y, PI_Comp.u_s) annotation (Line(points={{125,46},{124,
            46},{136.4,46}},      color={0,0,127}));
    connect(pressureState1.portA, junction.portA) annotation (Line(
        points={{48,-4},{48,-4},{72,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(valve2.portB, junction.portB) annotation (Line(
        points={{-134,52},{76,52},{76,0}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_q.port, pressureState1.portB) annotation (Line(
        points={{6,0},{6,-4},{36,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_p2.port, Compressor_MT.portA) annotation (Line(
        points={{142,28},{186,28},{186,54}},
        color={153,204,0},
        thickness=0.5));
    connect(Compressor_MT.portB, sensor_m_flow.portA) annotation (Line(
        points={{186,70},{186,70},{186,107}},
        color={153,204,0},
        thickness=0.5));
    connect(floorHeatingSetpoint1.y, PI_DHW.u_s) annotation (Line(points={{-105,
            344},{-105,344},{-128.4,344}},                       color={0,0,127}));
    connect(PI_DHW.y, simplePump.m_flow_in) annotation (Line(points={{-140.4,
            344},{-154,344}},                       color={0,0,127}));
    connect(PI_DHW.u_m, sensor_T_degC1.sensorValue) annotation (Line(points={{-134,
            338.2},{-134,338.2},{-134,278},{72,278}},
          color={0,0,127}));
    connect(sensor_q3.port, idealSeparator.portInlet) annotation (Line(
        points={{-242,58},{-216,58},{-216,50},{-211,50}},
        color={153,204,0},
        thickness=0.5));
    connect(Superheat_realinput1.y,PI_ValveIWC. u_s)
      annotation (Line(points={{-70.9,-96},{-82,-96},{-82,-86},{-90.4,-86}},
                                                       color={0,0,127}));
    connect(junction3.portA, idealSeparator.portLiquid) annotation (Line(
        points={{-206,8.88178e-016},{-206,36}},
        color={153,204,0},
        thickness=0.5));
    connect(junction3.portB, valve1.portA) annotation (Line(
        points={{-202,-4},{-198,-4},{-194,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(junction.portC, junction4.portC) annotation (Line(
        points={{80,-4},{86,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_Valve_Freezer.u_s,Superheat_realinput3. y) annotation (Line(
          points={{-114.4,-340},{-103,-340}},           color={0,0,127}));
    connect(PI_Valve_Freezer.y,valve5. effectiveFlowArea_in) annotation (Line(
          points={{-126.4,-340},{-188,-340},{-188,-385}},             color={0,
            0,127}));
    connect(PI_Valve_Freezer.u_m,sensor_superheating3. sensorValue)
      annotation (Line(points={{-120,-345.8},{-48,-345.8},{-48,-380},{-48,-378},
            {-48,-377.8}},                                  color={0,0,127}));
    connect(Bypass_Pressure3.y,PI_LP_Comp. u_s)
      annotation (Line(points={{71,-342},{74,-342},{82.4,-342}},
                                                         color={0,0,127}));
    connect(sensor_p3.port, Compressor_LT.portA) annotation (Line(
        points={{88,-374},{88,-378},{120,-378},{120,-344}},
        color={153,204,0},
        thickness=0.5));
    connect(pressureState3.portA, Compressor_LT.portA) annotation (Line(
        points={{28,-390},{28,-386},{120,-386},{120,-344}},
        color={153,204,0},
        thickness=0.5));
    connect(junction3.portC, junction5.portA) annotation (Line(
        points={{-206,-8},{-206,-8},{-206,-110}},
        color={153,204,0},
        thickness=0.5));
    connect(junction5.portB, valve3.portA) annotation (Line(
        points={{-202,-114},{-202,-114},{-194,-114}},
        color={153,204,0},
        thickness=0.5));
    connect(Superheat_realinput2.y,PI_Valve_GreyWater. u_s) annotation (Line(
          points={{-21,-200},{-21,-200},{-34,-200},{-40,-200},{-40,-216},{-72.4,
            -216}},                                    color={0,0,127}));
    connect(junction5.portC, junction2.portA) annotation (Line(
        points={{-206,-118},{-206,-240}},
        color={153,204,0},
        thickness=0.5));
    connect(junction2.portB, valve4.portA) annotation (Line(
        points={{-202,-244},{-198,-244},{-192,-244}},
        color={153,204,0},
        thickness=0.5));

    connect(valve3.portB, HX_CO2_IW.portA_a) annotation (Line(
        points={{-178,-114},{-112,-114}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC11.port, HX_CO2_IW.portA_b) annotation (Line(
        points={{-128,-124},{-128,-130},{-112,-130}},
        color={0,170,238},
        thickness=0.5));

    connect(sensor_T_degC17.port, hydraulicCapacitor1.portB) annotation (Line(
        points={{104,388},{104,384},{74,384}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_m_flow3.portA, hydraulicCapacitor1.portA) annotation (Line(
        points={{55,384},{55,384},{66,384}},
        color={0,170,238},
        thickness=0.5));
    connect(rotatoryBoundary1.rotatoryFlange, Compressor_MT.rotatoryFlange)
      annotation (Line(
        points={{158,62},{168,62},{178,62}},
        color={135,135,135},
        thickness=0.5));
    connect(rotatoryBoundary2.rotatoryFlange, Compressor_LT.rotatoryFlange)
      annotation (Line(
        points={{102,-336},{112,-336}},
        color={135,135,135},
        thickness=0.5));

    connect(tank_DHW.portB, junction9.portC) annotation (Line(
        points={{102,352},{102,352},{104,352},{104,358}},
        color={0,170,238},
        thickness=0.5));
    connect(tank_DHW.portA, junction10.portB) annotation (Line(
        points={{102,320},{104,320},{104,314},{108,314}},
        color={0,170,238},
        thickness=0.5));
    connect(junction10.portA, hydraulicCapacitor1.portB) annotation (Line(
        points={{112,310},{78,310},{78,384},{74,384}},
        color={0,170,238},
        thickness=0.5));
    connect(parallelFlowHX.portB_liq, sensor_m_flow3.portB) annotation (Line(
        points={{-32,384},{-32,384},{49,384}},
        color={0,170,238},
        thickness=0.5));
    connect(parallelFlowHX.portA_liq, simplePump.portA) annotation (Line(
        points={{-60,384},{-164,384},{-164,346}},
        color={0,170,238},
        thickness=0.5));
    connect(simpleFan2.portB, parallelFlowHX.portA_gas) annotation (Line(
        points={{-46,416},{-46,416},{-46,398}},
        color={255,153,0},
        thickness=0.5));
    connect(boundary.port, simpleFan2.portA) annotation (Line(
        points={{-46,444},{-46,444},{-46,432}},
        color={255,153,0},
        thickness=0.5));
    connect(parallelFlowHX.portB_gas, boundary1.port) annotation (Line(
        points={{-46,370},{-46,356}},
        color={255,153,0},
        thickness=0.5));
    connect(sensor_T_degC.port, simplePump.portA) annotation (Line(
        points={{-146,390},{-146,384},{-164,384},{-164,346}},
        color={0,170,238},
        thickness=0.5));
    connect(floorHeatingSetpoint3.y, greaterThreshold.u)
      annotation (Line(points={{59,414},{59,414},{52,414}},
                                                       color={0,0,127}));
    connect(junction13.portC, junction11.portB) annotation (Line(
        points={{-274,262},{-274,262},{-282,262}},
        color={0,170,238},
        thickness=0.5));
    connect(junction12.portB, junction14.portC) annotation (Line(
        points={{-282,208},{-274,208}},
        color={0,170,238},
        thickness=0.5));
    connect(tank_SH.portB, junction11.portA) annotation (Line(
        points={{-288,250},{-286,250},{-286,258}},
        color={0,170,238},
        thickness=0.5));
    connect(InletFloor2.port, junction12.portC) annotation (Line(
        points={{-332,208},{-290,208}},
        color={0,170,238},
        thickness=0.5));
    connect(InletFloor1.port, junction11.portC) annotation (Line(
        points={{-332,262},{-332,262},{-302,262},{-300,262},{-290,262}},
        color={0,170,238},
        thickness=0.5));
    connect(PI_Floor1.y, simplePump2.m_flow_in) annotation (Line(points={{-428.4,
            234},{-428.4,234},{-454,234}},        color={0,0,127}));
    connect(floorHeatingSetpoint5.y, PI_Floor1.u_s) annotation (Line(points={{-397,
            234},{-397,234},{-416.4,234}},      color={0,0,127}));
    connect(PI_Floor1.u_m, sensor_T_degC18.sensorValue) annotation (Line(points={{-422,
            228.2},{-422,226},{-430,226},{-452,226}},         color={0,0,127}));
    connect(sensor_T_degC10.port, junction8.portB) annotation (Line(
        points={{-266,-126},{-266,-130},{-250,-130}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC18.port, simplePump2.portA) annotation (Line(
        points={{-452,220},{-458,220},{-464,220},{-464,232}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC15.port, junction11.portC) annotation (Line(
        points={{-316,266},{-316,262},{-300,262},{-290,262}},
        color={0,170,238},
        thickness=0.5));
    connect(InletFloor4.port, junction15.portB) annotation (Line(
        points={{-282,-178},{-282,-178},{-250,-178}},
        color={0,170,238},
        thickness=0.5));
    connect(InletFloor3.port, junction8.portB) annotation (Line(
        points={{-280,-130},{-250,-130}},
        color={0,170,238},
        thickness=0.5));
    connect(HX1.portA_a, sensor_H_flow.portB) annotation (Line(
        points={{76,142},{87,142}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC8.port, HX1.portB_b) annotation (Line(
        points={{40,162},{40,158},{48,158}},
        color={0,170,238},
        thickness=0.5));
    connect(junction9.portA, HX1.portA_b) annotation (Line(
        points={{100,362},{88,362},{88,158},{76,158}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC1.port, HX1.portA_b) annotation (Line(
        points={{72,272},{88,272},{88,158},{76,158}},
        color={0,170,238},
        thickness=0.5));
    connect(HX2.portA_a, HX1.portB_a) annotation (Line(
        points={{-22,142},{13,142},{48,142}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC7.port, HX1.portB_a) annotation (Line(
        points={{14,146},{14,142},{48,142}},
        color={153,204,0},
        thickness=0.5));
    connect(HX3.portB_a, sensor_H_flow1.portA) annotation (Line(
        points={{-140,142},{-153,142}},
        color={153,204,0},
        thickness=0.5));
    connect(HX3.portA_a, HX2.portB_a) annotation (Line(
        points={{-112,142},{-82,142},{-50,142}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC6.port, HX2.portB_a) annotation (Line(
        points={{-90,146},{-90,142},{-50,142}},
        color={153,204,0},
        thickness=0.5));
    connect(simplePump.portB, HX3.portB_b) annotation (Line(
        points={{-164,330},{-164,330},{-164,158},{-140,158}},
        color={0,170,238},
        thickness=0.5));
    connect(HX3.portA_b, HX1.portB_b) annotation (Line(
        points={{-112,158},{-100,158},{-100,172},{30,172},{30,158},{48,158}},
        color={0,170,238},
        thickness=0.5));
    connect(Heat_Cooling.heatPort,volume. heatPort) annotation (Line(
        points={{-116,-60},{-116,-60},{-106,-60}},
        color={204,0,0},
        thickness=0.5));
    connect(PI_PumpChiller.y, simpleFan.V_flow_in) annotation (Line(points={{-119.6,
            -42},{-119.6,-42},{-106,-42}}, color={0,0,127}));
    connect(sensor_T.sensorValue, PI_PumpChiller.u_m) annotation (Line(points={
            {-108,-30},{-126,-30},{-126,-36.2}}, color={0,0,127}));
    connect(Setpoint_Cooling.y, PI_PumpChiller.u_s) annotation (Line(points={{-145,
            -42},{-145,-42},{-131.6,-42}}, color={0,0,127}));
    connect(volume.portB, simpleFan.portA) annotation (Line(
        points={{-96,-56},{-96,-50}},
        color={255,153,0},
        thickness=0.5));
    connect(simpleFan.portB, HX_Chiller.portA_gas) annotation (Line(
        points={{-96,-34},{-96,-18}},
        color={255,153,0},
        thickness=0.5));
    connect(sensor_T.port, HX_Chiller.portA_gas) annotation (Line(
        points={{-102,-30},{-96,-30},{-96,-18}},
        color={255,153,0},
        thickness=0.5));
    connect(HX_Chiller.portB_gas, volume.portA) annotation (Line(
        points={{-96,10},{-96,10},{-96,18},{-68,18},{-68,-68},{-96,-68},{-96,-64}},
        color={255,153,0},
        thickness=0.5));

    connect(sensor_T_degC19.port, volume.portA) annotation (Line(
        points={{-78,-38},{-68,-38},{-68,-68},{-96,-68},{-96,-64}},
        color={255,153,0},
        thickness=0.5));
    connect(simpleFan1.portA,volume2. portB) annotation (Line(
        points={{-130,-436},{-130,-436},{-130,-446}},
        color={255,153,0},
        thickness=0.5));
    connect(Heat_Cooling1.heatPort,volume2. heatPort) annotation (Line(
        points={{-152,-450},{-140,-450}},
        color={204,0,0},
        thickness=0.5));
    connect(PI_PumpFreezer.y, simpleFan1.V_flow_in) annotation (Line(points={{-153.6,
            -428},{-153.6,-428},{-140,-428}}, color={0,0,127}));
    connect(sensor_T2.sensorValue, PI_PumpFreezer.u_m) annotation (Line(points=
            {{-144,-410},{-160,-410},{-160,-422.2}}, color={0,0,127}));
    connect(Setpoint_Cooling1.y, PI_PumpFreezer.u_s) annotation (Line(points={{
            -175,-428},{-175,-428},{-165.6,-428}}, color={0,0,127}));
    connect(simpleFan1.portB, HX_Freezer.portA_gas) annotation (Line(
        points={{-130,-420},{-130,-420},{-130,-404}},
        color={255,153,0},
        thickness=0.5));
    connect(sensor_T2.port, HX_Freezer.portA_gas) annotation (Line(
        points={{-138,-410},{-130,-410},{-130,-404}},
        color={255,153,0},
        thickness=0.5));
    connect(HX_Freezer.portB_gas, volume2.portA) annotation (Line(
        points={{-130,-376},{-130,-376},{-130,-370},{-130,-366},{-98,-366},{-98,
            -460},{-130,-460},{-130,-454}},
        color={255,153,0},
        thickness=0.5));
    connect(sensor_T_degC14.port, volume2.portA) annotation (Line(
        points={{-110,-426},{-110,-426},{-98,-426},{-98,-460},{-130,-460},{-130,
            -454}},
        color={255,153,0},
        thickness=0.5));
    connect(valve5.portB, HX_Freezer.portA_vle) annotation (Line(
        points={{-180,-390},{-162,-390},{-144,-390}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_Freezer.portB_vle, pressureState3.portB) annotation (Line(
        points={{-116,-390},{-38,-390},{16,-390}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_superheating3.port, pressureState3.portB) annotation (Line(
        points={{-48,-384},{-48,-390},{16,-390}},
        color={153,204,0},
        thickness=0.5));
    connect(junction6.portC, junction4.portB) annotation (Line(
        points={{90,-110},{90,-110},{90,-8}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_CO2_IW.portB_a, junction6.portB) annotation (Line(
        points={{-84,-114},{2,-114},{86,-114}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_q4.port, junction6.portB) annotation (Line(
        points={{-22,-110},{-22,-114},{86,-114}},
        color={153,204,0},
        thickness=0.5));
    connect(off_value_GW.y, PI_Valve_GreyWater.y_notActive) annotation (Line(
          points={{-65,-206},{-78,-206},{-78,-210.2}}, color={0,0,127}));
   connect(not1.u,hysteresis. y) annotation (Line(points={{-18.4,-220},{-18.4,
            -220},{-12.8,-220}},
                        color={255,0,255}));
    connect(DHWT_Temp1.y, hysteresis.u) annotation (Line(points={{11.1,-220},{
            11.1,-220},{5.6,-220}}, color={0,0,127}));
    connect(not1.y, PI_Valve_GreyWater.activeInput) annotation (Line(points={{-36.8,
            -220},{-54,-220},{-54,-219.8},{-72.4,-219.8}},       color={255,0,
            255}));
    connect(junction7.portA, junction2.portC) annotation (Line(
        points={{-206,-386},{-206,-248}},
        color={153,204,0},
        thickness=0.5));
    connect(junction7.portB, valve5.portA) annotation (Line(
        points={{-202,-390},{-199,-390},{-196,-390}},
        color={153,204,0},
        thickness=0.5));
    connect(junction7.portC, valve6.portA) annotation (Line(
        points={{-206,-394},{-206,-394},{-206,-498},{-206,-500},{-62,-500}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_ValveAir.u_s, sup_heat.y) annotation (Line(points={{33.6,-446},{
            38,-446},{38,-436},{42,-436},{47,-436}}, color={0,0,127}));
    connect(PI_ValveAir.u_m, sensor_superheating4.sensorValue) annotation (Line(
          points={{28,-451.8},{28,-452},{28,-470},{78,-470},{78,-487.8}}, color=
           {0,0,127}));
    connect(PI_ValveAir.y, valve6.effectiveFlowArea_in) annotation (Line(points=
           {{21.6,-446},{-54,-446},{-54,-495}}, color={0,0,127}));
    connect(rotatoryBoundary3.rotatoryFlange, Compressor_parallell.rotatoryFlange)
      annotation (Line(
        points={{210,-464},{218,-464}},
        color={135,135,135},
        thickness=0.5));
    connect(junction16.portC, pressureState.portA) annotation (Line(
        points={{182,142},{176,142},{168,142}},
        color={153,204,0},
        thickness=0.5));
    connect(junction16.portB, sensor_m_flow.portB) annotation (Line(
        points={{186,138},{186,138},{186,113}},
        color={153,204,0},
        thickness=0.5));
    connect(junction16.portA, Compressor_parallell.portB) annotation (Line(
        points={{190,142},{226,142},{226,40},{226,-328},{226,-456}},
        color={153,204,0},
        thickness=0.5));
    connect(off_value_GW1.y, PI_ValveAir.y_notActive) annotation (Line(points={
            {47,-422},{28,-422},{28,-440.2}}, color={0,0,127}));
    connect(boundaryUnderdetermined1.port, HX_Air.portB_gas) annotation (Line(
        points={{60,-480},{32,-480},{32,-486}},
        color={255,153,0},
        thickness=0.5));
    connect(sensor_T_degC22.port, HX_Air.portB_gas) annotation (Line(
        points={{12,-480},{32,-480},{32,-486}},
        color={255,153,0},
        thickness=0.5));
    connect(off_value_GW2.y, PI_CompParallell.y_notActive) annotation (Line(
          points={{187,-446},{184,-446},{184,-458.2},{180,-458.2}}, color={0,0,
            127}));
    connect(PI_ValveCooling.u_m, sensor_q.sensorValue) annotation (Line(points={{-62,
            28.2},{-26,28.2},{-26,6.2},{6,6.2}},       color={0,0,127}));
    connect(HX_Ammonia_SH.portA_b, simplePump2.portA) annotation (Line(
        points={{-406,172},{-406,172},{-444,172},{-426,172},{-464,172},{-464,232}},
        color={0,170,238},
        thickness=0.5));
    connect(PI_Floor.y, simplePump1.m_flow_in) annotation (Line(points={{-230.4,
            240},{-236,240},{-236,218}}, color={0,0,127}));
    connect(junction14.portA, hydraulicCapacitor3.portB) annotation (Line(
        points={{-270,204},{-270,204},{-270,190},{-270,171.5},{-284,171.5}},
        color={0,170,238},
        thickness=0.5));
    connect(rotatoryBoundary4.rotatoryFlange, Compressor_propane.rotatoryFlange)
      annotation (Line(
        points={{-648,-6},{-648,-6},{-630,-6}},
        color={135,135,135},
        thickness=0.5));
    connect(asupheat.y, PI_ValveNH3.u_s) annotation (Line(points={{-399.4,-66},
            {-395.733,-66}},         color={0,0,127}));

    connect(Compressor_propane.portA, pressureState7.portA) annotation (Line(
        points={{-622,-14},{-622,-22}},
        color={153,204,0},
        thickness=0.5));
    connect(pressureState6.portB, Compressor_propane.portB) annotation (Line(
        points={{-622,8},{-622,8},{-622,2}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_m_flow13.portA, pressureState6.portA) annotation (Line(
        points={{-589,156},{-622,156},{-622,20}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_Propane_IW.portA_a, valve8.portB) annotation (Line(
        points={{-470,-94},{-420,-94},{-370,-94}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_superheating6.port,HX_Propane_IW. portB_a) annotation (Line(
        points={{-508,-92},{-508,-94},{-498,-94}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_Pump_IWC1.y, simplePump3.m_flow_in)
      annotation (Line(points={{-540.4,-154},{-550,-154}},
                                                         color={0,0,127}));
    connect(junction14.portB, simplePump1.portA) annotation (Line(
        points={{-266,208},{-238,208}},
        color={0,170,238},
        thickness=0.5));
    connect(valve1.portB, HX_Chiller.portA_vle) annotation (Line(
        points={{-178,-4},{-110,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_Chiller.portB_vle, pressureState1.portB) annotation (Line(
        points={{-82,-4},{36,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(idealSeparator1.portGas, Compressor_MT.portA) annotation (Line(
        points={{149,-4},{186,-4},{186,54}},
        color={153,204,0},
        thickness=0.5));
    connect(tank_IW.portA, junction15.portA) annotation (Line(
        points={{-246,-168},{-246,-168},{-246,-174}},
        color={0,170,238},
        thickness=0.5));
    connect(HX_CO2_IW.portB_b, Pump_IWC.portB) annotation (Line(
        points={{-84,-130},{-74,-130},{-74,-152}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_p4.port, Compressor_parallell.portA) annotation (Line(
        points={{182,-494},{182,-500},{226,-500},{226,-472}},
        color={153,204,0},
        thickness=0.5));
    connect(simplePump2.portB, junction13.portA) annotation (Line(
        points={{-464,248},{-464,248},{-464,290},{-270,290},{-270,266}},
        color={0,170,238},
        thickness=0.5));
    connect(junction10.portC, OutletDHW3.port) annotation (Line(
        points={{116,314},{160,314},{160,314}},
        color={0,170,238},
        thickness=0.5));
    connect(junction9.portB, OutletDHW2.port) annotation (Line(
        points={{104,366},{104,370},{162,370}},
        color={0,170,238},
        thickness=0.5));
    connect(tank_SH.portA, junction12.portA) annotation (Line(
        points={{-288,218},{-286,218},{-286,212}},
        color={0,170,238},
        thickness=0.5));
    connect(junction8.portC, junction17.portB) annotation (Line(
        points={{-242,-130},{-240,-130},{-236,-130}},
        color={0,170,238},
        thickness=0.5));
    connect(junction17.portC, HX_CO2_IW.portA_b) annotation (Line(
        points={{-228,-130},{-112,-130}},
        color={0,170,238},
        thickness=0.5));
    connect(HX_Propane_IW.portA_b, junction17.portA) annotation (Line(
        points={{-470,-110},{-376,-110},{-232,-110},{-232,-126}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC30.port, junction17.portA) annotation (Line(
        points={{-460,-126},{-442,-126},{-442,-110},{-232,-110},{-232,-126}},
        color={0,170,238},
        thickness=0.5));
    connect(junction15.portC, junction18.portB) annotation (Line(
        points={{-242,-178},{-242,-178},{-236,-178}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_m_flow2.portA, junction18.portA) annotation (Line(
        points={{-267,-226},{-250,-226},{-232,-226},{-232,-182}},
        color={0,170,238},
        thickness=0.5));
    connect(simplePump3.portA, sensor_m_flow2.portB) annotation (Line(
        points={{-560,-156},{-560,-156},{-560,-224},{-560,-226},{-273,-226}},
        color={0,170,238},
        thickness=0.5));
    connect(PI_Pump_IWC.y, Pump_IWC.m_flow_in) annotation (Line(points={{-46.4,
            -166},{-62,-166},{-64,-166}}, color={0,0,127}));
    connect(off_IWPump.y, PI_Pump_IWC.y_notActive) annotation (Line(points={{
            5.3,-183},{5.3,-180},{-40,-180},{-40,-171.8}}, color={0,0,127}));
    connect(switch4.y, hysteresis1.u) annotation (Line(points={{15.4,-156},{
            12.2,-156},{13.2,-156}}, color={0,0,127}));
    connect(IWT_Temp1.y, switch4.u1) annotation (Line(points={{39.1,-149},{32,
            -149},{32,-151.2},{29.2,-151.2}}, color={0,0,127}));
    connect(switch4.u3, IWT_Temp10.y) annotation (Line(points={{29.2,-160.8},{
            35.6,-160.8},{35.6,-161},{39.1,-161}}, color={0,0,127}));
    connect(hysteresis1.y, switch4.u2) annotation (Line(points={{-0.6,-156},{-2,
            -156},{-2,-164},{34,-164},{34,-156},{29.2,-156}}, color={255,0,255}));
    connect(hysteresis1.y, PI_Pump_IWC.activeInput) annotation (Line(points={{
            -0.6,-156},{-14,-156},{-14,-158},{-14,-162.2},{-34.4,-162.2}},
          color={255,0,255}));
    connect(statePoint2.sensorPort, valve8.portB) annotation (Line(
        points={{-456,-90},{-456,-94},{-370,-94}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC9.port, valve8.portB) annotation (Line(
        points={{-424,-90},{-424,-94},{-370,-94}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_m_flow4.portB,HX_Propane_IW. portB_b) annotation (Line(
        points={{-519,-110},{-508,-110},{-498,-110}},
        color={0,170,238},
        thickness=0.5));
    connect(HX_Ammonia_SH.portB_b, sensor_m_flow5.portB) annotation (Line(
        points={{-378,172},{-367,172}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_m_flow5.portA, hydraulicCapacitor3.portA) annotation (Line(
        points={{-361,172},{-328,172},{-328,171.5},{-290,171.5}},
        color={0,170,238},
        thickness=0.5));
    connect(not3.u,hysteresis2. y) annotation (Line(points={{-839.2,18},{-839.2,
            18},{-841.4,18}},          color={255,0,255}));
    connect(RelDispl1.y, PI_CompAmmonia1.u_s) annotation (Line(points={{-725.1,-48},
            {-703.6,-48}},              color={0,0,127}));
    connect(PI_CompAmmonia1.y, criticalDamping2.u) annotation (Line(points={{-691.6,
            -48},{-691.6,-48},{-682,-48}},   color={0,0,127}));
    connect(switch2.y,hysteresis2. u)
      annotation (Line(points={{-861.4,18},{-861.4,18},{-855.2,18}},
                                                         color={0,0,127}));
    connect(SHT_Temp.y, switch2.u1) annotation (Line(points={{-887.1,23},{
            -887.1,22.8},{-875.2,22.8}}, color={0,0,127}));
   connect(DHWT_Temp2.y,switch2. u3)
     annotation (Line(points={{-887.1,13},{-887.1,13.2},{-875.2,13.2}},
                                                        color={0,0,127}));
   connect(not3.y,switch2. u2) annotation (Line(points={{-825.4,18},{-814,18},{
            -814,10},{-884,10},{-884,18},{-875.2,18}},
         color={255,0,255}));
    connect(AmmoniaOff.y,switch1. u3) annotation (Line(points={{-749.2,-32},{-734,
            -32},{-734,-12},{-724,-12}}, color={0,0,127}));
    connect(AmmoniaOn.y,switch1. u1) annotation (Line(points={{-747.2,24},{-734,24},
            {-734,4},{-724,4}},          color={0,0,127}));
    connect(criticalDamping2.y, Compressor_propane.relDisplacement_in)
      annotation (Line(points={{-659,-48},{-640,-48},{-640,-12},{-633,-12}},
                                                                         color=
            {0,0,127}));
    connect(PI_ValveNH3.u_m, sensor_superheating6.sensorValue) annotation (Line(
          points={{-392,-69.8667},{-392,-69.8667},{-392,-80},{-508,-80},{-508,
            -85.8}},
          color={0,0,127}));
    connect(PI_Pump_IWC.u_s, sensor_T_degC11.sensorValue) annotation (Line(
          points={{-34.4,-166},{-26,-166},{-26,-118},{-128,-118}}, color={0,0,
            127}));
    connect(PI_Pump_IWC.u_m, Temp_IWC3.y) annotation (Line(points={{-40,-160.2},
            {-42,-160.2},{-42,-136},{-42,-137},{-6.7,-137}}, color={0,0,127}));
    connect(Temp_IWC1.y, PI_Pump_IWC1.u_s) annotation (Line(points={{-515,-154},{-528.4,
            -154}},                     color={0,0,127}));
    connect(PI_ValveIWC.activeInput, on_off_airvalve1.y) annotation (Line(
          points={{-90.4,-82.2},{-81.2,-82.2},{-81.2,-87},{-74.8,-87}}, color={
            255,0,255}));
    connect(boundary2.port,HX_propaneAir. portB_gas) annotation (Line(
        points={{-460,42},{-460,34},{-460,30}},
        color={255,153,0},
        thickness=0.5));
    connect(valve7.portB,HX_propaneAir. portA_vle) annotation (Line(
        points={{-382,16},{-446,16}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_superheating1.port,HX_propaneAir. portB_vle) annotation (
        Line(
        points={{-508,22},{-508,16},{-474,16}},
        color={153,204,0},
        thickness=0.5));
    connect(asupheat3.y, PI_ValveNH1.u_s) annotation (Line(points={{-415.5,-12},
            {-415.5,-12},{-409.733,-12}},         color={0,0,127}));
    connect(junction20.portC, valve8.portA) annotation (Line(
        points={{-304,-50},{-304,-50},{-304,-94},{-304,-94},{-304,-94},{-354,-94}},
        color={153,204,0},
        thickness=0.5));
    connect(junction20.portA, valve7.portA) annotation (Line(
        points={{-304,-42},{-304,16},{-366,16}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_Ammonia_SH.portB_a, junction20.portB) annotation (Line(
        points={{-378,156},{-378,156},{-262,156},{-262,-46},{-300,-46}},
        color={153,204,0},
        thickness=0.5));

    connect(switch1.y, criticalDamping1.u) annotation (Line(points={{-701,-4},{-692,
            -4},{-692,-6},{-686,-6}},          color={0,0,127}));
    connect(rotatoryBoundary4.n_in, criticalDamping1.y) annotation (Line(points={{-652,-6},
            {-663,-6}},                        color={0,0,127}));
    connect(on_off_airvalve4.y, PI_Floor1.activeInput) annotation (Line(points={{-394.8,
            220},{-402,220},{-402,230.2},{-416.4,230.2}},          color={255,0,
            255}));
    connect(asupheat5.y, PI_Floor1.y_notActive) annotation (Line(points={{
            -427.3,254},{-424,254},{-424,239.8},{-422,239.8}}, color={0,0,127}));
    connect(PI_Pump_IWC1.u_m, sensor_T_degC30.sensorValue) annotation (Line(
          points={{-534,-148.2},{-534,-148.2},{-534,-124},{-460,-124},{-460,-120}},
                       color={0,0,127}));
    connect(PI_Pump_IWC1.y_notActive, asupheat4.y) annotation (Line(points={{-534,
            -159.8},{-534,-172},{-535.3,-172}},   color={0,0,127}));
    connect(not2.y, and1.u1) annotation (Line(points={{-535.5,-35},{-535.5,-35},{-529,
            -35}},               color={255,0,255}));
    connect(on_off_airvalve2.y, and1.u2) annotation (Line(points={{-535.3,-49},{-534,
            -49},{-534,-39},{-529,-39}}, color={255,0,255}));
    connect(on_off_airvalve2.y, and2.u1) annotation (Line(points={{-535.3,-49},{-534,
            -49},{-534,-55},{-529,-55}},   color={255,0,255}));
    connect(fileReader.tfr_signals,realVariableName. tfr_signals)
      annotation (Line(points={{194,408},{194,408},{194,394}},
                                                         color={127,0,0}));
    connect(realVariableName.value, OutletDHW2.m_flow_in) annotation (Line(
          points={{182,386},{174,386},{174,372},{166,372}}, color={0,0,127}));
    connect(simpleFan3.portA, boundary3.port) annotation (Line(
        points={{-460,-22},{-460,-30}},
        color={255,153,0},
        thickness=0.5));
    connect(asupheat6.y, switch5.u1) annotation (Line(points={{-491.5,-9},{-491.5,
            -9},{-490,-9},{-487,-9}},
                                   color={0,0,127}));
    connect(PI_ValveNH3.y, criticalDamping3.u) annotation (Line(points={{
            -387.733,-66},{-387.733,-66},{-380.8,-66}},        color={0,0,127}));
    connect(criticalDamping3.y, valve8.effectiveFlowArea_in) annotation (Line(
          points={{-371.6,-66},{-362,-66},{-362,-89}},            color={0,0,
            127}));
    connect(criticalDamping4.u, PI_ValveNH1.y)
      annotation (Line(points={{-394.8,-12},{-401.733,-12}},
                                                           color={0,0,127}));
    connect(Superheat_realinput4.y, PI_ValveIWC.y_notActive) annotation (Line(
          points={{-70.9,-106},{-70.9,-106},{-96,-106},{-96,-91.8}}, color={0,0,
            127}));
    connect(criticalDamping5.u, PI_ValveIWC.y) annotation (Line(points={{-112.8,
            -86},{-104,-86},{-102.4,-86}},            color={0,0,127}));
    connect(criticalDamping5.y, valve3.effectiveFlowArea_in) annotation (Line(
          points={{-126.6,-86},{-186,-86},{-186,-90},{-186,-109}},
          color={0,0,127}));
    connect(realVariableSC.value, InletFloor3.m_flow_in) annotation (Line(
          points={{-304,-128},{-284,-128}},             color={0,0,127}));
    connect(switch6.y,hysteresis3. u) annotation (Line(points={{-861.4,-12},{
            -868,-12},{-853.2,-12}}, color={0,0,127}));
    connect(idealSeparator3.portGas, Compressor_parallell.portA) annotation (
        Line(
        points={{157,-500},{226,-500},{226,-472}},
        color={153,204,0},
        thickness=0.5));
    connect(idealSeparator3.portInlet, HX_Air.portB_vle) annotation (Line(
        points={{147,-500},{46,-500}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_superheating4.port, HX_Air.portB_vle) annotation (Line(
        points={{78,-494},{80,-494},{80,-500},{46,-500}},
        color={153,204,0},
        thickness=0.5));
    connect(asupheat8.y,switch7. u1) annotation (Line(points={{-81.3,-558},{-72,
            -558},{-64,-558}},     color={0,0,127}));
    connect(boundaryOverdetermined1.port, simpleFan4.portA) annotation (Line(
        points={{-34,-530},{-16,-530}},
        color={255,153,0},
        thickness=0.5));
    connect(simpleFan4.portB, HX_Air.portA_gas) annotation (Line(
        points={{0,-530},{32,-530},{32,-514}},
        color={255,153,0},
        thickness=0.5));
    connect(switch7.y, simpleFan4.V_flow_in) annotation (Line(points={{-41,-566},
            {-28,-566},{-8,-566},{-8,-540}}, color={0,0,127}));
    connect(asupheat9.y, switch7.u3) annotation (Line(points={{-81.3,-574},{
            -72.65,-574},{-64,-574}}, color={0,0,127}));
    connect(on_off_airvalve3.y, switch7.u2) annotation (Line(points={{-103,-566},
            {-98,-566},{-64,-566}}, color={255,0,255}));
    connect(fileReader2.tfr_signals, realVariableSC1.tfr_signals) annotation (
        Line(points={{-374,268},{-368,268},{-368,282},{-358,282},{-358,272}},
          color={127,0,0}));
    connect(realVariableSC1.value, InletFloor1.m_flow_in) annotation (Line(
          points={{-346,264},{-340,264},{-336,264}}, color={0,0,127}));
    connect(switch9.u2, not1.y) annotation (Line(points={{-2.8,-256},{-4,-256},
            {-4,-234},{-36.8,-234},{-36.8,-220}},  color={255,0,255}));
    connect(switch9.u3, off_IWPump1.y) annotation (Line(points={{-2.8,-260.8},{
            -2.4,-260.8},{-2.4,-261},{5.3,-261}},     color={0,0,127}));
    connect(switch9.u1, off_IWPump2.y) annotation (Line(points={{-2.8,-251.2},{
            -1.4,-251.2},{-1.4,-251},{5.3,-251}},     color={0,0,127}));
    connect(off_value_GW5.y, PI_CompParallell.u_s) annotation (Line(points={{
            155,-454},{164,-454},{164,-464},{174.4,-464}}, color={0,0,127}));
    connect(Bypass_Pressure5.y, PI_CompParallell.u_m) annotation (Line(points={
            {155,-484},{168,-484},{168,-482},{180,-482},{180,-469.8}}, color={0,
            0,127}));
    connect(pressureState5.portA, HX_Air.portA_vle) annotation (Line(
        points={{-10,-500},{4,-500},{18,-500}},
        color={153,204,0},
        thickness=0.5));
    connect(pressureState5.portB, valve6.portB) annotation (Line(
        points={{-22,-500},{-46,-500},{-46,-500}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_ValveIWC.u_m, sensor_q4.sensorValue) annotation (Line(points={{
            -96,-80.2},{-96,-72},{-22,-72},{-22,-103.8}}, color={0,0,127}));
    connect(not5.u, hysteresis5.y) annotation (Line(points={{123.6,-422},{123.6,
            -422},{129.2,-422}}, color={255,0,255}));
    connect(not5.y, PI_ValveAir.activeInput) annotation (Line(points={{105.2,
            -422},{76,-422},{76,-452},{33.6,-452},{33.6,-449.8}}, color={255,0,
            255}));
    connect(not5.y, PI_CompParallell.activeInput) annotation (Line(points={{
            105.2,-422},{100,-422},{100,-462},{100,-467.8},{174.4,-467.8}},
          color={255,0,255}));
    connect(PI_LP_Comp.y, Compressor_LT.relDisplacement_in)
      annotation (Line(points={{94.4,-342},{109,-342}},color={0,0,127}));
    connect(PI_LP_Comp.u_m, sensor_p3.sensorValue)
      annotation (Line(points={{88,-347.8},{88,-367.8}}, color={0,0,127}));
    connect(boundaryUnderdetermined.port, GreyWater_HX.portB_liq) annotation (
        Line(
        points={{-160,-258},{-118,-258}},
        color={0,170,238},
        thickness=0.5));
    connect(GreyWater_HX.portA_liq, boundaryOverdetermined.port) annotation (Line(
        points={{-90,-258},{-70,-258},{-50,-258}},
        color={0,170,238},
        thickness=0.5));
    connect(valve4.portB, GreyWater_HX.portA_vle) annotation (Line(
        points={{-176,-244},{-111.778,-244}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_CompParallell.y, Compressor_parallell.relDisplacement_in)
      annotation (Line(points={{186.4,-464},{200,-464},{200,-470},{215,-470}},
          color={0,0,127}));
    connect(PI_Comp.y, Compressor_MT.relDisplacement_in) annotation (Line(points={
            {148.4,46},{150,46},{175,46},{175,56}}, color={0,0,127}));
    connect(sensor_p2.sensorValue, PI_Comp.u_m)
      annotation (Line(points={{142,34.2},{142,40.2}}, color={0,0,127}));
    connect(sensor_m_flow1.portA, junction18.portC) annotation (Line(
        points={{-197,-178},{-212,-178},{-228,-178}},
        color={0,170,238},
        thickness=0.5));
    connect(hydraulicCapacitor2.portA, sensor_m_flow1.portB) annotation (Line(
        points={{-146,-178.5},{-168,-178.5},{-168,-178},{-191,-178}},
        color={0,170,238},
        thickness=0.5));
    connect(hydraulicCapacitor2.portB, Pump_IWC.portA) annotation (Line(
        points={{-140,-178.5},{-74,-178.5},{-74,-168}},
        color={0,170,238},
        thickness=0.5));
    connect(tank_IW.portB, junction8.portA) annotation (Line(
        points={{-246,-140},{-246,-140},{-246,-134}},
        color={0,170,238},
        thickness=0.5));
    connect(criticalDamping6.u, PI_Valve_GreyWater.y)
      annotation (Line(points={{-96.8,-216},{-84.4,-216}}, color={0,0,127}));
    connect(criticalDamping6.y, valve4.effectiveFlowArea_in) annotation (Line(
          points={{-110.6,-216},{-146,-216},{-184,-216},{-184,-239}}, color={0,
            0,127}));
    connect(criticalDamping7.u, switch9.y)
      annotation (Line(points={{-24.8,-256},{-16.6,-256}}, color={0,0,127}));
    connect(criticalDamping7.y, boundaryOverdetermined.m_flow_in) annotation (
        Line(points={{-38.6,-256},{-38.6,-256},{-46,-256}}, color={0,0,127}));
    connect(junction1.portA, idealSeparator1.portInlet) annotation (Line(
        points={{124,-4},{124,-4},{139,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(junction1.portC, junction4.portA) annotation (Line(
        points={{116,-4},{116,-4},{94,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(GreyWater_HX.portB_vle, junction6.portA) annotation (Line(
        points={{-96.2222,-272},{-70,-272},{-70,-242},{84,-242},{84,-118},{90,
            -118}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_superheating2.port, GreyWater_HX.portB_vle) annotation (Line(
        points={{-78,-236},{-70,-236},{-70,-272},{-96.2222,-272}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_Valve_GreyWater.u_m, sensor_superheating2.sensorValue)
      annotation (Line(points={{-78,-221.8},{-78,-221.8},{-78,-229.8}}, color={
            0,0,127}));
    connect(simplePump3.portB, sensor_m_flow4.portA) annotation (Line(
        points={{-560,-140},{-560,-140},{-560,-110},{-525,-110}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC5.port, junction13.portB) annotation (Line(
        points={{-200,270},{-200,262},{-266,262}},
        color={0,170,238},
        thickness=0.5));
    connect(HX2.portA_b, junction13.portB) annotation (Line(
        points={{-22,158},{-4,158},{-4,158},{14,158},{14,262},{-266,262}},
        color={0,170,238},
        thickness=0.5));
    connect(not4.u,hysteresis4. y) annotation (Line(points={{-94.4,236},{-94.4,
            236},{-88.8,236}},         color={255,0,255}));
    connect(switch8.y,hysteresis4. u) annotation (Line(points={{-63,234},{-66,
            234},{-66,236},{-70.4,236}}, color={0,0,127}));
    connect(not4.y,switch8. u2) annotation (Line(points={{-112.8,236},{-114,236},
            {-114,260},{-32,260},{-32,234},{-40,234}}, color={255,0,255}));
    connect(PI_Floor.activeInput, not4.y) annotation (Line(points={{-218.4,
            243.8},{-196,243.8},{-196,252},{-112.8,252},{-112.8,236}}, color={
            255,0,255}));
    connect(floorHeatingSetpoint2.y, PI_Floor.y_notActive) annotation (Line(
          points={{-207,224},{-216,224},{-224,224},{-224,234.2}}, color={0,0,
            127}));
    connect(tube.portA, simplePump1.portB) annotation (Line(
        points={{-152,208},{-222,208}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC4.port, simplePump1.portB) annotation (Line(
        points={{-178,210},{-178,210},{-178,208},{-222,208}},
        color={0,170,238},
        thickness=0.5));
    connect(tube.portB, HX2.portB_b) annotation (Line(
        points={{-136,208},{-68,208},{-68,158},{-50,158}},
        color={0,170,238},
        thickness=0.5));
    connect(switch8.u3, DHWT_Temp4.y) annotation (Line(points={{-40,226},{-28.9,226}},
                               color={0,0,127}));
    connect(switch8.u1, DHWT_Temp3.y) annotation (Line(points={{-40,242},{-26.9,242}},
                               color={0,0,127}));
    connect(tube1.heatPort, tube.heatPort) annotation (Line(
        points={{122,-168},{236,-168},{326,-168},{326,218},{-144,218},{-144,210}},
        color={204,0,0},
        thickness=0.5));

    connect(tube1.portA, junction1.portB) annotation (Line(
        points={{120,-160},{120,-8}},
        color={153,204,0},
        thickness=0.5));
    connect(Compressor_LT.portB, tube1.portB) annotation (Line(
        points={{120,-328},{120,-328},{120,-176}},
        color={153,204,0},
        thickness=0.5));
    connect(IWT_Temp2.y, switch6.u1) annotation (Line(points={{-889.1,-7},{
            -889.55,-7},{-889.55,-7.2},{-875.2,-7.2}}, color={0,0,127}));
    connect(IWT_Temp3.y, switch6.u3) annotation (Line(points={{-889.1,-17},{
            -875.2,-17},{-875.2,-16.8}},
                                       color={0,0,127}));
    connect(hysteresis3.y, switch6.u2) annotation (Line(points={{-839.4,-12},{
            -834,-12},{-834,-22},{-882,-22},{-882,-12},{-875.2,-12}},
                                                                 color={255,0,
            255}));
    connect(on_off_propane_valves1.y, PI_Pump_IWC1.activeInput) annotation (
        Line(points={{-510.8,-142},{-520,-142},{-520,-150.2},{-528.4,-150.2}},
          color={255,0,255}));
    connect(HX_propaneDump.portB_vle, HX_Ammonia_SH.portA_a) annotation (Line(
        points={{-504,156},{-504,156},{-406,156}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_propaneDump.portA_vle, sensor_m_flow13.portB) annotation (Line(
        points={{-532,156},{-583,156}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC2.port, sensor_m_flow13.portB) annotation (Line(
        points={{-566,160},{-566,156},{-583,156}},
        color={153,204,0},
        thickness=0.5));
    connect(statePoint.sensorPort, sensor_m_flow13.portB) annotation (Line(
        points={{-548,160},{-548,156},{-583,156}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_propaneDump.portB_gas, boundary4.port) annotation (Line(
        points={{-518,142},{-518,118}},
        color={255,153,0},
        thickness=0.5));
    connect(simpleFan5.portB,HX_propaneDump. portA_gas) annotation (Line(
        points={{-536,200},{-518,200},{-518,170}},
        color={255,153,0},
        thickness=0.5));
    connect(asupheat10.y, switch10.u1)
      annotation (Line(points={{-635.3,226},{-630,226}}, color={0,0,127}));
    connect(asupheat11.y, switch10.u3) annotation (Line(points={{-635.3,210},{-635.3,
            210},{-630,210}},        color={0,0,127}));
    connect(on_off_propane_valves2.y, and3.u1) annotation (Line(points={{-679.2,222},
            {-672,222},{-672,218},{-669.2,218}},      color={255,0,255}));
    connect(on_off_propane_valves3.y, and3.u2) annotation (Line(points={{-679.2,212},
            {-672,212},{-672,213.2},{-669.2,213.2}},      color={255,0,255}));
    connect(boundary5.port, simpleFan5.portA) annotation (Line(
        points={{-574,200},{-564,200},{-552,200}},
        color={255,153,0},
        thickness=0.5));
    connect(switch10.y, criticalDamping8.u) annotation (Line(points={{-607,218},{-602.5,
            218},{-598,218}}, color={0,0,127}));
    connect(criticalDamping8.y, simpleFan5.V_flow_in) annotation (Line(points={{-575,
            218},{-544,218},{-544,210}}, color={0,0,127}));
    connect(fileReader1.tfr_signals, realVariableSC.tfr_signals) annotation (Line(
          points={{-316,-146},{-316,-141},{-316,-136}}, color={127,0,0}));
    connect(junction19.portC, sensor_superheating6.port) annotation (Line(
        points={{-590,-50},{-590,-94},{-508,-94},{-508,-92},{-508,-92}},
        color={153,204,0},
        thickness=0.5));
    connect(junction19.portA, HX_propaneAir.portB_vle) annotation (Line(
        points={{-590,-42},{-590,16},{-474,16}},
        color={153,204,0},
        thickness=0.5));
    connect(junction19.portB, pressureState7.portB) annotation (Line(
        points={{-594,-46},{-622,-46},{-622,-34}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_ValveNH1.u_m, sensor_superheating1.sensorValue) annotation (Line(
          points={{-406,-8.13333},{-406,-8.13333},{-406,32},{-508,32},{-508,
            28.2}},
          color={0,0,127}));
    connect(simpleFan3.portB, HX_propaneAir.portA_gas) annotation (Line(
        points={{-460,-6},{-460,2}},
        color={255,153,0},
        thickness=0.5));
    connect(switch5.y, simpleFan3.V_flow_in) annotation (Line(points={{-475.5,-13},
            {-475.5,-14},{-470,-14}}, color={0,0,127}));
    connect(asupheat7.y, switch5.u3) annotation (Line(points={{-491.5,-17},{-491.5,
            -17},{-487,-17}}, color={0,0,127}));
    connect(criticalDamping4.y, valve7.effectiveFlowArea_in) annotation (Line(
          points={{-385.6,-12},{-385.6,-12},{-374,-12},{-374,11}}, color={0,0,127}));
    connect(and1.y, switch5.u2) annotation (Line(points={{-517.5,-35},{-512,-35},{
            -490,-35},{-490,-13},{-487,-13}}, color={255,0,255}));
    connect(and1.y, PI_ValveNH1.activeInput) annotation (Line(points={{-517.5,
            -35},{-414,-35},{-414,-9.46667},{-409.733,-9.46667}},
                                                             color={255,0,255}));
    connect(not2.u, on_off_propane_valves.y) annotation (Line(points={{-547,-35},{
            -557.4,-35},{-557.4,-48}}, color={255,0,255}));
    connect(on_off_propane_valves.y, and2.u2) annotation (Line(points={{-557.4,-48},
            {-558,-48},{-558,-58},{-558,-59},{-529,-59}}, color={255,0,255}));
    connect(and2.y, PI_ValveNH3.activeInput) annotation (Line(points={{-517.5,
            -55},{-416,-55},{-416,-68.5333},{-395.733,-68.5333}},
                                                             color={255,0,255}));
    connect(statePoint3.sensorPort, junction20.portB) annotation (Line(
        points={{-328,160},{-328,156},{-262,156},{-262,-46},{-300,-46}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC23.port, junction20.portB) annotation (Line(
        points={{-346,160},{-346,156},{-262,156},{-262,-46},{-300,-46}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC12.port, junction20.portB) annotation (Line(
        points={{-306,160},{-306,156},{-262,156},{-262,-46},{-300,-46}},
        color={153,204,0},
        thickness=0.5));
    connect(asupheat1.y, switch11.u1) annotation (Line(points={{-457.5,-43},{-457.5,
            -43},{-451,-43}}, color={0,0,127}));
    connect(asupheat2.y, switch11.u3)
      annotation (Line(points={{-457.5,-51},{-451,-51}}, color={0,0,127}));
    connect(switch11.y, PI_ValveNH1.y_notActive) annotation (Line(points={{-439.5,
            -47},{-406,-47},{-406,-15.8667}}, color={0,0,127}));
    connect(switch11.y, PI_ValveNH3.y_notActive) annotation (Line(points={{-439.5,
            -47},{-392,-47},{-392,-62.1333}}, color={0,0,127}));
    connect(on_off_airvalve2.y, switch11.u2) annotation (Line(points={{-535.3,-49},
            {-534,-49},{-534,-46},{-451,-46},{-451,-47}}, color={255,0,255}));
    connect(and3.y, switch10.u2) annotation (Line(points={{-655.4,218},{-630,218}},
                         color={255,0,255}));
    connect(not3.y, PI_CompAmmonia1.activeInput) annotation (Line(points={{-825.4,
            18},{-820,18},{-814,18},{-814,-51.8},{-703.6,-51.8}}, color={255,0,255}));
    connect(RelDispl2.y, PI_CompAmmonia1.y_notActive) annotation (Line(points={{-703.1,
            -34},{-698,-34},{-698,-42.2}}, color={0,0,127}));
    connect(sensor_p5.port, pressureState6.portA) annotation (Line(
        points={{-610,166},{-610,156},{-622,156},{-622,20}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_p6.port, pressureState7.portB) annotation (Line(
        points={{-602,-40},{-604,-40},{-604,-46},{-622,-46},{-622,-34}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC13.port, OutletDHW2.port) annotation (Line(
        points={{138,376},{138,376},{138,370},{162,370}},
        color={0,170,238},
        thickness=0.5));
    connect(or2.y, switch1.u2)
      annotation (Line(points={{-745,-4},{-724,-4}}, color={255,0,255}));
    connect(not3.y, or2.u1) annotation (Line(points={{-825.4,18},{-804,18},{
            -768,18},{-768,-4}}, color={255,0,255}));
    connect(hysteresis3.y, or2.u2) annotation (Line(points={{-839.4,-12},{-804,
            -12},{-768,-12}}, color={255,0,255}));
    connect(switch12.y, hysteresis5.u) annotation (Line(points={{153.4,-420},{150,
            -420},{150,-422},{147.6,-422}}, color={0,0,127}));
    connect(DHWT_Temp6.y, switch12.u1) annotation (Line(points={{175.1,-414},{167.2,
            -414},{167.2,-415.2}}, color={0,0,127}));
    connect(DHWT_Temp5.y, switch12.u3) annotation (Line(points={{177.1,-426},{170,
            -426},{170,-424.8},{167.2,-424.8}}, color={0,0,127}));
    connect(not5.y, switch12.u2) annotation (Line(points={{105.2,-422},{100,-422},
            {100,-436},{172,-436},{172,-420},{167.2,-420}}, color={255,0,255}));
    connect(PI_DHWdump.y, simpleFan2.V_flow_in) annotation (Line(points={{-16.4,424},
            {-28,424},{-36,424}}, color={0,0,127}));
    connect(greaterThreshold.y, PI_DHWdump.activeInput) annotation (Line(points={{
            29,414},{14,414},{-4.4,414},{-4.4,420.2}}, color={255,0,255}));
    connect(PI_DHWdump.u_m, sensor_T_degC.sensorValue) annotation (Line(points={{-10,
            418.2},{-10,418.2},{-10,408},{-10,404},{-146,404},{-146,396}}, color={
            0,0,127}));
    connect(floorHeatingSetpoint4.y, PI_DHWdump.y_notActive) annotation (Line(
          points={{27,448},{8,448},{-10,448},{-10,429.8}}, color={0,0,127}));
    connect(floorHeatingSetpoint6.y, PI_DHWdump.u_s) annotation (Line(points={{31,
            430},{14,430},{14,424},{-4.4,424}}, color={0,0,127}));
    connect(comControl.y1, PI_CompAmmonia1.u_m) annotation (Line(points={{-756.7,-79.5},
            {-698,-79.5},{-698,-53.8}}, color={0,0,127}));
    annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-920,
              -460},{280,480}})), Diagram(coordinateSystem(preserveAspectRatio=false,
                     extent={{-920,-460},{280,480}}), graphics={Text(
            extent={{-220,-176},{-236,-168}},
            lineColor={0,0,0},
            textString="IWT Top"), Text(
            extent={{-208,-148},{-236,-136}},
            lineColor={0,0,0},
            textString="IWT Bottom
          ")}));
  end Winter_run;
  annotation (uses(
      TIL(version="3.4.0"),
      TILMedia(version="3.4.0"),
      Modelica(version="3.2.1"),
      TILFileReader(version="3.3.2")));
  model Summer_run
    output Real COP_total_CO2=(tube.summary.Q_flow_liq+GC1_Q+GC2_Q+GC3_Q+HX_CO2_IW_Q+HX_RefRoom_Q+HX_Freezer_Q-HX_DHWdump_Q)/(Comp_MT_W+Comp_LT_W+Com_Parll_W);
    output Real COP_h_CO2=(tube.summary.Q_flow_liq+GC1_Q+GC2_Q+GC3_Q-HX_DHWdump_Q)/(Comp_MT_W+Comp_LT_W+Com_Parll_W);
    output Real COP_h_CO2_noD=(tube.summary.Q_flow_liq+GC1_Q+GC2_Q+GC3_Q)/(Comp_MT_W+Comp_LT_W+Com_Parll_W);
    output Real COP_c_CO2=(HX_CO2_IW_Q+HX_RefRoom_Q+HX_Freezer_Q)/(Comp_MT_W+Comp_LT_W+Com_Parll_W);
    output Real COP_h_Prop=(HX_ProSH/Comp_Pro_W);
    output Real COP_c_Prop=(HX_ProIW/Comp_Pro_W);
    output Real Q_SH_Demand=(InletFloor1.summary.h-InletFloor2.summary.h)*InletFloor1.m_flow_in;

    output Real T_GC_CO2out=sensor_T_degC3.sensorValue;
    output Real q_HP_valve_CO2=sensor_q3.sensorValue;
    output Real p_HP_Prop=sensor_p5.sensorValue;
    output Real p_LP_Prop=sensor_p6.sensorValue;
    output Real T_IW_consumer=sensor_T_degC10.sensorValue;
    output Real T_SH_consumer=sensor_T_degC15.sensorValue;
    output Real T_DHW_consumer=sensor_T_degC13.sensorValue;

    output Real Comp_MT_W;
    output Real Comp_MT_reldisp;
    output Real Comp_LT_W;
    output Real Comp_LT_reldisp;
    output Real Com_Parll_reldisp;
    output Real Com_Parll_W;
    output Real Comp_Pro_W;
    output Real Comp_Pro_reldisp;

    output Real Prop_HP_ON=Compressor_propane.n;

    output Real GC1_Q;
    output Real GC2_Q;
    output Real GC3_Q;
    output Real GC_total=add_GasCooler.y;
     output Real HX_CO2_IW_Q;
    output Real HX_DHWdump_Q;
    output Real HX_RefRoom_Q;
    output Real HX_Freezer_Q;
    output Real HX_CO2air;
    output Real HX_ProSH;
    output Real HX_ProIW;
    output Real HX_ProDump=-HX_propaneDump.summary.Q_flow_vle;

    output Real tankSH_1=tank_SH.summary.arrays.T_degC_liq_cell[1];
    output Real tankSH_2=tank_SH.summary.arrays.T_degC_liq_cell[2];
    output Real tankSH_3=tank_SH.summary.arrays.T_degC_liq_cell[3];
    output Real tankSH_4=tank_SH.summary.arrays.T_degC_liq_cell[4];
    output Real tankSH_5=tank_SH.summary.arrays.T_degC_liq_cell[5];
    output Real tankSH_6=tank_SH.summary.arrays.T_degC_liq_cell[6];
    output Real tankSH_7=tank_SH.summary.arrays.T_degC_liq_cell[7];
    output Real tankSH_8=tank_SH.summary.arrays.T_degC_liq_cell[8];
    output Real tankSH_9=tank_SH.summary.arrays.T_degC_liq_cell[9];
    output Real tankSH_10=tank_SH.summary.arrays.T_degC_liq_cell[10];
    output Real tankSH_11=tank_SH.summary.arrays.T_degC_liq_cell[11];
    output Real tankSH_12=tank_SH.summary.arrays.T_degC_liq_cell[12];
    output Real tankSH_13=tank_SH.summary.arrays.T_degC_liq_cell[13];
    output Real tankSH_14=tank_SH.summary.arrays.T_degC_liq_cell[14];
    output Real tankSH_15=tank_SH.summary.arrays.T_degC_liq_cell[15];
    output Real tankSH_16=tank_SH.summary.arrays.T_degC_liq_cell[16];
    output Real tankSH_17=tank_SH.summary.arrays.T_degC_liq_cell[17];
    output Real tankSH_18=tank_SH.summary.arrays.T_degC_liq_cell[18];
    output Real tankSH_19=tank_SH.summary.arrays.T_degC_liq_cell[19];
    output Real tankSH_20=tank_SH.summary.arrays.T_degC_liq_cell[20];

    output Real tankIW_1=tank_IW.summary.arrays.T_degC_liq_cell[1];
    output Real tankIW_2=tank_IW.summary.arrays.T_degC_liq_cell[2];
    output Real tankIW_3=tank_IW.summary.arrays.T_degC_liq_cell[3];
    output Real tankIW_4=tank_IW.summary.arrays.T_degC_liq_cell[4];
    output Real tankIW_5=tank_IW.summary.arrays.T_degC_liq_cell[5];
    output Real tankIW_6=tank_IW.summary.arrays.T_degC_liq_cell[6];
    output Real tankIW_7=tank_IW.summary.arrays.T_degC_liq_cell[7];
    output Real tankIW_8=tank_IW.summary.arrays.T_degC_liq_cell[8];
    output Real tankIW_9=tank_IW.summary.arrays.T_degC_liq_cell[9];
    output Real tankIW_10=tank_IW.summary.arrays.T_degC_liq_cell[10];
    output Real tankIW_11=tank_IW.summary.arrays.T_degC_liq_cell[11];
    output Real tankIW_12=tank_IW.summary.arrays.T_degC_liq_cell[12];
    output Real tankIW_13=tank_IW.summary.arrays.T_degC_liq_cell[13];
    output Real tankIW_14=tank_IW.summary.arrays.T_degC_liq_cell[14];
    output Real tankIW_15=tank_IW.summary.arrays.T_degC_liq_cell[15];
    output Real tankIW_16=tank_IW.summary.arrays.T_degC_liq_cell[16];
    output Real tankIW_17=tank_IW.summary.arrays.T_degC_liq_cell[17];
    output Real tankIW_18=tank_IW.summary.arrays.T_degC_liq_cell[18];
    output Real tankIW_19=tank_IW.summary.arrays.T_degC_liq_cell[19];
    output Real tankIW_20=tank_IW.summary.arrays.T_degC_liq_cell[20];

    output Real tankDHW_1=tank_DHW.summary.arrays.T_degC_liq_cell[1];
    output Real tankDHW_2=tank_DHW.summary.arrays.T_degC_liq_cell[2];
    output Real tankDHW_3=tank_DHW.summary.arrays.T_degC_liq_cell[3];
    output Real tankDHW_4=tank_DHW.summary.arrays.T_degC_liq_cell[4];
    output Real tankDHW_5=tank_DHW.summary.arrays.T_degC_liq_cell[5];
    output Real tankDHW_6=tank_DHW.summary.arrays.T_degC_liq_cell[6];
    output Real tankDHW_7=tank_DHW.summary.arrays.T_degC_liq_cell[7];
    output Real tankDHW_8=tank_DHW.summary.arrays.T_degC_liq_cell[8];
    output Real tankDHW_9=tank_DHW.summary.arrays.T_degC_liq_cell[9];
    output Real tankDHW_10=tank_DHW.summary.arrays.T_degC_liq_cell[10];
    output Real tankDHW_11=tank_DHW.summary.arrays.T_degC_liq_cell[11];
    output Real tankDHW_12=tank_DHW.summary.arrays.T_degC_liq_cell[12];
    output Real tankDHW_13=tank_DHW.summary.arrays.T_degC_liq_cell[13];
    output Real tankDHW_14=tank_DHW.summary.arrays.T_degC_liq_cell[14];
    output Real tankDHW_15=tank_DHW.summary.arrays.T_degC_liq_cell[15];
    output Real tankDHW_16=tank_DHW.summary.arrays.T_degC_liq_cell[16];
    output Real tankDHW_17=tank_DHW.summary.arrays.T_degC_liq_cell[17];
    output Real tankDHW_18=tank_DHW.summary.arrays.T_degC_liq_cell[18];
    output Real tankDHW_19=tank_DHW.summary.arrays.T_degC_liq_cell[19];
    output Real tankDHW_20=tank_DHW.summary.arrays.T_degC_liq_cell[20];

    inner TIL.SystemInformationManager sim(redeclare
        TILMedia.VLEFluidTypes.TILMedia_CO2 vleFluidType1,
      redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType1,
      redeclare TILMedia.LiquidTypes.TILMedia_Water liquidType2,
      redeclare TILMedia.GasTypes.TILMedia_MoistAir gasType2,
      redeclare Refprop_Propane vleFluidType2,
      redeclare TILMedia.GasTypes.TILMedia_MoistAir gasType1,
      removeSingularity=true)
      annotation (Placement(transformation(extent={{186,276},{206,296}})));

    TIL.LiquidComponents.Pumps.SimplePump simplePump(
      presetVariableType="m_flow",
      use_volumeFlowRateInput=false,
      m_flowFixed=0.3,
      use_massFlowRateInput=true)
                annotation (Placement(transformation(
          extent={{-8,-8},{8,8}},
          rotation=180,
          origin={-164,338})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC
      annotation (Placement(transformation(extent={{-150,390},{-142,398}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC1
      annotation (Placement(transformation(extent={{68,272},{76,280}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC3
      annotation (Placement(transformation(extent={{-194,146},{-186,154}})));

    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState(pInitial=
          10000000)
      annotation (Placement(transformation(extent={{156,136},{168,148}})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint1(stateViewerIndex=1)
      annotation (Placement(transformation(extent={{128,146},{136,154}})));
    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX       HX2(
      pressureStateID=1,
      initVLEFluid_a="linearEnthalpyDistribution",
      initHeatTransfer_a="alpha",
      m_flowStart_b=PI_Floor.yInitial,
      pStart_a=pressureState.pInitial,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.Plate.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      initLiquid_b="linearTemperatureDistribution",
      m_flowStart_a=0.2,
      hInitialVLEFluid_a_CellN=260e3,
      hInitialVLEFluid_a_Cell1=354e3,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      nCells=3,
      redeclare TIL.HeatExchangers.Plate.Geometry.PlateGeometry hxGeometry(
        length=0.6,
        width=0.2,
        phi=30,
        wallThickness=0.0009,
        patternAmplitude=0.0011,
        patternWaveLength=12.6e-3,
        numberOfPlates=144),
      TInitialVLEFluid_a=278.15,
      TInitialLiquid_b=313.15,
      TInitialLiquid_b_Cell1=308.15,
      TInitialLiquid_b_CellN=298.15)
      annotation (Placement(transformation(extent={{-22,136},{-50,164}})));

    TIL.LiquidComponents.Pumps.SimplePump simplePump1(
      presetVariableType="m_flow",
      use_massFlowRateInput=true,
      use_volumeFlowRateInput=false)
                annotation (Placement(transformation(
          extent={{-8,-8},{8,8}},
          rotation=270,
          origin={-230,208})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC4
      annotation (Placement(transformation(extent={{-182,210},{-174,218}})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint(y=35)
      annotation (Placement(transformation(extent={{-166,228},{-186,248}})));
    TIL.OtherComponents.Controllers.PIController PI_Floor(
      controllerType="PI",
      invertFeedback=true,
      yMax=10,
      initType="initialOutput",
      yInitial=0.47,
      Ti=0.1,
      k=1e-1,
      use_activeInput=true,
      use_y_notActive=true,
      yMin=1e-7)
      annotation (Placement(transformation(extent={{-218,246},{-230,234}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC5(
        initialSensorValue=40, useTimeConstant=false)
      annotation (Placement(transformation(extent={{-204,270},{-196,278}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC6
      annotation (Placement(transformation(extent={{-94,146},{-86,154}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC7
      annotation (Placement(transformation(extent={{10,146},{18,154}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC8
      annotation (Placement(transformation(extent={{36,162},{44,170}})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve(
        use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=-90,
          origin={-216,104})));

    TIL.OtherComponents.Controllers.PIController PI_HPValve(
      controllerType="PI",
      invertFeedback=true,
      Ti=0.01,
      yMax=1e-2,
      yMin=1e-12,
      yInitial=2e-6,
      k=1e-10)
      annotation (Placement(transformation(extent={{-186,110},{-198,98}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p(
      tau=1,
      useTimeConstant=false,
      initialSensorValue=10000000)                   annotation (Placement(
          transformation(
          extent={{-4,-4},{4,4}},
          rotation=-90,
          origin={-198,128})));
    Modelica.Blocks.Sources.RealExpression HighPressure(y=100e5)
      annotation (Placement(transformation(extent={{-150,94},{-170,114}})));
    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX       HX3(
      pressureStateID=1,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      initVLEFluid_a="linearEnthalpyDistribution",
      initHeatTransfer_a="alpha",
      alphaInitial_a=1900,
      m_flowStart_b=PI_DHW.yInitial,
      pStart_a=pressureState.pInitial,
      initLiquid_b="linearTemperatureDistribution",
      m_flowStart_a=0.2,
      hInitialVLEFluid_a_Cell1=260e3,
      hInitialVLEFluid_a_CellN=227e3,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.Plate.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      nCells=3,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        length=0.6,
        width=0.2,
        wallThickness=0.0009,
        patternAmplitude=0.0011,
        phi=30,
        numberOfPlates=144),
      TInitialVLEFluid_a=303.15,
      TInitialLiquid_b=328.15,
      TInitialLiquid_b_Cell1=296.15,
      TInitialLiquid_b_CellN=283.15)
      annotation (Placement(transformation(extent={{-110,136},{-138,164}})));

    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX       HX1(
      pressureStateID=1,
      initVLEFluid_a="linearEnthalpyDistribution",
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      initHeatTransfer_a="alpha",
      alphaInitial_a=1900,
      m_flowStart_b=PI_DHW.yInitial,
      pStart_a=pressureState.pInitial,
      initLiquid_b="linearTemperatureDistribution",
      hInitialVLEFluid_a_Cell1=494e3,
      hInitialVLEFluid_a_CellN=360e3,
      m_flowStart_a=0.20,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.Plate.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      nCells=3,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        length=0.6,
        width=0.2,
        wallThickness=0.0009,
        patternAmplitude=0.0011,
        phi=30,
        numberOfPlates=144),
      TInitialVLEFluid_a=551.3,
      TInitialLiquid_b=621.3,
      TInitialLiquid_b_Cell1=343.15,
      TInitialLiquid_b_CellN=296.15)
      annotation (Placement(transformation(extent={{76,136},{48,164}})));

    TIL.VLEFluidComponents.Sensors.Sensor_H_flow sensor_H_flow
      annotation (Placement(transformation(extent={{94,146},{86,138}})));
    TIL.VLEFluidComponents.Sensors.Sensor_H_flow sensor_H_flow1
      annotation (Placement(transformation(extent={{-152,146},{-160,138}})));
    Modelica.Blocks.Math.Add add_GasCooler(k2=-1) annotation (Placement(
          transformation(
          extent={{-6,-6},{6,6}},
          rotation=-90,
          origin={56,110})));

    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState1(
        pressureStateID=3, pInitial=3400000)
      annotation (Placement(transformation(extent={{36,-10},{48,2}})));
    TIL.VLEFluidComponents.Sensors.Sensor_q sensor_q
      annotation (Placement(transformation(extent={{2,0},{10,8}})));
    TIL.VLEFluidComponents.Separators.IdealSeparator idealSeparator(
        pressureStateID=2,
      hStart=233e3,
      mixingRatioInitial={0.1},
      V=1,
      initialFillingLevel=0.5,
      mdotStart=0.1)
      annotation (Placement(transformation(extent={{-212,36},{-200,56}})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve1(
        use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=0,
          origin={-186,-4})));
    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState2(
        pressureStateID=2, pInitial=4000000)
      annotation (Placement(transformation(extent={{-6,-6},{6,6}},
          rotation=-90,
          origin={-216,74})));
    TIL.OtherComponents.Controllers.PIController PI_ValveCooling(
      controllerType="PI",
      invertFeedback=true,
      yMin=1e-9,
      yMax=1e-5,
      initType="initialOutput",
      k=1e-10,
      yInitial=7.08e-7,
      Ti=0.1) annotation (Placement(transformation(extent={{-56,28},{-68,40}})));
    Modelica.Blocks.Sources.RealExpression Superheat_realinput(y=0.85)
      annotation (Placement(transformation(extent={{-16,24},{-36,44}})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve2(
        use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=0,
          origin={-142,52})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p1
      annotation (Placement(transformation(extent={{-172,56},{-164,64}})));
    TIL.OtherComponents.Controllers.PIController PI_bypass(
      controllerType="PI",
      invertFeedback=true,
      yInitial=1e-7,
      yMax=1e-3,
      k=1e-7,
      Ti=10,
      yMin=0)
      annotation (Placement(transformation(extent={{-150,72},{-138,84}})));
    Modelica.Blocks.Sources.RealExpression Bypass_Pressure1(y=40e5)
      annotation (Placement(transformation(extent={{-192,70},{-172,90}})));
    TIL.VLEFluidComponents.Compressors.EffCompressor Compressor_MT(
        use_mechanicalPort=true,
      use_relDisplacementInput=true,
      displacement=20e-6)
      annotation (Placement(transformation(extent={{194,54},{178,70}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p2
      annotation (Placement(transformation(extent={{138,28},{146,36}})));
    TIL.OtherComponents.Controllers.PIController PI_Comp(
      controllerType="PI",
      invertFeedback=true,
      yMax=10,
      yMin=0.01,
      yInitial=3,
      Ti=100,
      k=0.01)
      annotation (Placement(transformation(extent={{136,40},{148,52}})));
    Modelica.Blocks.Sources.RealExpression Bypass_Pressure2(y=34e5)
      annotation (Placement(transformation(extent={{104,36},{124,56}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction(
      pressureStateID=3,
      volume=5e-4,
      hInitial=397e3)
      annotation (Placement(transformation(extent={{72,-8},{80,0}})));

    TIL.VLEFluidComponents.Sensors.Sensor_m_flow sensor_m_flow annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=90,
          origin={186,110})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint1(y=70)
      annotation (Placement(transformation(extent={{-84,334},{-104,354}})));
    TIL.OtherComponents.Controllers.PIController PI_DHW(
      controllerType="PI",
      invertFeedback=true,
      yMin=0.01,
      yMax=1,
      Ti=1,
      yInitial=0.10,
      k=1e-2,
      initType="initialOutput")
      annotation (Placement(transformation(extent={{-128,338},{-140,350}})));
    TIL.VLEFluidComponents.Sensors.Sensor_q sensor_q3(initialSensorValue=0.1,
        useTimeConstant=false)
      annotation (Placement(transformation(extent={{-246,58},{-238,66}})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve3(effectiveFlowAreaFixed=
          4.6e-5, use_effectiveFlowAreaInput=true)
                                         annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=0,
          origin={-186,-114})));
    TIL.OtherComponents.Controllers.PIController PI_ValveIWC(
      controllerType="PI",
      invertFeedback=true,
      yMin=1e-8,
      yMax=5e-5,
      use_activeInput=true,
      use_y_notActive=true,
      yInitial=6.4e-6,
      Ti=0.01,
      k=1e-9)
      annotation (Placement(transformation(extent={{-90,-80},{-102,-92}})));
    TIL.VLEFluidComponents.Sensors.Sensor_q sensor_q4
      annotation (Placement(transformation(extent={{-26,-110},{-18,-102}})));
    Modelica.Blocks.Sources.RealExpression Superheat_realinput1(y=0.95)
      annotation (Placement(transformation(extent={{-52,-102},{-70,-90}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC11(liquidType=sim.liquidType1)
                                                               annotation (
        Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=180,
          origin={-128,-120})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction3(
      pressureStateID=2,
      volume=5e-5,
      hInitial=213e3)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=-90,
          origin={-206,-4})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction4(
      pressureStateID=3,
      hInitial=435e3,
      volume=5e-3)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=180,
          origin={90,-4})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction5(
      pressureStateID=2,
      volume=5e-5,
      hInitial=junction3.hInitial)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=-90,
          origin={-206,-114})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve5(
        use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=0,
          origin={-188,-390})));
    TIL.OtherComponents.Controllers.PIController PI_Valve_Freezer(
      controllerType="PI",
      invertFeedback=true,
      initType="initialOutput",
      yInitial=6.5e-7,
      k=1e-12,
      yMax=1e-5,
      yMin=1e-8,
      Ti=1)
      annotation (Placement(transformation(extent={{-114,-346},{-126,-334}})));
    Modelica.Blocks.Sources.RealExpression Superheat_realinput3(
                                                               y=2)
      annotation (Placement(transformation(extent={{-82,-350},{-102,-330}})));
    TIL.VLEFluidComponents.Sensors.Sensor_superheating sensor_superheating3
      annotation (Placement(transformation(extent={{-52,-384},{-44,-376}})));
    TIL.VLEFluidComponents.Compressors.EffCompressor Compressor_LT(
        use_mechanicalPort=true, use_relDisplacementInput=true)
      annotation (Placement(transformation(extent={{128,-344},{112,-328}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p3
      annotation (Placement(transformation(extent={{84,-374},{92,-366}})));
    TIL.OtherComponents.Controllers.PIController PI_LP_Comp(
      controllerType="PI",
      invertFeedback=true,
      yMin=1,
      Ti=100,
      yMax=3,
      k=1e-6,
      yInitial=1.1)
      annotation (Placement(transformation(extent={{82,-348},{94,-336}})));
    Modelica.Blocks.Sources.RealExpression Bypass_Pressure3(y=14.2e5)
      annotation (Placement(transformation(extent={{50,-352},{70,-332}})));
    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState3(
        pressureStateID=4, pInitial=1420000)
      annotation (Placement(transformation(extent={{16,-396},{28,-384}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction1(
      pressureStateID=3,
      volume=5e-3,
      hInitial=467e3)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=180,
          origin={120,-4})));

    TIL.VLEFluidComponents.Separators.IdealSeparator idealSeparator1(
      pressureStateID=3,
      hStart=junction.hInitial,
      mixingRatioInitial={1},
      V=1,
      mdotStart=0.2,
      initialFillingLevel=0)
      annotation (Placement(transformation(extent={{138,-18},{150,2}})));

    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX HX_CO2_IW(
      initVLEFluid_a="linearEnthalpyDistribution",
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Steel,
      pressureStateID=3,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      m_flowStart_a=PI_ValveIWC.yInitial,
      pStart_a=pressureState1.pInitial,
      m_flowStart_b=PI_Pump_IWC.yInitial,
      initHeatTransfer_a="alpha",
      alphaInitial_a=1500,
      hInitialVLEFluid_a_CellN=junction4.hInitial,
      hInitialVLEFluid_a_Cell1=junction3.hInitial,
      liquidType_b=sim.liquidType1,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
          numberOfPlates=80),
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      cellOrientation_a="A",
      nCells=5,
      initLiquid_b="linearTemperatureDistribution",
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      TInitialVLEFluid_a=273.15,
      TInitialLiquid_b=280.15,
      TInitialLiquid_b_Cell1=280.15,
      TInitialLiquid_b_CellN=288.15)
      annotation (Placement(transformation(extent={{-112,-108},{-84,-136}})));

    TIL.LiquidComponents.HydraulicCapacitors.HydraulicCapacitor
      hydraulicCapacitor1(
                         C=1e20,
      fixedInitialPressure=true,
      massInitial=1,
      m_flowStart=0.3,
      TInitial=283.15)
      annotation (Placement(transformation(extent={{66,380},{74,396}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC17
      annotation (Placement(transformation(extent={{100,388},{108,396}})));
    TIL.LiquidComponents.Sensors.Sensor_m_flow sensor_m_flow3
      annotation (Placement(transformation(extent={{56,380},{48,388}})));
    TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundary1(
        boundaryType="n",
      use_nInput=false,
      nFixed=50)
      annotation (Placement(transformation(extent={{154,52},{162,72}})));
    TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundary2(
        boundaryType="n",
      use_nInput=false,
      nFixed=50)
      annotation (Placement(transformation(extent={{98,-346},{106,-326}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC10(liquidType=sim.liquidType1)
                                                               annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=0,
          origin={-266,-122})));
    TIL.LiquidComponents.Tubes.Tube tank_IW(
      redeclare model PressureDropModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      initLiquid="linearTemperatureDistribution",
      m_flowStart=0.5,
      redeclare model TubeSideHeatTransferModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1),
      redeclare model WallHeatConductionModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.WallHeatTransfer.ConstantR
          (constantR=1/4000),
      tubeGeometry(
        wallThickness=0.05,
        crossSectionType=TIL.Internals.CrossSectionType.Circular,
        innerDiameter=1,
        length=60.15),
      nCells=20,
      TInitialWall=288.15,
      TInitialLiquid_Cell1=288.15,
      TInitialLiquid_CellN=288.15) annotation (Placement(transformation(
          extent={{14,-4},{-14,4}},
          rotation=-90,
          origin={-246,-154})));

    TIL.LiquidComponents.JunctionElements.VolumeJunction junction8(volume=1e-4,
        TInitial=280.15)                                           annotation (
        Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=0,
          origin={-246,-130})));
    TIL.LiquidComponents.Tubes.Tube tank_DHW(
      nCells=20,
      redeclare model TubeSideHeatTransferModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1900),
      redeclare model WallHeatConductionModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model PressureDropModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      m_flowStart=3,
      redeclare TIL.LiquidComponents.Tubes.Geometry.TubeGeometry tubeGeometry(
          innerDiameter=1, length=12.73),
      initLiquid="constantTemperature",
      TInitialLiquid=283.15,
      TInitialWall=283.15,
      TInitialLiquid_Cell1=283.15,
      TInitialLiquid_CellN=343.15)
                           annotation (Placement(transformation(
          extent={{-16,-4},{16,4}},
          rotation=90,
          origin={102,336})));

    TIL.LiquidComponents.Boundaries.Boundary OutletDHW2(
      streamVariablesInputType="T",
      use_temperatureInput=false,
      boundaryType="m_flow",
      m_flowFixed=0.5,
      use_massFlowRateInput=true,
      TFixed=353.15)
      annotation (Placement(transformation(extent={{166,360},{158,380}})));
    TIL.LiquidComponents.Boundaries.Boundary OutletDHW3(
                                                       boundaryType="p",
      streamVariablesInputType="T",
      use_temperatureInput=false,
      TFixed=278.15)
      annotation (Placement(transformation(extent={{156,304},{164,324}})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction9(volume=5e-3, TInitial=
         343.15)
      annotation (Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=-90,
          origin={104,362})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction10(volume=5e-3,
        TInitial=283.15)
      annotation (Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=0,
          origin={112,314})));
    TIL.HeatExchangers.FinAndTube.MoistAirLiquid.CrossFlowHX    parallelFlowHX(
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      moistAirCellFlowType="flow A-B",
      redeclare model FinSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
      gasType=sim.gasType2,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=10000),
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=10000),
      nCells=3,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
      redeclare model FinEfficiencyModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinEfficiency.Schmidt,
      redeclare TIL.HeatExchangers.FinAndTube.Geometry.KKI001 hxGeometry(
          nSerialTubes=20, nParallelTubes=20),
      m_flowLiquidStart=0.122,
      m_flowMoistAirStart=1e-7,
      TInitialLiquid=283.15,
      TInitialWall=283.15)
      annotation (Placement(transformation(extent={{-60,370},{-32,398}})));

    TIL.GasComponents.Fans.SimpleFan simpleFan2(use_volumeFlowRateInput=true,
        gasType=sim.gasType2) annotation (Placement(transformation(
          extent={{-8,-8},{8,8}},
          rotation=180,
          origin={-46,424})));
    TIL.GasComponents.Boundaries.Boundary boundary(
      streamVariablesInputType="T",
      boundaryType="p",
      gasType=sim.gasType2,
      use_temperatureInput=false,
      TFixed=290.15)
      annotation (Placement(transformation(extent={{-4,-10},{4,10}},
          rotation=-90,
          origin={-46,444})));
    TIL.GasComponents.Boundaries.Boundary boundary1(
      boundaryType="p",
      streamVariablesInputType="T",
      gasType=sim.gasType2,
      TFixed=283.15)
      annotation (Placement(transformation(extent={{-4,-10},{4,10}},
          rotation=90,
          origin={-46,356})));
    Modelica.Blocks.Logical.GreaterThreshold greaterThreshold(threshold=17)
      annotation (Placement(transformation(extent={{50,404},{30,424}})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint3(y=
          sensor_T_degC17.sensorValue)
      annotation (Placement(transformation(extent={{80,404},{60,424}})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction11(volume=8e-3,
        TInitial=308.15)                                           annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=180,
          origin={-286,262})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction12(volume=8e-3,
        TInitial=298.15)                                           annotation (
        Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=180,
          origin={-286,208})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction13(volume=8e-3,
        TInitial=308.15)                                           annotation (
        Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=180,
          origin={-270,262})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction14(volume=8e-3,
        TInitial=298.15)                                           annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=180,
          origin={-270,208})));
    TIL.LiquidComponents.Tubes.Tube tank_SH(
      redeclare model PressureDropModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      enableHeatPorts=false,
      initLiquid="linearTemperatureDistribution",
      redeclare model TubeSideHeatTransferModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1),
      redeclare model WallHeatConductionModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.WallHeatTransfer.ConstantR
          (constantR=1/4000),
      m_flowStart=-0.3,
      nCells=20,
      tubeGeometry(
        wallThickness=0.05,
        crossSectionType=TIL.Internals.CrossSectionType.Circular,
        innerDiameter=1,
        length=60.93),
      TInitialWall=298.15,
      TInitialLiquid_Cell1=298.15,
      TInitialLiquid_CellN=298.15) annotation (Placement(transformation(
          extent={{16,-4},{-16,4}},
          rotation=-90,
          origin={-288,234})));

    TIL.LiquidComponents.Boundaries.Boundary InletFloor1(
      boundaryType="m_flow",
      m_flowFixed=0.8,
      use_massFlowRateInput=true,
      TFixed=308.15)   annotation (Placement(transformation(
          extent={{-4,-10},{4,10}},
          rotation=0,
          origin={-332,262})));
    TIL.LiquidComponents.Boundaries.Boundary InletFloor2(
      m_flowFixed=-0.8,
      boundaryType="p",
      TFixed=298.15)   annotation (Placement(transformation(
          extent={{-4,-10},{4,10}},
          rotation=0,
          origin={-332,208})));
    TIL.LiquidComponents.Pumps.SimplePump simplePump2(
      presetVariableType="m_flow",
      use_massFlowRateInput=true,
      use_volumeFlowRateInput=false)
                annotation (Placement(transformation(
          extent={{8,-8},{-8,8}},
          rotation=0,
          origin={-464,240})));
    TIL.OtherComponents.Controllers.PIController PI_Floor1(
      controllerType="PI",
      invertFeedback=true,
      k=0.1,
      Ti=10,
      yMax=10,
      yMin=1e-7,
      yInitial=0.8,
      use_activeInput=true,
      use_y_notActive=true)
      annotation (Placement(transformation(extent={{-416,228},{-428,240}})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint5(y=35)
      annotation (Placement(transformation(extent={{-376,224},{-396,244}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC18
      annotation (Placement(transformation(extent={{-456,220},{-448,228}})));
    TIL.LiquidComponents.HydraulicCapacitors.HydraulicCapacitor
      hydraulicCapacitor3(
                         C=1e20,
      fixedInitialPressure=true,
      massInitial=1,
      m_flowStart=0.3)
      annotation (Placement(transformation(extent={{-290,168},{-284,182}})));
    TIL.OtherComponents.Controllers.PIController PI_Pump_IWC(
      controllerType="PI",
      initType="initialOutput",
      use_activeInput=true,
      use_y_notActive=true,
      invertFeedback=true,
      yMax=6,
      k=1e-4,
      yMin=0.2,
      yInitial=0.2,
      Ti=0.01)
      annotation (Placement(transformation(extent={{-34,-160},{-46,-172}})));
    Modelica.Blocks.Sources.RealExpression Temp_IWC3(y=7)
      annotation (Placement(transformation(extent={{8,-146},{-6,-128}})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction15(volume=1e-4,
        TInitial=288.15)                                           annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=0,
          origin={-246,-178})));
    TIL.LiquidComponents.Pumps.SimplePump Pump_IWC(
      m_flowFixed=0.2,
      presetVariableType="m_flow",
      use_massFlowRateInput=true,
      use_volumeFlowRateInput=false,
      liquidType=sim.liquidType1) annotation (Placement(transformation(
          extent={{8,-8},{-8,8}},
          rotation=0,
          origin={-74,-160})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC15
      annotation (Placement(transformation(extent={{-320,266},{-312,274}})));
    TIL.LiquidComponents.Boundaries.Boundary InletFloor3(
      boundaryType="m_flow",
      m_flowFixed=0.4,
      use_massFlowRateInput=true,
      TFixed=313.15)   annotation (Placement(transformation(
          extent={{-4,-10},{4,10}},
          rotation=0,
          origin={-280,-130})));
    TIL.LiquidComponents.Boundaries.Boundary InletFloor4(
      m_flowFixed=-0.4,
      boundaryType="p",
      TFixed=288.15)   annotation (Placement(transformation(
          extent={{-4,-10},{4,10}},
          rotation=0,
          origin={-282,-178})));
    TIL.HeatExchangers.FinAndTube.GasVLEFluid.CrossFlowHX HX_Chiller(
      fixedPressureDropInitialVLEFluid=false,
      fixedTInitialWall=false,
      pressureStateID=3,
      pVLEFluidStart=pressureState1.pInitial,
      pressureDropInitialVLEFluid=0,
      gasCellFlowType="flow A-B",
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
      redeclare model FinEfficiencyModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinEfficiency.Schmidt,
      redeclare model FinSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
      nCells=3,
      initVLEFluid="linearEnthalpyDistribution",
      hInitialVLEFluid_Cell1=213e3,
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=150),
      hInitialVLEFluid_CellN=429e3,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare TIL.HeatExchangers.FinAndTube.Geometry.KKI001 hxGeometry(
          nSerialTubes=8, nParallelTubes=14),
      m_flowVLEFluidStart=0.023,
      initHeatTransfer="alpha",
      alphaInitialVLEFluid=2500,
      TInitialVLEFluid=272.15,
      TInitialWall=273.57)
      annotation (Placement(transformation(extent={{-110,10},{-82,-18}})));

    TIL.GasComponents.Fans.SimpleFan simpleFan(use_volumeFlowRateInput=true)
      annotation (Placement(transformation(extent={{-104,-50},{-88,-34}})));
    TIL.GasComponents.Volumes.Volume volume(volume=75, TInitial=276.15)
      annotation (Placement(transformation(
          extent={{-4,-8},{4,8}},
          rotation=90,
          origin={-100,-60})));
    TIL.OtherComponents.Thermal.HeatBoundary Heat_Cooling(boundaryType="Q_flow",
        Q_flowFixed(displayUnit="kW") = -5000)  annotation (Placement(
          transformation(
          extent={{-4,-6},{4,6}},
          rotation=0,
          origin={-116,-60})));
    TIL.GasComponents.Sensors.Sensor_T sensor_T annotation (Placement(
          transformation(
          extent={{-4,4},{4,-4}},
          rotation=-90,
          origin={-106,-30})));
    TIL.OtherComponents.Controllers.PIController PI_PumpChiller(
      controllerType="PI",
      invertFeedback=true,
      yMin=1,
      initType="initialOutput",
      yMax=5,
      Ti=100,
      yInitial=2,
      k=1)
      annotation (Placement(transformation(extent={{-132,-36},{-120,-48}})));
    Modelica.Blocks.Sources.RealExpression Setpoint_Cooling(y=276.15)
      annotation (Placement(transformation(extent={{-166,-52},{-146,-32}})));
    TIL.GasComponents.Sensors.Sensor_T_degC sensor_T_degC19
      annotation (Placement(transformation(extent={{-82,-38},{-74,-30}})));
    TIL.HeatExchangers.FinAndTube.GasVLEFluid.CrossFlowHX HX_Freezer(
      fixedPressureDropInitialVLEFluid=false,
      fixedTInitialWall=false,
      hInitialVLEFluid_Cell1=250,
      hInitialVLEFluid_CellN=430,
      pressureStateID=4,
      hInitialVLEFluid=440e3,
      initVLEFluid="constantTemperature",
      gasCellFlowType="flow A-B",
      nCells=3,
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
      redeclare model FinEfficiencyModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinEfficiency.Schmidt,
      redeclare model FinSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
      pVLEFluidStart=pressureState3.pInitial,
      m_flowVLEFluidStart=0.03,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare TIL.HeatExchangers.FinAndTube.Geometry.KKI001 hxGeometry(
          nSerialTubes=8, nParallelTubes=10),
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=150),
      TInitialVLEFluid=243.15,
      TInitialWall=243.15)
      annotation (Placement(transformation(extent={{-144,-376},{-116,-404}})));

    TIL.GasComponents.Fans.SimpleFan simpleFan1(
                                               use_volumeFlowRateInput=true)
      annotation (Placement(transformation(extent={{-138,-436},{-122,-420}})));
    TIL.GasComponents.Volumes.Volume volume2(volume=60, TInitial=253.15)
      annotation (Placement(transformation(
          extent={{-4,-8},{4,8}},
          rotation=90,
          origin={-134,-450})));
    TIL.OtherComponents.Thermal.HeatBoundary Heat_Cooling1(
                                                          boundaryType="Q_flow",
        Q_flowFixed(displayUnit="kW") = -10000) annotation (Placement(
          transformation(
          extent={{-4,-6},{4,6}},
          rotation=0,
          origin={-152,-450})));
    TIL.GasComponents.Sensors.Sensor_T sensor_T2
                                                annotation (Placement(
          transformation(
          extent={{-4,4},{4,-4}},
          rotation=-90,
          origin={-142,-410})));
    TIL.OtherComponents.Controllers.PIController PI_PumpFreezer(
      controllerType="PI",
      invertFeedback=true,
      yMin=1,
      k=1,
      Ti=100,
      yInitial=1.5,
      yMax=5)
      annotation (Placement(transformation(extent={{-166,-422},{-154,-434}})));
    Modelica.Blocks.Sources.RealExpression Setpoint_Cooling1(y=253.15)
      annotation (Placement(transformation(extent={{-196,-438},{-176,-418}})));
    TIL.GasComponents.Sensors.Sensor_T_degC sensor_T_degC14
      annotation (Placement(transformation(extent={{-114,-426},{-106,-418}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction7(
      pressureStateID=2,
      volume=5e-5,
      hInitial=junction3.hInitial)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=-90,
          origin={-206,-390})));
    TIL.VLEFluidComponents.Valves.OrificeValve valve6(
        use_effectiveFlowAreaInput=true) annotation (Placement(transformation(
          extent={{-8,-4},{8,4}},
          rotation=0,
          origin={-54,-500})));
    Modelica.Blocks.Sources.RealExpression sup_heat(y=2)
      annotation (Placement(transformation(extent={{68,-446},{48,-426}})));
    TIL.VLEFluidComponents.Sensors.Sensor_superheating sensor_superheating4
      annotation (Placement(transformation(extent={{74,-494},{82,-486}})));
    TIL.HeatExchangers.FinAndTube.GasVLEFluid.CrossFlowHX HX_Air(
      fixedPressureDropInitialVLEFluid=false,
      fixedTInitialWall=false,
      pVLEFluidStart=pressureState1.pInitial,
      pressureDropInitialVLEFluid=0,
      initHeatTransfer="alphaA",
      alphaAInitialVLEFluid=5000,
      gasCellFlowType="flow A-B",
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model FinEfficiencyModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinEfficiency.Schmidt,
      redeclare model FinSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
      nCells=3,
      hInitialVLEFluid_Cell1=213e3,
      hInitialVLEFluid_CellN=413e3,
      pressureStateID=8,
      initVLEFluid="constantEnthalpy",
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=150),
      redeclare TIL.HeatExchangers.FinAndTube.Geometry.KKI001 hxGeometry(
        nTubeSideParallelHydraulicFlows=3,
        finnedTubeLength=2,
        nSerialTubes=10,
        nParallelTubes=25),
      redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
      TInitialVLEFluid=272.15,
      TInitialWall=274.15)
      annotation (Placement(transformation(extent={{18,-486},{46,-514}})));

    TIL.OtherComponents.Controllers.PIController PI_ValveAir(
      controllerType="PI",
      invertFeedback=true,
      yMin=1e-9,
      yMax=0.5,
      use_activeInput=true,
      use_y_notActive=true,
      Ti=0.1,
      initType="initialOutput",
      k=1e-11,
      yInitial=3e-7)
      annotation (Placement(transformation(extent={{34,-452},{22,-440}})));
    TIL.VLEFluidComponents.Compressors.EffCompressor Compressor_parallell(
        use_mechanicalPort=true,
      use_relDisplacementInput=true,
      displacement=20e-6)
      annotation (Placement(transformation(extent={{234,-472},{218,-456}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p4
      annotation (Placement(transformation(extent={{178,-494},{186,-486}})));
    TIL.OtherComponents.Controllers.PIController PI_CompParallell(
      controllerType="PI",
      initType="initialOutput",
      use_activeInput=true,
      use_y_notActive=true,
      k=1e-3,
      invertFeedback=false,
      yMax=5,
      yMin=0.1,
      yInitial=1,
      Ti=1)
      annotation (Placement(transformation(extent={{174,-470},{186,-458}})));
    TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundary3(
        boundaryType="n",
      use_nInput=false,
      nFixed=50)
      annotation (Placement(transformation(extent={{206,-474},{214,-454}})));
    TIL.VLEFluidComponents.JunctionElements.VolumeJunction junction16(
      volume=5e-4,
      pressureStateID=1,
      hInitial=495e3)
      annotation (Placement(transformation(extent={{-4,-4},{4,4}},
          rotation=180,
          origin={186,142})));
    Modelica.Blocks.Sources.RealExpression off_value_GW1(y=0)
      annotation (Placement(transformation(extent={{68,-432},{48,-412}})));
    TIL.GasComponents.Boundaries.Boundary
      boundaryUnderdetermined1(boundaryType="p")
      annotation (Placement(transformation(extent={{56,-490},{64,-470}})));
    TIL.GasComponents.Boundaries.Boundary               boundaryOverdetermined1(
      streamVariablesInputType="T",
      V_flowFixed=-0.5,
      boundaryType="p",
      use_volumeFlowRateInput=false,
      TFixed=290.15)
      annotation (Placement(transformation(extent={{-38,-540},{-30,-520}})));
    TIL.GasComponents.Sensors.Sensor_T_degC sensor_T_degC22
      annotation (Placement(transformation(extent={{8,-480},{16,-472}})));
    Modelica.Blocks.Sources.RealExpression off_value_GW2(y=0)
      annotation (Placement(transformation(extent={{208,-456},{188,-436}})));
    TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX HX_Ammonia_SH(
      liquidType_b=sim.liquidType1,
      vleFluidType_a=sim.vleFluidType2,
      pressureStateID=5,
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.Plate.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      initLiquid_b="linearTemperatureDistribution",
      hInitialVLEFluid_a=1000e3,
      initVLEFluid_a="linearEnthalpyDistribution",
      hInitialVLEFluid_a_CellN=300e3,
      nCells=3,
      m_flowStart_b=0.8,
      hInitialVLEFluid_a_Cell1=650e3,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      m_flowStart_a=0.1,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        phi=30,
        wallThickness=0.0009,
        patternAmplitude=0.0011,
        numberOfPlates=300,
        length=0.4,
        width=0.25),
      TInitialLiquid_b_Cell1=308.15,
      TInitialLiquid_b_CellN=298.15,
      pStart_a=1300000) annotation (Placement(transformation(
          extent={{-14,-14},{14,14}},
          rotation=0,
          origin={-392,164})));

   TIL.VLEFluidComponents.Valves.OrificeValve valve8(
       use_effectiveFlowAreaInput=true, vleFluidType=sim.vleFluidType2)
     annotation (Placement(transformation(
         extent={{8,-4},{-8,4}},
         rotation=0,
         origin={-362,-94})));
   TIL.VLEFluidComponents.Compressors.EffCompressor2 Compressor_propane(
      use_mechanicalPort=true,
      vleFluidType=sim.vleFluidType2,
      displacement=2e-4,
      use_relDisplacementInput=true) annotation (Placement(transformation(
          extent={{8,-8},{-8,8}},
          rotation=0,
          origin={-622,-6})));
   TIL.OtherComponents.Mechanical.RotatoryBoundary rotatoryBoundary4(
       boundaryType="n", use_nInput=true)
     annotation (Placement(transformation(extent={{-4,-10},{4,10}},
         rotation=0,
         origin={-648,-6})));
   TIL.HeatExchangers.Plate.VLEFluidLiquid.ParallelFlowHX HX_Propane_IW(
      redeclare model PressureDropModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model PressureDropModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      initHeatTransfer_a="alpha",
      alphaInitial_a=1900,
      vleFluidType_a=sim.vleFluidType2,
      pressureStateID=6,
      hInitialVLEFluid_a=1000e3,
      initVLEFluid_a="linearEnthalpyDistribution",
      initLiquid_b="linearTemperatureDistribution",
      m_flowStart_a=0.1,
      hInitialVLEFluid_a_Cell1=300e3,
      nCells=3,
      hInitialVLEFluid_a_CellN=500e3,
      m_flowStart_b=1,
      redeclare model HeatTransferModel_a =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      redeclare model HeatTransferModel_b =
          TIL.HeatExchangers.Plate.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.Plate.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare TIL.HeatExchangers.Plate.Geometry.Example hxGeometry(
        wallThickness=0.0009,
        patternAmplitude=0.0011,
        phi=30,
        numberOfPlates=100,
        length=0.3,
        width=0.2),
      TInitialVLEFluid_a=303.15,
      TInitialLiquid_b=291.15,
      TInitialLiquid_b_Cell1=280.15,
      TInitialLiquid_b_CellN=288.15,
      pStart_a=600000)   annotation (Placement(transformation(
          extent={{14,14},{-14,-14}},
          rotation=0,
          origin={-484,-102})));

   TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState6(
     vleFluidType=sim.vleFluidType2,
      pressureStateID=5,
      pInitial=1300000)
     annotation (Placement(transformation(extent={{-6,-6},{6,6}},
         rotation=90,
         origin={-622,14})));
   TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState7(
     pressureStateID=6,
     vleFluidType=sim.vleFluidType2,
      pInitial=600000)
     annotation (Placement(transformation(extent={{-6,-6},{6,6}},
         rotation=90,
         origin={-622,-28})));
   TIL.OtherComponents.Controllers.PIController PI_ValveNH3(
     controllerType="PI",
     invertFeedback=true,
     initType="initialOutput",
      yMax=5e-5,
      use_activeInput=true,
      use_y_notActive=true,
      yInitial=2.6e-6,
      yMin=1e-8,
      k=1e-11,
      Ti=0.01)
     annotation (Placement(transformation(extent={{4,4},{-4,-4}},
         rotation=180,
         origin={-392,-66})));
   Modelica.Blocks.Sources.RealExpression asupheat(y=2)
      annotation (Placement(transformation(extent={{-412,-70},{-400,-62}})));
   TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC30
     annotation (Placement(transformation(extent={{-464,-126},{-456,-118}})));
   TIL.VLEFluidComponents.Sensors.Sensor_superheating sensor_superheating6(
       vleFluidType=sim.vleFluidType2)
     annotation (Placement(transformation(extent={{-512,-92},{-504,-84}})));
   TIL.VLEFluidComponents.Sensors.Sensor_m_flow sensor_m_flow13(vleFluidType=
         sim.vleFluidType2)
     annotation (Placement(transformation(extent={{-590,152},{-582,160}})));
   TIL.VLEFluidComponents.Sensors.Sensor_q      sensor_T_degC23(vleFluidType=
         sim.vleFluidType2, useTimeConstant=false)
     annotation (Placement(transformation(extent={{-350,160},{-342,168}})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint(vleFluidType=sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-552,160},{-544,168}})));
    Modelica.Blocks.Sources.RealExpression Temp_IWC1(y=7)
      annotation (Placement(transformation(extent={{-494,-164},{-514,-144}})));
    TIL.OtherComponents.Controllers.PIController PI_Pump_IWC1(
      controllerType="PI",
      initType="initialOutput",
      yMax=10,
      Ti=0.01,
      invertFeedback=false,
      use_activeInput=true,
      use_y_notActive=true,
      yInitial=0.7,
      k=1e-5,
      yMin=0.01)
      annotation (Placement(transformation(extent={{-528,-148},{-540,-160}})));
    TIL.LiquidComponents.Pumps.SimplePump simplePump3(presetVariableType=
          "m_flow", use_massFlowRateInput=true)
      annotation (Placement(transformation(extent={{-552,-156},{-568,-140}})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction17(volume=1e-4,
        TInitial=280.15)                                           annotation (
        Placement(transformation(
          extent={{-4,-4},{4,4}},
          rotation=0,
          origin={-232,-130})));
    TIL.LiquidComponents.JunctionElements.VolumeJunction junction18(volume=1e-4,
        TInitial=288.15)                                           annotation (
        Placement(transformation(
          extent={{-4,4},{4,-4}},
          rotation=0,
          origin={-232,-178})));
    TIL.LiquidComponents.Sensors.Sensor_m_flow sensor_m_flow1
      annotation (Placement(transformation(extent={{-198,-182},{-190,-174}})));
    TIL.LiquidComponents.Sensors.Sensor_m_flow sensor_m_flow2
      annotation (Placement(transformation(extent={{-266,-230},{-274,-222}})));
    Modelica.Blocks.Sources.RealExpression off_IWPump(y=1e-7)
      annotation (Placement(transformation(extent={{20,-190},{6,-176}})));
   Modelica.Blocks.Sources.RealExpression IWT_Temp1(y=tank_IW.summary.arrays.T_degC_liq_cell[
          1])
      annotation (Placement(transformation(extent={{58,-156},{40,-142}})));
   Modelica.Blocks.Logical.Hysteresis hysteresis1(
      pre_y_start=true,
      uLow=7,
      uHigh=14)
     annotation (Placement(transformation(extent={{12,-162},{0,-150}})));
   Modelica.Blocks.Logical.Switch switch4
     annotation (Placement(transformation(extent={{28,-162},{16,-150}})));
   Modelica.Blocks.Sources.RealExpression IWT_Temp10(y=tank_IW.summary.arrays.T_degC_liq_cell[
          4])
     annotation (Placement(transformation(extent={{58,-168},{40,-154}})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint2(
                                                         vleFluidType=sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-460,-90},{-452,-82}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC2(vleFluidType=
          sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-570,160},{-562,168}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC9(vleFluidType=
          sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-428,-90},{-420,-82}})));
    TIL.VLEFluidComponents.Sensors.StatePoint statePoint3(
                                                         vleFluidType=sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-332,160},{-324,168}})));
    TIL.VLEFluidComponents.Sensors.Sensor_T_degC sensor_T_degC12(
                                                                vleFluidType=
          sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-310,160},{-302,168}})));
    TIL.LiquidComponents.Sensors.Sensor_m_flow sensor_m_flow4
      annotation (Placement(transformation(extent={{-526,-114},{-518,-106}})));
    TIL.LiquidComponents.Sensors.Sensor_m_flow sensor_m_flow5
      annotation (Placement(transformation(extent={{-360,168},{-368,176}})));
   Modelica.Blocks.Sources.RealExpression SHT_Temp(y=tank_SH.summary.arrays.T_degC_liq_cell[
          1])
      annotation (Placement(transformation(extent={{-906,16},{-888,30}})));
   Modelica.Blocks.Logical.Hysteresis hysteresis2(
     pre_y_start=false,
      uHigh=33,
      uLow=26)
     annotation (Placement(transformation(extent={{-854,12},{-842,24}})));
   Modelica.Blocks.Logical.Not not3
     annotation (Placement(transformation(extent={{-838,12},{-826,24}})));
   Modelica.Blocks.Sources.Constant AmmoniaOn(k=50)
      annotation (Placement(transformation(extent={{-764,16},{-748,32}})));
   TIL.OtherComponents.Controllers.PIController PI_CompAmmonia1(
      controllerType="PI",
      initType="initialOutput",
      use_activeInput=true,
      use_y_notActive=true,
      activationTime=40000,
      Ti=0.1,
      k=0.01,
      yMin=1,
      invertFeedback=true,
      yInitial=1,
      yMax=20)    annotation (Placement(transformation(
          extent={{-6,-6},{6,6}},
          rotation=0,
          origin={-700,-48})));
   Modelica.Blocks.Sources.RealExpression RelDispl1(y=7.5)
     annotation (Placement(transformation(extent={{-744,-56},{-726,-40}})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping2(
      n=1,
      f=0.1,
      x_start={8})
     annotation (Placement(transformation(extent={{-682,-58},{-662,-38}})));
   Modelica.Blocks.Logical.Switch switch2
     annotation (Placement(transformation(extent={{-874,12},{-862,24}})));
   Modelica.Blocks.Sources.RealExpression DHWT_Temp2(y=tank_SH.summary.arrays.T_degC_liq_cell[
          4])
     annotation (Placement(transformation(extent={{-906,6},{-888,20}})));
   Modelica.Blocks.Sources.Constant AmmoniaOff(k=1)
      annotation (Placement(transformation(extent={{-766,-40},{-750,-24}})));
    Modelica.Blocks.Logical.Switch switch1
      annotation (Placement(transformation(extent={{-722,-14},{-702,6}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_airvalve1(y=hysteresis1.y)
      annotation (Placement(transformation(extent={{-58,-94},{-74,-80}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_propane_valves(y=
          hysteresis3.y)
      annotation (Placement(transformation(extent={{-570,-54},{-558,-42}})));
   Modelica.Blocks.Sources.RealExpression asupheat1(y=1e-11)
      annotation (Placement(transformation(extent={{-468,-48},{-458,-38}})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping1(
      n=1,
      x_start={50},
      f=0.001)
     annotation (Placement(transformation(extent={{-684,-16},{-664,4}})));
   Modelica.Blocks.Sources.RealExpression asupheat4(y=1e-7)
      annotation (Placement(transformation(extent={{-550,-178},{-536,-166}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_airvalve4(y=not3.y)
      annotation (Placement(transformation(extent={{-378,214},{-394,226}})));
   Modelica.Blocks.Sources.RealExpression asupheat5(y=1e-7)
      annotation (Placement(transformation(extent={{-442,248},{-428,260}})));
    Modelica.Blocks.Logical.And and2
      annotation (Placement(transformation(extent={{-528,-60},{-518,-50}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_airvalve2(y=or2.y)
      annotation (Placement(transformation(extent={{-550,-54},{-536,-44}})));
    TILFileReader.FileReader fileReader(
      fileType=TILFileReader.Internals.FileTypes.CSVFile,
      decimalSeparator=TILFileReader.Internals.DecimalSeparators.ColonSeparator,
      fileName="C:/Dymola/Input_Dymola.csv")
      annotation (Placement(transformation(extent={{188,406},{208,426}})));
    TILFileReader.Variables.RealVariableName realVariableName(
                 interpolationMethod=TILFileReader.Internals.InterpolationMethods.NoInterpolation,
      factor=1,
      offset=0.001,
      variableName="DHW_70")
      annotation (Placement(transformation(extent={{200,376},{180,396}})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping3(
      n=1,
      x_start={3e-6},
      f=0.1)
     annotation (Placement(transformation(extent={{-380,-70},{-372,-62}})));
    Modelica.Blocks.Sources.RealExpression Superheat_realinput4(y=1e-12)
      annotation (Placement(transformation(extent={{-52,-112},{-70,-100}})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping5(
      n=1,
      f=0.1,
      x_start={6.4e-6})
     annotation (Placement(transformation(extent={{-114,-92},{-126,-80}})));
    TILFileReader.FileReader fileReader1(
      fileType=TILFileReader.Internals.FileTypes.CSVFile,
      decimalSeparator=TILFileReader.Internals.DecimalSeparators.ColonSeparator,
      fileName="C:/Dymola/Input_Dymola.csv")
      annotation (Placement(transformation(extent={{-322,-144},{-302,-164}})));
    TILFileReader.Variables.RealVariableName realVariableSC(
      interpolationMethod=TILFileReader.Internals.InterpolationMethods.NoInterpolation,
      offset=0.001,
      variableName="SC_S_TEK10",
      factor=0.9)
      annotation (Placement(transformation(extent={{-322,-118},{-302,-138}})));

   Modelica.Blocks.Sources.RealExpression IWT_Temp2(y=tank_IW.summary.arrays.T_degC_liq_cell[
          10])
      annotation (Placement(transformation(extent={{-908,-14},{-890,0}})));
   Modelica.Blocks.Logical.Hysteresis hysteresis3(
      pre_y_start=true,
      uLow=7,
      uHigh=14.5)
     annotation (Placement(transformation(extent={{-852,-18},{-840,-6}})));
   Modelica.Blocks.Logical.Switch switch6
     annotation (Placement(transformation(extent={{-874,-18},{-862,-6}})));
   Modelica.Blocks.Sources.RealExpression IWT_Temp3(y=tank_IW.summary.arrays.T_degC_liq_cell[
          6])
     annotation (Placement(transformation(extent={{-908,-24},{-890,-10}})));
    TIL.VLEFluidComponents.Separators.IdealSeparator idealSeparator3(
      mixingRatioInitial={0.1},
      mdotStart=0.1,
      V=0.001,
      initialFillingLevel=0,
      hStart=433e3,
      pressureStateID=8)
      annotation (Placement(transformation(extent={{146,-514},{158,-494}})));
    TIL.GasComponents.Fans.SimpleFan simpleFan4(V_flowFixed=3,
        use_volumeFlowRateInput=true)
      annotation (Placement(transformation(extent={{-8,8},{8,-8}},
          rotation=90,
          origin={-8,-530})));
    Modelica.Blocks.Logical.Switch switch7
      annotation (Placement(transformation(extent={{-62,-576},{-42,-556}})));
   Modelica.Blocks.Sources.RealExpression asupheat8(y=10)
      annotation (Placement(transformation(extent={{-96,-564},{-82,-552}})));
   Modelica.Blocks.Sources.RealExpression asupheat9(y=1e-7)
      annotation (Placement(transformation(extent={{-96,-580},{-82,-568}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_airvalve3(y=not5.y)
      annotation (Placement(transformation(extent={{-124,-576},{-104,-556}})));
    TILFileReader.FileReader fileReader2(
      fileType=TILFileReader.Internals.FileTypes.CSVFile,
      decimalSeparator=TILFileReader.Internals.DecimalSeparators.ColonSeparator,
      fileName="C:/Dymola/Input_Dymola.csv")
      annotation (Placement(transformation(extent={{-10,-10},{10,10}},
          rotation=90,
          origin={-382,272})));
    TILFileReader.Variables.RealVariableName realVariableSC1(
      interpolationMethod=TILFileReader.Internals.InterpolationMethods.NoInterpolation,
      offset=0.001,
      factor=0.9,
      variableName="SH_S_TEK10")
      annotation (Placement(transformation(extent={{-364,254},{-344,274}})));
    Modelica.Blocks.Sources.RealExpression Bypass_Pressure5(y=HX_Air.summary.Q_flow_vle)
      annotation (Placement(transformation(extent={{134,-494},{154,-474}})));
    Modelica.Blocks.Sources.RealExpression off_value_GW5(y=25000)
      annotation (Placement(transformation(extent={{134,-464},{154,-444}})));
    TIL.VLEFluidComponents.PressureStateElements.PressureState pressureState5(
        pressureStateID=8, pInitial=3000000)
      annotation (Placement(transformation(extent={{-22,-506},{-10,-494}})));
   Modelica.Blocks.Logical.Hysteresis hysteresis5(
     pre_y_start=false,
      uLow=60,
      uHigh=69)
     annotation (Placement(transformation(extent={{146,-430},{130,-414}})));
   Modelica.Blocks.Logical.Not not5
     annotation (Placement(transformation(extent={{122,-430},{106,-414}})));
   Modelica.Blocks.Sources.RealExpression DHWT_Temp5(y=tank_DHW.summary.arrays.T_degC_liq_cell[
          15])
     annotation (Placement(transformation(extent={{196,-434},{178,-418}})));
    Modelica.Blocks.Interaction.Show.BooleanValue booleanValue(use_activePort=false,
        active=hysteresis1.y)
      annotation (Placement(transformation(extent={{0,-98},{22,-74}})));
    Modelica.Blocks.Interaction.Show.BooleanValue booleanValue2(use_activePort=false,
        active=not5.y)
      annotation (Placement(transformation(extent={{204,-404},{226,-380}})));
    Modelica.Blocks.Interaction.Show.BooleanValue booleanValue3(use_activePort=false,
        active=and2.y)
      annotation (Placement(transformation(extent={{-340,-82},{-318,-58}})));
    Modelica.Blocks.Interaction.Show.BooleanValue booleanValue6(use_activePort=false,
        active=not3.y)
      annotation (Placement(transformation(extent={{-494,228},{-472,252}})));
    TIL.LiquidComponents.HydraulicCapacitors.HydraulicCapacitor
      hydraulicCapacitor2(
                         C=1e20,
      fixedInitialPressure=true,
      massInitial=1,
      m_flowStart=0.3,
      TInitial=288.15)
      annotation (Placement(transformation(extent={{-3,-7},{3,7}},
          rotation=0,
          origin={-143,-175})));
    TIL.LiquidComponents.Tubes.Tube tube(
      redeclare model TubeSideHeatTransferModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=1000),
      redeclare model WallHeatConductionModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model PressureDropModel =
          TIL.LiquidComponents.Tubes.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      enableHeatPorts=true,
      initLiquid="linearTemperatureDistribution",
      m_flowStart=0.47,
      redeclare TIL.LiquidComponents.Tubes.Geometry.Tube6x1 tubeGeometry,
      nCells=2,
      TInitialWall=298.15,
      TInitialLiquid_Cell1=298.15,
      TInitialLiquid_CellN=299.15)
      annotation (Placement(transformation(extent={{-152,206},{-136,210}})));

    TIL.VLEFluidComponents.Tubes.Tube tube1(
      pressureStateID=3,
      redeclare model WallHeatConductionModel =
          TIL.VLEFluidComponents.Tubes.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model PressureDropModel =
          TIL.VLEFluidComponents.Tubes.TransportPhenomena.PressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      enableHeatPorts=true,
      initVLEFluid="linearEnthalpyDistribution",
      redeclare TIL.VLEFluidComponents.Tubes.Geometry.Tube6x1 tubeGeometry,
      nCells=2,
      m_flowStart=-0.033,
      redeclare model TubeSideHeatTransferModel =
          TIL.VLEFluidComponents.Tubes.TransportPhenomena.HeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      hInitialVLEFluid_Cell1=423e3,
      hInitialVLEFluid_CellN=493e3,
      TInitialWall=313.15,
      pStart=3300000) annotation (Placement(transformation(
          extent={{8,2},{-8,-2}},
          rotation=90,
          origin={120,-168})));

   Modelica.Blocks.Sources.RealExpression DHWT_Temp3(
                                                    y=tank_SH.summary.arrays.T_degC_liq_cell[
         1])
     annotation (Placement(transformation(extent={{-8,234},{-26,250}})));
   Modelica.Blocks.Logical.Hysteresis hysteresis4(
     pre_y_start=false,
      uHigh=34.8,
      uLow=34)
     annotation (Placement(transformation(extent={{-72,228},{-88,244}})));
   Modelica.Blocks.Logical.Not not4
     annotation (Placement(transformation(extent={{-96,228},{-112,244}})));
   Modelica.Blocks.Sources.RealExpression DHWT_Temp4(y=tank_SH.summary.arrays.T_degC_liq_cell[
          5])
     annotation (Placement(transformation(extent={{-10,218},{-28,234}})));
    Modelica.Blocks.Logical.Switch switch8
      annotation (Placement(transformation(extent={{-42,224},{-62,244}})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint2(y=1e-7)
      annotation (Placement(transformation(extent={{-186,214},{-206,234}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_propane_valves1(
                                                                    y=
          hysteresis3.y)
      annotation (Placement(transformation(extent={{-494,-148},{-510,-136}})));
    TIL.HeatExchangers.FinAndTube.GasVLEFluid.CrossFlowHX    HX_propaneDump(
      fixedPressureDropInitialVLEFluid=false,
      fixedTInitialWall=false,
      pressureDropInitialVLEFluid=0,
      gasCellFlowType="flow A-B",
      redeclare model TubeSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSidePressureDrop.ZeroPressureDrop,
      redeclare model WallMaterial = TILMedia.SolidTypes.TILMedia_Copper,
      redeclare model WallHeatConductionModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.WallHeatTransfer.GeometryBasedConduction,
      redeclare model FinMaterial = TILMedia.SolidTypes.TILMedia_Aluminum,
      redeclare model FinEfficiencyModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinEfficiency.Schmidt,
      redeclare model FinSidePressureDropModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSidePressureDrop.ZeroPressureDrop,
      nCells=3,
      vleFluidType=sim.vleFluidType2,
      hInitialVLEFluid_Cell1=600e3,
      hInitialVLEFluid_CellN=300e3,
      gasType=sim.gasType1,
      redeclare model TubeSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.TubeSideHeatTransfer.ConstantAlpha
          (constantAlpha=2500),
      pVLEFluidStart=pressureState6.pInitial,
      pressureStateID=5,
      initVLEFluid="constantEnthalpy",
      hInitialVLEFluid=640e3,
      m_flowVLEFluidStart=0.1,
      redeclare model FinSideHeatTransferModel =
          TIL.HeatExchangers.FinAndTube.TransportPhenomena.FinSideHeatTransfer.ConstantAlpha
          (constantAlpha=150),
      redeclare TIL.HeatExchangers.FinAndTube.Geometry.KKI001 hxGeometry(
        finnedTubeLength=2,
        nSerialTubes=12,
        nParallelTubes=30),
      TInitialVLEFluid=272.15,
      TInitialWall=303.15)
      annotation (Placement(transformation(extent={{-532,142},{-504,170}})));
    TIL.GasComponents.Boundaries.Boundary boundary4(
      boundaryType="p",
      streamVariablesInputType="T",
      gasType=sim.gasType1,
      TFixed=283.15)
      annotation (Placement(transformation(extent={{-4,-10},{4,10}},
          rotation=90,
          origin={-518,118})));
    TIL.GasComponents.Fans.SimpleFan simpleFan5(V_flowFixed=3,
        use_volumeFlowRateInput=true)
      annotation (Placement(transformation(extent={{8,8},{-8,-8}},
          rotation=90,
          origin={-544,200})));
    Modelica.Blocks.Logical.Switch switch10
      annotation (Placement(transformation(extent={{-628,208},{-608,228}})));
   Modelica.Blocks.Sources.RealExpression asupheat10(
                                                    y=10)
      annotation (Placement(transformation(extent={{-650,220},{-636,232}})));
   Modelica.Blocks.Sources.RealExpression asupheat11(y=1e-6)
      annotation (Placement(transformation(extent={{-650,204},{-636,216}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_propane_valves2(
                                                                    y=
          hysteresis3.y)
      annotation (Placement(transformation(extent={{-696,216},{-680,228}})));
    Modelica.Blocks.Logical.And and3
      annotation (Placement(transformation(extent={{-668,212},{-656,224}})));
    Modelica.Blocks.Sources.BooleanExpression on_off_propane_valves3(y=
          hysteresis2.y)
      annotation (Placement(transformation(extent={{-696,206},{-680,218}})));
    TIL.GasComponents.Boundaries.Boundary boundary5(
      streamVariablesInputType="T",
      gasType=sim.gasType1,
      V_flowFixed=-3,
      boundaryType="p",
      TFixed=290.15)
      annotation (Placement(transformation(extent={{-4,-10},{4,10}},
          rotation=0,
          origin={-574,200})));
   Modelica.Blocks.Continuous.CriticalDamping criticalDamping8(
      n=1,
      x_start={1e-12},
      f=0.1)
     annotation (Placement(transformation(extent={{-596,208},{-576,228}})));
   Modelica.Blocks.Sources.RealExpression asupheat2(y=3e-6)
      annotation (Placement(transformation(extent={{-468,-56},{-458,-46}})));
    Modelica.Blocks.Logical.Switch switch11
      annotation (Placement(transformation(extent={{-450,-52},{-440,-42}})));
   Modelica.Blocks.Sources.RealExpression RelDispl2(y=1)
     annotation (Placement(transformation(extent={{-722,-42},{-704,-26}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p5(vleFluidType=sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-614,166},{-606,174}})));
    TIL.VLEFluidComponents.Sensors.Sensor_p sensor_p6(vleFluidType=sim.vleFluidType2)
      annotation (Placement(transformation(extent={{-606,-40},{-598,-32}})));
    TIL.LiquidComponents.Sensors.Sensor_T_degC sensor_T_degC13
      annotation (Placement(transformation(extent={{134,376},{142,384}})));
    Or2 or2(
      IW_Layer=tank_IW.summary.arrays.T_degC_liq_cell[5],
      IW_Temp=9,
      SH_Layer=tank_SH.summary.arrays.T_degC_liq_cell[1],
      SH_Temp=34)
      annotation (Placement(transformation(extent={{-766,-14},{-746,6}})));
   Modelica.Blocks.Logical.Switch switch12
     annotation (Placement(transformation(extent={{166,-426},{154,-414}})));
   Modelica.Blocks.Sources.RealExpression DHWT_Temp6(y=tank_DHW.summary.arrays.T_degC_liq_cell[
          10])
     annotation (Placement(transformation(extent={{194,-422},{176,-406}})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint4(y=1e-7)
      annotation (Placement(transformation(extent={{48,438},{28,458}})));
    TIL.OtherComponents.Controllers.PIController PI_DHWdump(
      controllerType="PI",
      invertFeedback=true,
      initType="initialOutput",
      use_activeInput=true,
      use_y_notActive=true,
      yMax=3,
      yInitial=1e-7,
      yMin=1e-7,
      Ti=0.1,
      k=1e-4) annotation (Placement(transformation(extent={{-4,418},{-16,430}})));
    Modelica.Blocks.Sources.RealExpression floorHeatingSetpoint6(y=17)
      annotation (Placement(transformation(extent={{52,420},{32,440}})));
    ComControl comControl(
      Reldisp=Comp_Pro_reldisp,
      u1=tank_IW.summary.arrays.T_degC_liq_cell[20],
      u2=tank_IW.summary.arrays.T_degC_liq_cell[15],
      RelTreshold=1)
      annotation (Placement(transformation(extent={{-780,-90},{-760,-70}})));
    Modelica.Blocks.Sources.BooleanStep booleanStep(startTime=50000, startValue=
         false)
      annotation (Placement(transformation(extent={{-810,-62},{-790,-42}})));
  equation
    Comp_MT_W=Compressor_MT.shaftPower;
    Comp_MT_reldisp=Compressor_MT.relDisplacement_in;
    Comp_LT_W=Compressor_LT.shaftPower;
    Comp_LT_reldisp=Compressor_LT.relDisplacement_in;
    Com_Parll_reldisp=Compressor_parallell.relDisplacement_in;
    Com_Parll_W=Compressor_parallell.shaftPower;
    Comp_Pro_W=Compressor_propane.shaftPower+0.001;
    Comp_Pro_reldisp=Compressor_propane.relDisplacement_in;

    GC1_Q=HX1.summary.path_b.Q_flow_liq;
    GC2_Q=HX2.summary.path_b.Q_flow_liq;
    GC3_Q=HX3.summary.path_b.Q_flow_liq;
    HX_CO2_IW_Q=HX_CO2_IW.summary.Q_flow;
    HX_DHWdump_Q=-parallelFlowHX.summary.Q_flow_liq;
    HX_RefRoom_Q=HX_Chiller.summary.Q_flow_vle;
    HX_Freezer_Q=HX_Freezer.summary.Q_flow_vle;
    HX_CO2air=HX_Air.summary.Q_flow_vle;
    HX_ProSH=-HX_Ammonia_SH.summary.Q_flow;
    HX_ProIW=HX_Propane_IW.summary.Q_flow;

    connect(floorHeatingSetpoint.y, PI_Floor.u_s) annotation (Line(points={{-187,
            238},{-187,240},{-218.4,240}},       color={0,0,127}));
    connect(sensor_T_degC5.sensorValue, PI_Floor.u_m) annotation (Line(points={{-200,
            276},{-224,276},{-224,245.8}},color={0,0,127}));
    connect(sensor_T_degC3.port, valve.portA) annotation (Line(
        points={{-190,146},{-190,142},{-216,142},{-216,112}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_p.port, valve.portA) annotation (Line(
        points={{-202,128},{-216,128},{-216,112}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_p.sensorValue, PI_HPValve.u_m) annotation (Line(points={{-195.8,
            128},{-192,128},{-192,109.8}}, color={0,0,127}));
    connect(HighPressure.y, PI_HPValve.u_s)
      annotation (Line(points={{-171,104},{-186,104},{-186.4,104}},
                                                         color={0,0,127}));
    connect(PI_HPValve.y, valve.effectiveFlowArea_in) annotation (Line(points={{-198.4,
            104},{-198.4,104},{-211,104}},         color={0,0,127}));
    connect(statePoint1.sensorPort, pressureState.portB) annotation (Line(
        points={{132,146},{132,142},{156,142}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_H_flow.portA, pressureState.portB) annotation (Line(
        points={{93,142},{104,142},{124,142},{156,142}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_H_flow1.sensorValue, add_GasCooler.u2) annotation (Line(
          points={{-156,139},{-156,139},{-156,117.2},{52.4,117.2}}, color={0,0,
            127}));
    connect(sensor_H_flow.sensorValue, add_GasCooler.u1) annotation (Line(
          points={{90,139},{90,140},{90,117.2},{59.6,117.2}}, color={0,0,127}));
    connect(sensor_H_flow1.portB, valve.portA) annotation (Line(
        points={{-159,142},{-216,142},{-216,112}},
        color={153,204,0},
        thickness=0.5));
    connect(valve.portB, pressureState2.portB) annotation (Line(
        points={{-216,96},{-216,80}},
        color={153,204,0},
        thickness=0.5));
    connect(pressureState2.portA, idealSeparator.portInlet) annotation (Line(
        points={{-216,68},{-216,68},{-216,50},{-211,50}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_ValveCooling.y, valve1.effectiveFlowArea_in) annotation (Line(
          points={{-68.4,34},{-186,34},{-186,1}}, color={0,0,127}));
    connect(Superheat_realinput.y, PI_ValveCooling.u_s)
      annotation (Line(points={{-37,34},{-56.4,34}},      color={0,0,127}));
    connect(idealSeparator.portGas, valve2.portA) annotation (Line(
        points={{-201,50},{-176,50},{-176,52},{-150,52}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_p1.port, valve2.portA) annotation (Line(
        points={{-168,56},{-168,52},{-150,52}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_bypass.y, valve2.effectiveFlowArea_in) annotation (Line(points={
            {-137.6,78},{-132,78},{-132,57},{-142,57}}, color={0,0,127}));
    connect(PI_bypass.u_m, sensor_p1.sensorValue) annotation (Line(points={{
            -144,72.2},{-146,72.2},{-146,62.2},{-168,62.2}}, color={0,0,127}));
    connect(Bypass_Pressure1.y, PI_bypass.u_s) annotation (Line(points={{-171,
            80},{-171,78},{-149.6,78}}, color={0,0,127}));
    connect(Bypass_Pressure2.y, PI_Comp.u_s) annotation (Line(points={{125,46},{124,
            46},{136.4,46}},      color={0,0,127}));
    connect(pressureState1.portA, junction.portA) annotation (Line(
        points={{48,-4},{48,-4},{72,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(valve2.portB, junction.portB) annotation (Line(
        points={{-134,52},{76,52},{76,0}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_q.port, pressureState1.portB) annotation (Line(
        points={{6,0},{6,-4},{36,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_p2.port, Compressor_MT.portA) annotation (Line(
        points={{142,28},{186,28},{186,54}},
        color={153,204,0},
        thickness=0.5));
    connect(Compressor_MT.portB, sensor_m_flow.portA) annotation (Line(
        points={{186,70},{186,70},{186,107}},
        color={153,204,0},
        thickness=0.5));
    connect(floorHeatingSetpoint1.y, PI_DHW.u_s) annotation (Line(points={{-105,
            344},{-105,344},{-128.4,344}},                       color={0,0,127}));
    connect(PI_DHW.y, simplePump.m_flow_in) annotation (Line(points={{-140.4,
            344},{-154,344}},                       color={0,0,127}));
    connect(PI_DHW.u_m, sensor_T_degC1.sensorValue) annotation (Line(points={{-134,
            338.2},{-134,338.2},{-134,278},{72,278}},
          color={0,0,127}));
    connect(sensor_q3.port, idealSeparator.portInlet) annotation (Line(
        points={{-242,58},{-216,58},{-216,50},{-211,50}},
        color={153,204,0},
        thickness=0.5));
    connect(Superheat_realinput1.y,PI_ValveIWC. u_s)
      annotation (Line(points={{-70.9,-96},{-84,-96},{-84,-86},{-90.4,-86}},
                                                       color={0,0,127}));
    connect(junction3.portA, idealSeparator.portLiquid) annotation (Line(
        points={{-206,8.88178e-016},{-206,36}},
        color={153,204,0},
        thickness=0.5));
    connect(junction3.portB, valve1.portA) annotation (Line(
        points={{-202,-4},{-198,-4},{-194,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(junction.portC, junction4.portC) annotation (Line(
        points={{80,-4},{86,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_Valve_Freezer.u_s,Superheat_realinput3. y) annotation (Line(
          points={{-114.4,-340},{-103,-340}},           color={0,0,127}));
    connect(PI_Valve_Freezer.y,valve5. effectiveFlowArea_in) annotation (Line(
          points={{-126.4,-340},{-188,-340},{-188,-385}},             color={0,
            0,127}));
    connect(PI_Valve_Freezer.u_m,sensor_superheating3. sensorValue)
      annotation (Line(points={{-120,-345.8},{-48,-345.8},{-48,-380},{-48,-378},
            {-48,-377.8}},                                  color={0,0,127}));
    connect(Bypass_Pressure3.y,PI_LP_Comp. u_s)
      annotation (Line(points={{71,-342},{74,-342},{82.4,-342}},
                                                         color={0,0,127}));
    connect(sensor_p3.port, Compressor_LT.portA) annotation (Line(
        points={{88,-374},{88,-378},{120,-378},{120,-344}},
        color={153,204,0},
        thickness=0.5));
    connect(pressureState3.portA, Compressor_LT.portA) annotation (Line(
        points={{28,-390},{28,-386},{120,-386},{120,-344}},
        color={153,204,0},
        thickness=0.5));
    connect(junction3.portC, junction5.portA) annotation (Line(
        points={{-206,-8},{-206,-8},{-206,-110}},
        color={153,204,0},
        thickness=0.5));
    connect(junction5.portB, valve3.portA) annotation (Line(
        points={{-202,-114},{-202,-114},{-194,-114}},
        color={153,204,0},
        thickness=0.5));

    connect(valve3.portB, HX_CO2_IW.portA_a) annotation (Line(
        points={{-178,-114},{-112,-114}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC11.port, HX_CO2_IW.portA_b) annotation (Line(
        points={{-128,-124},{-128,-130},{-112,-130}},
        color={0,170,238},
        thickness=0.5));

    connect(sensor_T_degC17.port, hydraulicCapacitor1.portB) annotation (Line(
        points={{104,388},{104,384},{74,384}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_m_flow3.portA, hydraulicCapacitor1.portA) annotation (Line(
        points={{55,384},{55,384},{66,384}},
        color={0,170,238},
        thickness=0.5));
    connect(rotatoryBoundary1.rotatoryFlange, Compressor_MT.rotatoryFlange)
      annotation (Line(
        points={{158,62},{168,62},{178,62}},
        color={135,135,135},
        thickness=0.5));
    connect(rotatoryBoundary2.rotatoryFlange, Compressor_LT.rotatoryFlange)
      annotation (Line(
        points={{102,-336},{112,-336}},
        color={135,135,135},
        thickness=0.5));

    connect(tank_DHW.portB, junction9.portC) annotation (Line(
        points={{102,352},{102,352},{104,352},{104,358}},
        color={0,170,238},
        thickness=0.5));
    connect(tank_DHW.portA, junction10.portB) annotation (Line(
        points={{102,320},{104,320},{104,314},{108,314}},
        color={0,170,238},
        thickness=0.5));
    connect(junction10.portA, hydraulicCapacitor1.portB) annotation (Line(
        points={{112,310},{78,310},{78,384},{74,384}},
        color={0,170,238},
        thickness=0.5));
    connect(parallelFlowHX.portB_liq, sensor_m_flow3.portB) annotation (Line(
        points={{-32,384},{-32,384},{49,384}},
        color={0,170,238},
        thickness=0.5));
    connect(parallelFlowHX.portA_liq, simplePump.portA) annotation (Line(
        points={{-60,384},{-164,384},{-164,346}},
        color={0,170,238},
        thickness=0.5));
    connect(simpleFan2.portB, parallelFlowHX.portA_gas) annotation (Line(
        points={{-46,416},{-46,416},{-46,398}},
        color={255,153,0},
        thickness=0.5));
    connect(boundary.port, simpleFan2.portA) annotation (Line(
        points={{-46,444},{-46,444},{-46,432}},
        color={255,153,0},
        thickness=0.5));
    connect(parallelFlowHX.portB_gas, boundary1.port) annotation (Line(
        points={{-46,370},{-46,356}},
        color={255,153,0},
        thickness=0.5));
    connect(sensor_T_degC.port, simplePump.portA) annotation (Line(
        points={{-146,390},{-146,384},{-164,384},{-164,346}},
        color={0,170,238},
        thickness=0.5));
    connect(floorHeatingSetpoint3.y, greaterThreshold.u)
      annotation (Line(points={{59,414},{59,414},{52,414}},
                                                       color={0,0,127}));
    connect(junction13.portC, junction11.portB) annotation (Line(
        points={{-274,262},{-274,262},{-282,262}},
        color={0,170,238},
        thickness=0.5));
    connect(junction12.portB, junction14.portC) annotation (Line(
        points={{-282,208},{-274,208}},
        color={0,170,238},
        thickness=0.5));
    connect(tank_SH.portB, junction11.portA) annotation (Line(
        points={{-288,250},{-286,250},{-286,258}},
        color={0,170,238},
        thickness=0.5));
    connect(InletFloor2.port, junction12.portC) annotation (Line(
        points={{-332,208},{-290,208}},
        color={0,170,238},
        thickness=0.5));
    connect(InletFloor1.port, junction11.portC) annotation (Line(
        points={{-332,262},{-332,262},{-302,262},{-300,262},{-290,262}},
        color={0,170,238},
        thickness=0.5));
    connect(PI_Floor1.y, simplePump2.m_flow_in) annotation (Line(points={{-428.4,
            234},{-428.4,234},{-454,234}},        color={0,0,127}));
    connect(floorHeatingSetpoint5.y, PI_Floor1.u_s) annotation (Line(points={{-397,
            234},{-397,234},{-416.4,234}},      color={0,0,127}));
    connect(PI_Floor1.u_m, sensor_T_degC18.sensorValue) annotation (Line(points={{-422,
            228.2},{-422,226},{-430,226},{-452,226}},         color={0,0,127}));
    connect(sensor_T_degC10.port, junction8.portB) annotation (Line(
        points={{-266,-126},{-266,-130},{-250,-130}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC18.port, simplePump2.portA) annotation (Line(
        points={{-452,220},{-458,220},{-464,220},{-464,232}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC15.port, junction11.portC) annotation (Line(
        points={{-316,266},{-316,262},{-300,262},{-290,262}},
        color={0,170,238},
        thickness=0.5));
    connect(InletFloor4.port, junction15.portB) annotation (Line(
        points={{-282,-178},{-282,-178},{-250,-178}},
        color={0,170,238},
        thickness=0.5));
    connect(InletFloor3.port, junction8.portB) annotation (Line(
        points={{-280,-130},{-250,-130}},
        color={0,170,238},
        thickness=0.5));
    connect(HX1.portA_a, sensor_H_flow.portB) annotation (Line(
        points={{76,142},{87,142}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC8.port, HX1.portB_b) annotation (Line(
        points={{40,162},{40,158},{48,158}},
        color={0,170,238},
        thickness=0.5));
    connect(junction9.portA, HX1.portA_b) annotation (Line(
        points={{100,362},{88,362},{88,158},{76,158}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC1.port, HX1.portA_b) annotation (Line(
        points={{72,272},{88,272},{88,158},{76,158}},
        color={0,170,238},
        thickness=0.5));
    connect(HX2.portA_a, HX1.portB_a) annotation (Line(
        points={{-22,142},{13,142},{48,142}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC7.port, HX1.portB_a) annotation (Line(
        points={{14,146},{14,142},{48,142}},
        color={153,204,0},
        thickness=0.5));
    connect(HX3.portB_a, sensor_H_flow1.portA) annotation (Line(
        points={{-138,142},{-153,142}},
        color={153,204,0},
        thickness=0.5));
    connect(HX3.portA_a, HX2.portB_a) annotation (Line(
        points={{-110,142},{-110,142},{-50,142}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC6.port, HX2.portB_a) annotation (Line(
        points={{-90,146},{-90,142},{-50,142}},
        color={153,204,0},
        thickness=0.5));
    connect(simplePump.portB, HX3.portB_b) annotation (Line(
        points={{-164,330},{-164,330},{-164,158},{-138,158}},
        color={0,170,238},
        thickness=0.5));
    connect(HX3.portA_b, HX1.portB_b) annotation (Line(
        points={{-110,158},{-100,158},{-100,172},{30,172},{30,158},{48,158}},
        color={0,170,238},
        thickness=0.5));
    connect(Heat_Cooling.heatPort,volume. heatPort) annotation (Line(
        points={{-116,-60},{-116,-60},{-106,-60}},
        color={204,0,0},
        thickness=0.5));
    connect(PI_PumpChiller.y, simpleFan.V_flow_in) annotation (Line(points={{-119.6,
            -42},{-119.6,-42},{-106,-42}}, color={0,0,127}));
    connect(sensor_T.sensorValue, PI_PumpChiller.u_m) annotation (Line(points={
            {-108,-30},{-126,-30},{-126,-36.2}}, color={0,0,127}));
    connect(Setpoint_Cooling.y, PI_PumpChiller.u_s) annotation (Line(points={{-145,
            -42},{-145,-42},{-131.6,-42}}, color={0,0,127}));
    connect(volume.portB, simpleFan.portA) annotation (Line(
        points={{-96,-56},{-96,-50}},
        color={255,153,0},
        thickness=0.5));
    connect(simpleFan.portB, HX_Chiller.portA_gas) annotation (Line(
        points={{-96,-34},{-96,-18}},
        color={255,153,0},
        thickness=0.5));
    connect(sensor_T.port, HX_Chiller.portA_gas) annotation (Line(
        points={{-102,-30},{-96,-30},{-96,-18}},
        color={255,153,0},
        thickness=0.5));
    connect(HX_Chiller.portB_gas, volume.portA) annotation (Line(
        points={{-96,10},{-96,10},{-96,18},{-68,18},{-68,-68},{-96,-68},{-96,-64}},
        color={255,153,0},
        thickness=0.5));

    connect(sensor_T_degC19.port, volume.portA) annotation (Line(
        points={{-78,-38},{-68,-38},{-68,-68},{-96,-68},{-96,-64}},
        color={255,153,0},
        thickness=0.5));
    connect(simpleFan1.portA,volume2. portB) annotation (Line(
        points={{-130,-436},{-130,-436},{-130,-446}},
        color={255,153,0},
        thickness=0.5));
    connect(Heat_Cooling1.heatPort,volume2. heatPort) annotation (Line(
        points={{-152,-450},{-140,-450}},
        color={204,0,0},
        thickness=0.5));
    connect(PI_PumpFreezer.y, simpleFan1.V_flow_in) annotation (Line(points={{-153.6,
            -428},{-153.6,-428},{-140,-428}}, color={0,0,127}));
    connect(sensor_T2.sensorValue, PI_PumpFreezer.u_m) annotation (Line(points=
            {{-144,-410},{-160,-410},{-160,-422.2}}, color={0,0,127}));
    connect(Setpoint_Cooling1.y, PI_PumpFreezer.u_s) annotation (Line(points={{
            -175,-428},{-175,-428},{-165.6,-428}}, color={0,0,127}));
    connect(simpleFan1.portB, HX_Freezer.portA_gas) annotation (Line(
        points={{-130,-420},{-130,-420},{-130,-404}},
        color={255,153,0},
        thickness=0.5));
    connect(sensor_T2.port, HX_Freezer.portA_gas) annotation (Line(
        points={{-138,-410},{-130,-410},{-130,-404}},
        color={255,153,0},
        thickness=0.5));
    connect(HX_Freezer.portB_gas, volume2.portA) annotation (Line(
        points={{-130,-376},{-130,-376},{-130,-370},{-130,-366},{-98,-366},{-98,
            -460},{-130,-460},{-130,-454}},
        color={255,153,0},
        thickness=0.5));
    connect(sensor_T_degC14.port, volume2.portA) annotation (Line(
        points={{-110,-426},{-110,-426},{-98,-426},{-98,-460},{-130,-460},{-130,
            -454}},
        color={255,153,0},
        thickness=0.5));
    connect(valve5.portB, HX_Freezer.portA_vle) annotation (Line(
        points={{-180,-390},{-162,-390},{-144,-390}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_Freezer.portB_vle, pressureState3.portB) annotation (Line(
        points={{-116,-390},{-38,-390},{16,-390}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_superheating3.port, pressureState3.portB) annotation (Line(
        points={{-48,-384},{-48,-390},{16,-390}},
        color={153,204,0},
        thickness=0.5));
    connect(junction7.portB, valve5.portA) annotation (Line(
        points={{-202,-390},{-199,-390},{-196,-390}},
        color={153,204,0},
        thickness=0.5));
    connect(junction7.portC, valve6.portA) annotation (Line(
        points={{-206,-394},{-206,-394},{-206,-498},{-206,-500},{-62,-500}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_ValveAir.u_s, sup_heat.y) annotation (Line(points={{33.6,-446},{
            38,-446},{38,-436},{42,-436},{47,-436}}, color={0,0,127}));
    connect(PI_ValveAir.u_m, sensor_superheating4.sensorValue) annotation (Line(
          points={{28,-451.8},{28,-452},{28,-470},{78,-470},{78,-487.8}}, color=
           {0,0,127}));
    connect(PI_ValveAir.y, valve6.effectiveFlowArea_in) annotation (Line(points=
           {{21.6,-446},{-54,-446},{-54,-495}}, color={0,0,127}));
    connect(rotatoryBoundary3.rotatoryFlange, Compressor_parallell.rotatoryFlange)
      annotation (Line(
        points={{210,-464},{218,-464}},
        color={135,135,135},
        thickness=0.5));
    connect(junction16.portC, pressureState.portA) annotation (Line(
        points={{182,142},{176,142},{168,142}},
        color={153,204,0},
        thickness=0.5));
    connect(junction16.portB, sensor_m_flow.portB) annotation (Line(
        points={{186,138},{186,138},{186,113}},
        color={153,204,0},
        thickness=0.5));
    connect(junction16.portA, Compressor_parallell.portB) annotation (Line(
        points={{190,142},{224,142},{224,40},{224,-456},{226,-456}},
        color={153,204,0},
        thickness=0.5));
    connect(off_value_GW1.y, PI_ValveAir.y_notActive) annotation (Line(points={
            {47,-422},{28,-422},{28,-440.2}}, color={0,0,127}));
    connect(boundaryUnderdetermined1.port, HX_Air.portB_gas) annotation (Line(
        points={{60,-480},{32,-480},{32,-486}},
        color={255,153,0},
        thickness=0.5));
    connect(sensor_T_degC22.port, HX_Air.portB_gas) annotation (Line(
        points={{12,-480},{32,-480},{32,-486}},
        color={255,153,0},
        thickness=0.5));
    connect(off_value_GW2.y, PI_CompParallell.y_notActive) annotation (Line(
          points={{187,-446},{184,-446},{184,-458.2},{180,-458.2}}, color={0,0,
            127}));
    connect(PI_ValveCooling.u_m, sensor_q.sensorValue) annotation (Line(points={{-62,
            28.2},{-26,28.2},{-26,6.2},{6,6.2}},       color={0,0,127}));
    connect(HX_Ammonia_SH.portA_b, simplePump2.portA) annotation (Line(
        points={{-406,172},{-406,172},{-444,172},{-426,172},{-464,172},{-464,232}},
        color={0,170,238},
        thickness=0.5));
    connect(PI_Floor.y, simplePump1.m_flow_in) annotation (Line(points={{-230.4,
            240},{-236,240},{-236,218}}, color={0,0,127}));
    connect(junction14.portA, hydraulicCapacitor3.portB) annotation (Line(
        points={{-270,204},{-270,204},{-270,190},{-270,171.5},{-284,171.5}},
        color={0,170,238},
        thickness=0.5));
    connect(rotatoryBoundary4.rotatoryFlange, Compressor_propane.rotatoryFlange)
      annotation (Line(
        points={{-648,-6},{-648,-6},{-630,-6}},
        color={135,135,135},
        thickness=0.5));
    connect(asupheat.y, PI_ValveNH3.u_s) annotation (Line(points={{-399.4,-66},
            {-395.733,-66}},         color={0,0,127}));

    connect(Compressor_propane.portA, pressureState7.portA) annotation (Line(
        points={{-622,-14},{-622,-22}},
        color={153,204,0},
        thickness=0.5));
    connect(pressureState6.portB, Compressor_propane.portB) annotation (Line(
        points={{-622,8},{-622,8},{-622,2}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_m_flow13.portA, pressureState6.portA) annotation (Line(
        points={{-589,156},{-622,156},{-622,20}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_Propane_IW.portA_a, valve8.portB) annotation (Line(
        points={{-470,-94},{-420,-94},{-370,-94}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_superheating6.port,HX_Propane_IW. portB_a) annotation (Line(
        points={{-508,-92},{-508,-94},{-498,-94}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_Pump_IWC1.y, simplePump3.m_flow_in)
      annotation (Line(points={{-540.4,-154},{-550,-154}},
                                                         color={0,0,127}));
    connect(junction14.portB, simplePump1.portA) annotation (Line(
        points={{-266,208},{-238,208}},
        color={0,170,238},
        thickness=0.5));
    connect(valve1.portB, HX_Chiller.portA_vle) annotation (Line(
        points={{-178,-4},{-110,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_Chiller.portB_vle, pressureState1.portB) annotation (Line(
        points={{-82,-4},{36,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(idealSeparator1.portGas, Compressor_MT.portA) annotation (Line(
        points={{149,-4},{186,-4},{186,54}},
        color={153,204,0},
        thickness=0.5));
    connect(tank_IW.portA, junction15.portA) annotation (Line(
        points={{-246,-168},{-246,-168},{-246,-174}},
        color={0,170,238},
        thickness=0.5));
    connect(HX_CO2_IW.portB_b, Pump_IWC.portB) annotation (Line(
        points={{-84,-130},{-74,-130},{-74,-152}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_p4.port, Compressor_parallell.portA) annotation (Line(
        points={{182,-494},{182,-500},{226,-500},{226,-472}},
        color={153,204,0},
        thickness=0.5));
    connect(simplePump2.portB, junction13.portA) annotation (Line(
        points={{-464,248},{-464,248},{-464,290},{-270,290},{-270,266}},
        color={0,170,238},
        thickness=0.5));
    connect(junction10.portC, OutletDHW3.port) annotation (Line(
        points={{116,314},{160,314},{160,314}},
        color={0,170,238},
        thickness=0.5));
    connect(junction9.portB, OutletDHW2.port) annotation (Line(
        points={{104,366},{104,370},{162,370}},
        color={0,170,238},
        thickness=0.5));
    connect(tank_SH.portA, junction12.portA) annotation (Line(
        points={{-288,218},{-286,218},{-286,212}},
        color={0,170,238},
        thickness=0.5));
    connect(junction8.portC, junction17.portB) annotation (Line(
        points={{-242,-130},{-240,-130},{-236,-130}},
        color={0,170,238},
        thickness=0.5));
    connect(junction17.portC, HX_CO2_IW.portA_b) annotation (Line(
        points={{-228,-130},{-112,-130}},
        color={0,170,238},
        thickness=0.5));
    connect(HX_Propane_IW.portA_b, junction17.portA) annotation (Line(
        points={{-470,-110},{-376,-110},{-232,-110},{-232,-126}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC30.port, junction17.portA) annotation (Line(
        points={{-460,-126},{-442,-126},{-442,-110},{-232,-110},{-232,-126}},
        color={0,170,238},
        thickness=0.5));
    connect(junction15.portC, junction18.portB) annotation (Line(
        points={{-242,-178},{-242,-178},{-236,-178}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_m_flow2.portA, junction18.portA) annotation (Line(
        points={{-267,-226},{-250,-226},{-232,-226},{-232,-182}},
        color={0,170,238},
        thickness=0.5));
    connect(simplePump3.portA, sensor_m_flow2.portB) annotation (Line(
        points={{-560,-156},{-560,-156},{-560,-224},{-560,-226},{-273,-226}},
        color={0,170,238},
        thickness=0.5));
    connect(PI_Pump_IWC.y, Pump_IWC.m_flow_in) annotation (Line(points={{-46.4,
            -166},{-62,-166},{-64,-166}}, color={0,0,127}));
    connect(off_IWPump.y, PI_Pump_IWC.y_notActive) annotation (Line(points={{
            5.3,-183},{5.3,-180},{-40,-180},{-40,-171.8}}, color={0,0,127}));
    connect(switch4.y, hysteresis1.u) annotation (Line(points={{15.4,-156},{
            12.2,-156},{13.2,-156}}, color={0,0,127}));
    connect(IWT_Temp1.y, switch4.u1) annotation (Line(points={{39.1,-149},{32,
            -149},{32,-151.2},{29.2,-151.2}}, color={0,0,127}));
    connect(switch4.u3, IWT_Temp10.y) annotation (Line(points={{29.2,-160.8},{
            35.6,-160.8},{35.6,-161},{39.1,-161}}, color={0,0,127}));
    connect(hysteresis1.y, switch4.u2) annotation (Line(points={{-0.6,-156},{-2,
            -156},{-2,-164},{34,-164},{34,-156},{29.2,-156}}, color={255,0,255}));
    connect(hysteresis1.y, PI_Pump_IWC.activeInput) annotation (Line(points={{
            -0.6,-156},{-14,-156},{-14,-158},{-14,-162.2},{-34.4,-162.2}},
          color={255,0,255}));
    connect(statePoint2.sensorPort, valve8.portB) annotation (Line(
        points={{-456,-90},{-456,-94},{-370,-94}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC9.port, valve8.portB) annotation (Line(
        points={{-424,-90},{-424,-94},{-370,-94}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_m_flow4.portB,HX_Propane_IW. portB_b) annotation (Line(
        points={{-519,-110},{-508,-110},{-498,-110}},
        color={0,170,238},
        thickness=0.5));
    connect(HX_Ammonia_SH.portB_b, sensor_m_flow5.portB) annotation (Line(
        points={{-378,172},{-367,172}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_m_flow5.portA, hydraulicCapacitor3.portA) annotation (Line(
        points={{-361,172},{-328,172},{-328,171.5},{-290,171.5}},
        color={0,170,238},
        thickness=0.5));
    connect(not3.u,hysteresis2. y) annotation (Line(points={{-839.2,18},{-839.2,
            18},{-841.4,18}},          color={255,0,255}));
    connect(RelDispl1.y, PI_CompAmmonia1.u_s) annotation (Line(points={{-725.1,
            -48},{-705.6,-48}},         color={0,0,127}));
    connect(PI_CompAmmonia1.y, criticalDamping2.u) annotation (Line(points={{-693.6,
            -48},{-693.6,-48},{-684,-48}},   color={0,0,127}));
    connect(switch2.y,hysteresis2. u)
      annotation (Line(points={{-861.4,18},{-861.4,18},{-855.2,18}},
                                                         color={0,0,127}));
    connect(SHT_Temp.y, switch2.u1) annotation (Line(points={{-887.1,23},{
            -887.1,22.8},{-875.2,22.8}}, color={0,0,127}));
   connect(DHWT_Temp2.y,switch2. u3)
     annotation (Line(points={{-887.1,13},{-887.1,13.2},{-875.2,13.2}},
                                                        color={0,0,127}));
   connect(not3.y,switch2. u2) annotation (Line(points={{-825.4,18},{-814,18},{
            -814,10},{-884,10},{-884,18},{-875.2,18}},
         color={255,0,255}));
    connect(AmmoniaOff.y,switch1. u3) annotation (Line(points={{-749.2,-32},{-734,
            -32},{-734,-12},{-724,-12}}, color={0,0,127}));
    connect(AmmoniaOn.y,switch1. u1) annotation (Line(points={{-747.2,24},{-734,24},
            {-734,4},{-724,4}},          color={0,0,127}));
    connect(criticalDamping2.y, Compressor_propane.relDisplacement_in)
      annotation (Line(points={{-661,-48},{-640,-48},{-640,-12},{-633,-12}},
                                                                         color=
            {0,0,127}));
    connect(PI_ValveNH3.u_m, sensor_superheating6.sensorValue) annotation (Line(
          points={{-392,-69.8667},{-392,-69.8667},{-392,-80},{-508,-80},{-508,
            -85.8}},
          color={0,0,127}));
    connect(PI_Pump_IWC.u_s, sensor_T_degC11.sensorValue) annotation (Line(
          points={{-34.4,-166},{-26,-166},{-26,-118},{-128,-118}}, color={0,0,
            127}));
    connect(PI_Pump_IWC.u_m, Temp_IWC3.y) annotation (Line(points={{-40,-160.2},
            {-42,-160.2},{-42,-136},{-42,-137},{-6.7,-137}}, color={0,0,127}));
    connect(Temp_IWC1.y, PI_Pump_IWC1.u_s) annotation (Line(points={{-515,-154},{-528.4,
            -154}},                     color={0,0,127}));
    connect(PI_ValveIWC.activeInput, on_off_airvalve1.y) annotation (Line(
          points={{-90.4,-82.2},{-83.2,-82.2},{-83.2,-87},{-74.8,-87}}, color={
            255,0,255}));

    connect(switch1.y, criticalDamping1.u) annotation (Line(points={{-701,-4},{-692,
            -4},{-692,-6},{-686,-6}},          color={0,0,127}));
    connect(rotatoryBoundary4.n_in, criticalDamping1.y) annotation (Line(points={{-652,-6},
            {-663,-6}},                        color={0,0,127}));
    connect(on_off_airvalve4.y, PI_Floor1.activeInput) annotation (Line(points={{-394.8,
            220},{-402,220},{-402,230.2},{-416.4,230.2}},          color={255,0,
            255}));
    connect(asupheat5.y, PI_Floor1.y_notActive) annotation (Line(points={{
            -427.3,254},{-424,254},{-424,239.8},{-422,239.8}}, color={0,0,127}));
    connect(PI_Pump_IWC1.u_m, sensor_T_degC30.sensorValue) annotation (Line(
          points={{-534,-148.2},{-534,-148.2},{-534,-124},{-460,-124},{-460,-120}},
                       color={0,0,127}));
    connect(PI_Pump_IWC1.y_notActive, asupheat4.y) annotation (Line(points={{-534,
            -159.8},{-534,-172},{-535.3,-172}},   color={0,0,127}));
    connect(on_off_airvalve2.y, and2.u1) annotation (Line(points={{-535.3,-49},{-534,
            -49},{-534,-55},{-529,-55}},   color={255,0,255}));
    connect(fileReader.tfr_signals,realVariableName. tfr_signals)
      annotation (Line(points={{194,408},{194,408},{194,394}},
                                                         color={127,0,0}));
    connect(realVariableName.value, OutletDHW2.m_flow_in) annotation (Line(
          points={{182,386},{174,386},{174,372},{166,372}}, color={0,0,127}));
    connect(PI_ValveNH3.y, criticalDamping3.u) annotation (Line(points={{
            -387.733,-66},{-387.733,-66},{-380.8,-66}},        color={0,0,127}));
    connect(criticalDamping3.y, valve8.effectiveFlowArea_in) annotation (Line(
          points={{-371.6,-66},{-362,-66},{-362,-89}},            color={0,0,
            127}));
    connect(Superheat_realinput4.y, PI_ValveIWC.y_notActive) annotation (Line(
          points={{-70.9,-106},{-70.9,-106},{-96,-106},{-96,-91.8}}, color={0,0,
            127}));
    connect(criticalDamping5.u, PI_ValveIWC.y) annotation (Line(points={{-112.8,
            -86},{-104,-86},{-102.4,-86}},            color={0,0,127}));
    connect(criticalDamping5.y, valve3.effectiveFlowArea_in) annotation (Line(
          points={{-126.6,-86},{-188,-86},{-188,-109},{-186,-109}},
          color={0,0,127}));
    connect(realVariableSC.value, InletFloor3.m_flow_in) annotation (Line(
          points={{-304,-128},{-284,-128}},             color={0,0,127}));
    connect(switch6.y,hysteresis3. u) annotation (Line(points={{-861.4,-12},{
            -868,-12},{-853.2,-12}}, color={0,0,127}));
    connect(idealSeparator3.portGas, Compressor_parallell.portA) annotation (
        Line(
        points={{157,-500},{226,-500},{226,-472}},
        color={153,204,0},
        thickness=0.5));
    connect(idealSeparator3.portInlet, HX_Air.portB_vle) annotation (Line(
        points={{147,-500},{46,-500}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_superheating4.port, HX_Air.portB_vle) annotation (Line(
        points={{78,-494},{80,-494},{80,-500},{46,-500}},
        color={153,204,0},
        thickness=0.5));
    connect(asupheat8.y,switch7. u1) annotation (Line(points={{-81.3,-558},{-72,
            -558},{-64,-558}},     color={0,0,127}));
    connect(boundaryOverdetermined1.port, simpleFan4.portA) annotation (Line(
        points={{-34,-530},{-16,-530}},
        color={255,153,0},
        thickness=0.5));
    connect(simpleFan4.portB, HX_Air.portA_gas) annotation (Line(
        points={{0,-530},{32,-530},{32,-514}},
        color={255,153,0},
        thickness=0.5));
    connect(switch7.y, simpleFan4.V_flow_in) annotation (Line(points={{-41,-566},
            {-28,-566},{-8,-566},{-8,-540}}, color={0,0,127}));
    connect(asupheat9.y, switch7.u3) annotation (Line(points={{-81.3,-574},{
            -72.65,-574},{-64,-574}}, color={0,0,127}));
    connect(on_off_airvalve3.y, switch7.u2) annotation (Line(points={{-103,-566},
            {-98,-566},{-64,-566}}, color={255,0,255}));
    connect(fileReader2.tfr_signals, realVariableSC1.tfr_signals) annotation (
        Line(points={{-374,268},{-368,268},{-368,282},{-358,282},{-358,272}},
          color={127,0,0}));
    connect(realVariableSC1.value, InletFloor1.m_flow_in) annotation (Line(
          points={{-346,264},{-340,264},{-336,264}}, color={0,0,127}));
    connect(off_value_GW5.y, PI_CompParallell.u_s) annotation (Line(points={{
            155,-454},{164,-454},{164,-464},{174.4,-464}}, color={0,0,127}));
    connect(Bypass_Pressure5.y, PI_CompParallell.u_m) annotation (Line(points={
            {155,-484},{168,-484},{168,-482},{180,-482},{180,-469.8}}, color={0,
            0,127}));
    connect(pressureState5.portA, HX_Air.portA_vle) annotation (Line(
        points={{-10,-500},{4,-500},{18,-500}},
        color={153,204,0},
        thickness=0.5));
    connect(pressureState5.portB, valve6.portB) annotation (Line(
        points={{-22,-500},{-46,-500},{-46,-500}},
        color={153,204,0},
        thickness=0.5));
    connect(PI_ValveIWC.u_m, sensor_q4.sensorValue) annotation (Line(points={{-96,
            -80.2},{-96,-72},{-22,-72},{-22,-103.8}},     color={0,0,127}));
    connect(not5.u, hysteresis5.y) annotation (Line(points={{123.6,-422},{123.6,
            -422},{129.2,-422}}, color={255,0,255}));
    connect(not5.y, PI_ValveAir.activeInput) annotation (Line(points={{105.2,
            -422},{76,-422},{76,-452},{33.6,-452},{33.6,-449.8}}, color={255,0,
            255}));
    connect(not5.y, PI_CompParallell.activeInput) annotation (Line(points={{
            105.2,-422},{100,-422},{100,-462},{100,-467.8},{174.4,-467.8}},
          color={255,0,255}));
    connect(PI_LP_Comp.y, Compressor_LT.relDisplacement_in)
      annotation (Line(points={{94.4,-342},{109,-342}},color={0,0,127}));
    connect(PI_LP_Comp.u_m, sensor_p3.sensorValue)
      annotation (Line(points={{88,-347.8},{88,-367.8}}, color={0,0,127}));
    connect(PI_CompParallell.y, Compressor_parallell.relDisplacement_in)
      annotation (Line(points={{186.4,-464},{200,-464},{200,-470},{215,-470}},
          color={0,0,127}));
    connect(PI_Comp.y, Compressor_MT.relDisplacement_in) annotation (Line(points={
            {148.4,46},{150,46},{175,46},{175,56}}, color={0,0,127}));
    connect(sensor_p2.sensorValue, PI_Comp.u_m)
      annotation (Line(points={{142,34.2},{142,40.2}}, color={0,0,127}));
    connect(sensor_m_flow1.portA, junction18.portC) annotation (Line(
        points={{-197,-178},{-212,-178},{-228,-178}},
        color={0,170,238},
        thickness=0.5));
    connect(hydraulicCapacitor2.portA, sensor_m_flow1.portB) annotation (Line(
        points={{-146,-178.5},{-168,-178.5},{-168,-178},{-191,-178}},
        color={0,170,238},
        thickness=0.5));
    connect(hydraulicCapacitor2.portB, Pump_IWC.portA) annotation (Line(
        points={{-140,-178.5},{-74,-178.5},{-74,-168}},
        color={0,170,238},
        thickness=0.5));
    connect(tank_IW.portB, junction8.portA) annotation (Line(
        points={{-246,-140},{-246,-140},{-246,-134}},
        color={0,170,238},
        thickness=0.5));
    connect(junction1.portA, idealSeparator1.portInlet) annotation (Line(
        points={{124,-4},{124,-4},{139,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(junction1.portC, junction4.portA) annotation (Line(
        points={{116,-4},{116,-4},{94,-4}},
        color={153,204,0},
        thickness=0.5));
    connect(simplePump3.portB, sensor_m_flow4.portA) annotation (Line(
        points={{-560,-140},{-560,-140},{-560,-110},{-525,-110}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC5.port, junction13.portB) annotation (Line(
        points={{-200,270},{-200,262},{-266,262}},
        color={0,170,238},
        thickness=0.5));
    connect(HX2.portA_b, junction13.portB) annotation (Line(
        points={{-22,158},{-4,158},{14,158},{14,262},{-266,262}},
        color={0,170,238},
        thickness=0.5));
    connect(not4.u,hysteresis4. y) annotation (Line(points={{-94.4,236},{-94.4,
            236},{-88.8,236}},         color={255,0,255}));
    connect(switch8.y,hysteresis4. u) annotation (Line(points={{-63,234},{-66,
            234},{-66,236},{-70.4,236}}, color={0,0,127}));
    connect(not4.y,switch8. u2) annotation (Line(points={{-112.8,236},{-114,236},
            {-114,260},{-32,260},{-32,234},{-40,234}}, color={255,0,255}));
    connect(PI_Floor.activeInput, not4.y) annotation (Line(points={{-218.4,
            243.8},{-196,243.8},{-196,252},{-112.8,252},{-112.8,236}}, color={
            255,0,255}));
    connect(floorHeatingSetpoint2.y, PI_Floor.y_notActive) annotation (Line(
          points={{-207,224},{-216,224},{-224,224},{-224,234.2}}, color={0,0,
            127}));
    connect(tube.portA, simplePump1.portB) annotation (Line(
        points={{-152,208},{-222,208}},
        color={0,170,238},
        thickness=0.5));
    connect(sensor_T_degC4.port, simplePump1.portB) annotation (Line(
        points={{-178,210},{-178,210},{-178,208},{-222,208}},
        color={0,170,238},
        thickness=0.5));
    connect(tube.portB, HX2.portB_b) annotation (Line(
        points={{-136,208},{-68,208},{-68,158},{-50,158}},
        color={0,170,238},
        thickness=0.5));
    connect(switch8.u3, DHWT_Temp4.y) annotation (Line(points={{-40,226},{-28.9,226}},
                               color={0,0,127}));
    connect(switch8.u1, DHWT_Temp3.y) annotation (Line(points={{-40,242},{-26.9,242}},
                               color={0,0,127}));
    connect(tube1.heatPort, tube.heatPort) annotation (Line(
        points={{122,-168},{122,-168},{324,-168},{324,218},{-144,218},{-144,210}},
        color={204,0,0},
        thickness=0.5));

    connect(tube1.portA, junction1.portB) annotation (Line(
        points={{120,-160},{120,-122},{122,-122},{122,-84},{120,-84},{120,-8}},
        color={153,204,0},
        thickness=0.5));
    connect(Compressor_LT.portB, tube1.portB) annotation (Line(
        points={{120,-328},{120,-328},{120,-176}},
        color={153,204,0},
        thickness=0.5));
    connect(IWT_Temp2.y, switch6.u1) annotation (Line(points={{-889.1,-7},{
            -889.55,-7},{-889.55,-7.2},{-875.2,-7.2}}, color={0,0,127}));
    connect(IWT_Temp3.y, switch6.u3) annotation (Line(points={{-889.1,-17},{
            -875.2,-17},{-875.2,-16.8}},
                                       color={0,0,127}));
    connect(hysteresis3.y, switch6.u2) annotation (Line(points={{-839.4,-12},{
            -834,-12},{-834,-22},{-882,-22},{-882,-12},{-875.2,-12}},
                                                                 color={255,0,
            255}));
    connect(on_off_propane_valves1.y, PI_Pump_IWC1.activeInput) annotation (
        Line(points={{-510.8,-142},{-520,-142},{-520,-150.2},{-528.4,-150.2}},
          color={255,0,255}));
    connect(HX_propaneDump.portB_vle, HX_Ammonia_SH.portA_a) annotation (Line(
        points={{-504,156},{-504,156},{-406,156}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_propaneDump.portA_vle, sensor_m_flow13.portB) annotation (Line(
        points={{-532,156},{-583,156}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC2.port, sensor_m_flow13.portB) annotation (Line(
        points={{-566,160},{-566,156},{-583,156}},
        color={153,204,0},
        thickness=0.5));
    connect(statePoint.sensorPort, sensor_m_flow13.portB) annotation (Line(
        points={{-548,160},{-548,156},{-583,156}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_propaneDump.portB_gas, boundary4.port) annotation (Line(
        points={{-518,142},{-518,118}},
        color={255,153,0},
        thickness=0.5));
    connect(simpleFan5.portB,HX_propaneDump. portA_gas) annotation (Line(
        points={{-536,200},{-518,200},{-518,170}},
        color={255,153,0},
        thickness=0.5));
    connect(asupheat10.y, switch10.u1)
      annotation (Line(points={{-635.3,226},{-630,226}}, color={0,0,127}));
    connect(asupheat11.y, switch10.u3) annotation (Line(points={{-635.3,210},{-635.3,
            210},{-630,210}},        color={0,0,127}));
    connect(on_off_propane_valves2.y, and3.u1) annotation (Line(points={{-679.2,222},
            {-672,222},{-672,218},{-669.2,218}},      color={255,0,255}));
    connect(on_off_propane_valves3.y, and3.u2) annotation (Line(points={{-679.2,212},
            {-672,212},{-672,213.2},{-669.2,213.2}},      color={255,0,255}));
    connect(boundary5.port, simpleFan5.portA) annotation (Line(
        points={{-574,200},{-564,200},{-552,200}},
        color={255,153,0},
        thickness=0.5));
    connect(switch10.y, criticalDamping8.u) annotation (Line(points={{-607,218},{-602.5,
            218},{-598,218}}, color={0,0,127}));
    connect(criticalDamping8.y, simpleFan5.V_flow_in) annotation (Line(points={{-575,
            218},{-544,218},{-544,210}}, color={0,0,127}));
    connect(fileReader1.tfr_signals, realVariableSC.tfr_signals) annotation (Line(
          points={{-316,-146},{-316,-141},{-316,-136}}, color={127,0,0}));
    connect(on_off_propane_valves.y, and2.u2) annotation (Line(points={{-557.4,-48},
            {-558,-48},{-558,-58},{-558,-59},{-529,-59}}, color={255,0,255}));
    connect(and2.y, PI_ValveNH3.activeInput) annotation (Line(points={{-517.5,
            -55},{-416,-55},{-416,-68.5333},{-395.733,-68.5333}},
                                                             color={255,0,255}));
    connect(asupheat1.y, switch11.u1) annotation (Line(points={{-457.5,-43},{-457.5,
            -43},{-451,-43}}, color={0,0,127}));
    connect(asupheat2.y, switch11.u3)
      annotation (Line(points={{-457.5,-51},{-451,-51}}, color={0,0,127}));
    connect(switch11.y, PI_ValveNH3.y_notActive) annotation (Line(points={{-439.5,
            -47},{-392,-47},{-392,-62.1333}}, color={0,0,127}));
    connect(on_off_airvalve2.y, switch11.u2) annotation (Line(points={{-535.3,-49},
            {-534,-49},{-534,-46},{-451,-46},{-451,-47}}, color={255,0,255}));
    connect(and3.y, switch10.u2) annotation (Line(points={{-655.4,218},{-630,218}},
                         color={255,0,255}));
    connect(RelDispl2.y, PI_CompAmmonia1.y_notActive) annotation (Line(points={{-703.1,
            -34},{-700,-34},{-700,-42.2}}, color={0,0,127}));
    connect(sensor_p5.port, pressureState6.portA) annotation (Line(
        points={{-610,166},{-610,156},{-622,156},{-622,20}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_p6.port, pressureState7.portB) annotation (Line(
        points={{-602,-40},{-604,-40},{-604,-46},{-622,-46},{-622,-34}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC13.port, OutletDHW2.port) annotation (Line(
        points={{138,376},{138,376},{138,370},{162,370}},
        color={0,170,238},
        thickness=0.5));
    connect(or2.y, switch1.u2)
      annotation (Line(points={{-745,-4},{-724,-4}}, color={255,0,255}));
    connect(not3.y, or2.u1) annotation (Line(points={{-825.4,18},{-804,18},{
            -768,18},{-768,-4}}, color={255,0,255}));
    connect(hysteresis3.y, or2.u2) annotation (Line(points={{-839.4,-12},{-804,
            -12},{-768,-12}}, color={255,0,255}));
    connect(switch12.y, hysteresis5.u) annotation (Line(points={{153.4,-420},{150,
            -420},{150,-422},{147.6,-422}}, color={0,0,127}));
    connect(DHWT_Temp6.y, switch12.u1) annotation (Line(points={{175.1,-414},{167.2,
            -414},{167.2,-415.2}}, color={0,0,127}));
    connect(DHWT_Temp5.y, switch12.u3) annotation (Line(points={{177.1,-426},{170,
            -426},{170,-424.8},{167.2,-424.8}}, color={0,0,127}));
    connect(not5.y, switch12.u2) annotation (Line(points={{105.2,-422},{100,-422},
            {100,-436},{172,-436},{172,-420},{167.2,-420}}, color={255,0,255}));
    connect(PI_DHWdump.y, simpleFan2.V_flow_in) annotation (Line(points={{-16.4,424},
            {-28,424},{-36,424}}, color={0,0,127}));
    connect(greaterThreshold.y, PI_DHWdump.activeInput) annotation (Line(points={{
            29,414},{14,414},{-4.4,414},{-4.4,420.2}}, color={255,0,255}));
    connect(PI_DHWdump.u_m, sensor_T_degC.sensorValue) annotation (Line(points={{-10,
            418.2},{-10,418.2},{-10,408},{-10,404},{-146,404},{-146,396}}, color={
            0,0,127}));
    connect(floorHeatingSetpoint4.y, PI_DHWdump.y_notActive) annotation (Line(
          points={{27,448},{8,448},{-10,448},{-10,429.8}}, color={0,0,127}));
    connect(floorHeatingSetpoint6.y, PI_DHWdump.u_s) annotation (Line(points={{31,
            430},{14,430},{14,424},{-4.4,424}}, color={0,0,127}));
    connect(comControl.y1, PI_CompAmmonia1.u_m) annotation (Line(points={{-758.7,
            -79.5},{-700,-79.5},{-700,-53.8}},
                                        color={0,0,127}));
    connect(booleanStep.y, PI_CompAmmonia1.activeInput) annotation (Line(points=
           {{-789,-52},{-746,-52},{-746,-51.8},{-705.6,-51.8}}, color={255,0,
            255}));
    connect(HX_Propane_IW.portB_a, pressureState7.portB) annotation (Line(
        points={{-498,-94},{-622,-94},{-622,-34}},
        color={153,204,0},
        thickness=0.5));
    connect(valve8.portA, HX_Ammonia_SH.portB_a) annotation (Line(
        points={{-354,-94},{-330,-94},{-290,-94},{-290,156},{-378,156}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC23.port, HX_Ammonia_SH.portB_a) annotation (Line(
        points={{-346,160},{-346,156},{-332,156},{-378,156}},
        color={153,204,0},
        thickness=0.5));
    connect(statePoint3.sensorPort, HX_Ammonia_SH.portB_a) annotation (Line(
        points={{-328,160},{-328,156},{-378,156}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_T_degC12.port, HX_Ammonia_SH.portB_a) annotation (Line(
        points={{-306,160},{-306,156},{-378,156}},
        color={153,204,0},
        thickness=0.5));
    connect(junction5.portC, junction7.portA) annotation (Line(
        points={{-206,-118},{-206,-118},{-206,-386}},
        color={153,204,0},
        thickness=0.5));
    connect(HX_CO2_IW.portB_a, junction4.portB) annotation (Line(
        points={{-84,-114},{-12,-114},{-12,-112},{90,-112},{90,-8}},
        color={153,204,0},
        thickness=0.5));
    connect(sensor_q4.port, junction4.portB) annotation (Line(
        points={{-22,-110},{-24,-110},{-24,-114},{-12,-114},{-12,-112},{90,-112},{
            90,-8}},
        color={153,204,0},
        thickness=0.5));
    annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-920,
              -460},{280,480}})), Diagram(coordinateSystem(preserveAspectRatio=false,
                     extent={{-920,-460},{280,480}}), graphics={Text(
            extent={{-220,-176},{-236,-168}},
            lineColor={0,0,0},
            textString="IWT Top"), Text(
            extent={{-208,-148},{-236,-136}},
            lineColor={0,0,0},
            textString="IWT Bottom
          ")}));
  end Summer_run;
end Britannia_HVAC_DHW;
